@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultMuleContext.java 24405 2012-05-25 14:28:45Z svacas $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -53,6 +53,7 @@ import org.mule.exception.DefaultSystemExceptionStrategy;
 import org.mule.expression.DefaultExpressionManager;
 import org.mule.lifecycle.MuleContextLifecycleManager;
 import org.mule.management.stats.AllStatistics;
+import org.mule.management.stats.ProcessingTimeWatcher;
 import org.mule.registry.DefaultRegistryBroker;
 import org.mule.registry.MuleRegistryHelper;
 import org.mule.transport.DefaultPollingController;
@@ -65,6 +66,7 @@ import org.mule.util.ServerStartupSplashScreen;
 import org.mule.util.SplashScreen;
 import org.mule.util.SystemUtils;
 import org.mule.util.UUID;
+import org.mule.util.lock.LockFactory;
 import org.mule.util.queue.QueueManager;
 
 import java.io.Serializable;
@@ -142,6 +144,10 @@ public class DefaultMuleContext implements MuleContext
 
     private TransactionManager transactionManager;
 
+    private LockFactory lockFactory;
+
+    private ProcessingTimeWatcher processingTimeWatcher;
+
     public DefaultMuleContext(MuleConfiguration config,
                               WorkManager workManager,
                               WorkListener workListener,
@@ -826,4 +832,25 @@ public class DefaultMuleContext implements MuleContext
     {
         return registryBroker.lookupObject(MuleProperties.OBJECT_EXPRESSION_LANGUAGE);
     }
+
+    @Override
+    public LockFactory getLockFactory()
+    {
+        if (this.lockFactory == null)
+        {
+            this.lockFactory = registryBroker.get(MuleProperties.OBJECT_LOCK_FACTORY);
+        }
+        return this.lockFactory;
+    }
+
+    @Override
+    public ProcessingTimeWatcher getProcessorTimeWatcher()
+    {
+        if (this.processingTimeWatcher == null)
+        {
+            this.processingTimeWatcher = registryBroker.get(MuleProperties.OBJECT_PROCESSING_TIME_WATCHER);
+        }
+
+        return this.processingTimeWatcher;
+    }
 }
