@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultMuleEventContext.java 20385 2010-11-29 20:25:26Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -39,8 +39,8 @@ import org.mule.transaction.TransactionCoordination;
 import org.mule.transformer.types.DataTypeFactory;
 
 import java.io.OutputStream;
-
-import edu.emory.mathcs.backport.java.util.concurrent.Callable;
+import java.net.URI;
+import java.util.concurrent.Callable;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -72,7 +72,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
     /**
      * Returns the message payload for this event
-     * 
+     *
      * @return the message payload for this event
      */
     public MuleMessage getMessage()
@@ -82,7 +82,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
     /**
      * Reterns the conents of the message as a byte array.
-     * 
+     *
      * @return the conents of the message as a byte array
      * @throws org.mule.api.MuleException if the message cannot be converted into an
      *             array of bytes
@@ -115,7 +115,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * Returns the message transformed into its recognised or expected format. The
      * transformer used is the one configured on the endpoint through which this
      * event was received.
-     * 
+     *
      * @param expectedType The class type required for the return object. This param
      *            just provides a convienient way to manage type casting of
      *            transformed objects
@@ -134,7 +134,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * Returns the message transformed into it's recognised or expected format and
      * then into an array of bytes. The transformer used is the one configured on the
      * endpoint through which this event was received.
-     * 
+     *
      * @return the message transformed into it's recognised or expected format as an
      *         array of bytes.
      * @throws org.mule.api.transformer.TransformerException if a failure occurs in
@@ -150,7 +150,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
     /**
      * Returns the message contents as a string
-     * 
+     *
      * @return the message contents as a string
      * @throws org.mule.api.MuleException if the message cannot be converted into a
      *             string
@@ -165,7 +165,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * then into a String. The transformer used is the one configured on the endpoint
      * through which this event was received. This method will use the default
      * encoding on the event
-     * 
+     *
      * @return the message transformed into it's recognised or expected format as a
      *         Strings.
      * @throws org.mule.api.transformer.TransformerException if a failure occurs in
@@ -180,7 +180,7 @@ public class DefaultMuleEventContext implements MuleEventContext
     /**
      * Returns the message contents as a string This method will use the default
      * encoding on the event
-     * 
+     *
      * @return the message contents as a string
      * @throws org.mule.api.MuleException if the message cannot be converted into a
      *             string
@@ -192,7 +192,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
     /**
      * Returns the current transaction (if any) for the session
-     * 
+     *
      * @return the current transaction for the session or null if there is no
      *         transaction in progress
      */
@@ -211,7 +211,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
     /**
      * This will send an event via the configured outbound router on the service
-     * 
+     *
      * @param message the message to send
      * @return the result of the send if any
      * @throws org.mule.api.MuleException if there is no outbound endpoint configured
@@ -226,7 +226,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * Depending on the session state this methods either Passes an event
      * synchronously to the next available Mule component in the pool or via the
      * endpoint configured for the event
-     * 
+     *
      * @param message the event message payload to send
      * @param endpoint The endpoint to disptch the event through.
      * @return the return Message from the call or null if there was no result
@@ -242,7 +242,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * Depending on the session state this methods either Passes an event
      * synchronously to the next available Mule component in the pool or via the
      * endpoint configured for the event
-     * 
+     *
      * @param message the message payload to send
      * @return the return Message from the call or null if there was no result
      * @throws org.mule.api.MuleException if the event fails to be processed by the
@@ -250,21 +250,18 @@ public class DefaultMuleEventContext implements MuleEventContext
      */
     public MuleMessage sendEvent(MuleMessage message) throws MuleException
     {
-        if (event.getEndpoint() instanceof OutboundEndpoint)
+        if (event.getFlowConstruct() instanceof Service)
         {
-            return clientInterface.process((OutboundEndpoint) event.getEndpoint(), message);
-        }
-        else if (session.getFlowConstruct() instanceof Service)
-        {
-            Service service = (Service) session.getFlowConstruct();
-            DefaultMuleEvent eventToSend = new DefaultMuleEvent(message, event.getEndpoint(), session);
+            Service service = (Service) event.getFlowConstruct();
+            DefaultMuleEvent eventToSend = new DefaultMuleEvent(message,
+                MessageExchangePattern.REQUEST_RESPONSE, service, session);
             MuleEvent event = service.sendEvent(eventToSend);
-            return event == null ? null : event.getMessage();
+            return event == null || VoidMuleEvent.getInstance().equals(event) ? null : event.getMessage();
         }
         else
         {
             throw new MessagingException(
-                CoreMessages.createStaticMessage("Current event has 'inbound' endpoint and FlowConstuct is not a 'Service', MuleEventContext cannot  this message"),
+                CoreMessages.createStaticMessage("FlowConstuct is not a 'Service', MuleEventContext cannot send this message"),
                 event);
         }
     }
@@ -273,7 +270,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * Depending on the session state this methods either Passes an event
      * synchronously to the next available Mule component in the pool or via the
      * endpointUri configured for the event
-     * 
+     *
      * @param message the event message payload to send
      * @param endpointUri The endpointUri to disptch the event through
      * @return the return Message from the call or null if there was no result
@@ -294,10 +291,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
         builder.setExchangePattern(MessageExchangePattern.REQUEST_RESPONSE);
 
-        OutboundEndpoint endpoint = getMuleContext().getRegistry()
-            .lookupEndpointFactory()
-            .getOutboundEndpoint(builder);
-
+        OutboundEndpoint endpoint = getMuleContext().getEndpointFactory().getOutboundEndpoint(builder);
         return clientInterface.process(endpoint, message);
     }
 
@@ -309,7 +303,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * any time to check that the invocation has completed. A timeout is associated
      * with the invocation, which is the maximum time in milli-seconds that the
      * invocation should take to complete
-     * 
+     *
      * @param message the object that is the payload of the event
      * @param timeout how long to block in milliseconds waiting for a result
      * @return the result message if any of the invocation
@@ -343,7 +337,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * any time to check that the invocation has completed. A timeout is associated
      * with the invocation, which is the maximum time in milli-seconds that the
      * invocation should take to complete
-     * 
+     *
      * @param message the MuleMessage of the event
      * @param timeout how long to block in milliseconds waiting for a result
      * @return the result message if any of the invocation
@@ -376,7 +370,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * any time to check that the invocation has completed. A timeout is associated
      * with the invocation, which is the maximum time in milli-seconds that the
      * invocation should take to complete
-     * 
+     *
      * @param message the MuleMessage of the event
      * @param endpointUri the endpointUri to dispatch to
      * @param timeout how long to block in milliseconds waiting for a result
@@ -411,7 +405,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * any time to check that the invocation has completed. A timeout is associated
      * with the invocation, which is the maximum time in milli-seconds that the
      * invocation should take to complete
-     * 
+     *
      * @param message the MuleMessage of the event
      * @param endpointName The endpoint name to disptch the event through. This will
      *            be looked up first on the service configuration and then on the
@@ -444,7 +438,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * Depending on the session state this methods either Passes an event
      * synchronously to the next available Mule component in the pool or via the
      * endpoint configured for the event
-     * 
+     *
      * @param message the event message payload to send
      * @param endpointName The endpoint name to disptch the event through. This will
      *            be looked up first on the service configuration and then on the
@@ -461,7 +455,7 @@ public class DefaultMuleEventContext implements MuleEventContext
     /**
      * This will dispatch an event asynchronously via the configured outbound
      * endpoint on the service for this session
-     * 
+     *
      * @param message payload to dispatch
      * @throws org.mule.api.MuleException if there is no outbound endpoint configured
      *             on the service or the events fails during dispatch
@@ -474,14 +468,14 @@ public class DefaultMuleEventContext implements MuleEventContext
     /**
      * This will dispatch an event asynchronously via the configured outbound
      * endpoint on the service for this session
-     * 
+     *
      * @param message the message to send
      * @throws org.mule.api.MuleException if there is no outbound endpoint configured
      *             on the service or the events fails during dispatch
      */
     public void dispatchEvent(MuleMessage message) throws MuleException
     {
-        FlowConstruct flowConstruct = session.getFlowConstruct();
+        FlowConstruct flowConstruct = event.getFlowConstruct();
         if (flowConstruct == null)
         {
             throw new IllegalStateException(CoreMessages.objectIsNull("flowConstruct").getMessage());
@@ -507,7 +501,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * Depending on the session state this methods either Passes an event
      * asynchronously to the next available Mule component in the pool or via the
      * endpointUri configured for the event
-     * 
+     *
      * @param message the event message payload to send
      * @param endpointUri the endpointUri to dispatc the event to first on the
      *            service configuration and then on the mule manager configuration
@@ -528,17 +522,14 @@ public class DefaultMuleEventContext implements MuleEventContext
 
         builder.setExchangePattern(MessageExchangePattern.ONE_WAY);
 
-        OutboundEndpoint endpoint = getMuleContext().getRegistry()
-            .lookupEndpointFactory()
-            .getOutboundEndpoint(builder);
-
+        OutboundEndpoint endpoint = getMuleContext().getEndpointFactory().getOutboundEndpoint(builder);
         clientInterface.process(endpoint, message);    }
 
     /**
      * Depending on the session state this methods either Passes an event
      * asynchronously to the next available Mule component in the pool or via the
      * endpoint configured for the event
-     * 
+     *
      * @param message the event message payload to send
      * @param endpointName The endpoint name to disptch the event through. This will
      *            be looked up first on the service configuration and then on the
@@ -557,10 +548,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
         builder.setExchangePattern(MessageExchangePattern.ONE_WAY);
 
-        OutboundEndpoint endpoint = getMuleContext().getRegistry()
-            .lookupEndpointFactory()
-            .getOutboundEndpoint(builder);
-
+        OutboundEndpoint endpoint = getMuleContext().getEndpointFactory().getOutboundEndpoint(builder);
         clientInterface.process(endpoint, message);
     }
 
@@ -568,7 +556,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * Depending on the session state this methods either Passes an event
      * asynchronously to the next available Mule component in the pool or via the
      * endpoint configured for the event
-     * 
+     *
      * @param message the event message payload to send
      * @param endpoint The endpoint name to disptch the event through.
      * @throws org.mule.api.MuleException if the event fails to be processed by the
@@ -581,7 +569,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
     /**
      * Requests a synchronous receive of an event on the service
-     * 
+     *
      * @param endpoint the endpoint identifing the endpointUri on ewhich the event
      *            will be received
      * @param timeout time in milliseconds before the request timesout
@@ -595,7 +583,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
     /**
      * Requests a synchronous receive of an event on the service
-     * 
+     *
      * @param endpointName the endpoint identifing the endpointUri on ewhich the
      *            event will be received
      * @param timeout time in milliseconds before the request timesout
@@ -609,7 +597,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
     /**
      * Requests a synchronous receive of an event on the service
-     * 
+     *
      * @param endpointUri the endpointUri on which the event will be received
      * @param timeout time in milliseconds before the request timesout
      * @return The requested event or null if the request times out
@@ -639,7 +627,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * <code>RequestContext.getEventContext</code> to obtain the MuleEventContext for
      * the current thread. The user can programmatically control how events are
      * dispatched.
-     * 
+     *
      * @return Returns true is the user has set stopFurtherProcessing.
      * @see org.mule.api.MuleEventContext
      * @see org.mule.api.lifecycle.Callable
@@ -658,7 +646,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * <code>RequestContext.getEventContext</code> to obtain the MuleEventContext for
      * the current thread. The user can programmatically control how events are
      * dispached.
-     * 
+     *
      * @param stopFurtherProcessing the value to set.
      */
     public void setStopFurtherProcessing(boolean stopFurtherProcessing)
@@ -669,7 +657,7 @@ public class DefaultMuleEventContext implements MuleEventContext
     /**
      * An outputstream the can optionally be used write response data to an incoming
      * message.
-     * 
+     *
      * @return an output stream if one has been made available by the message
      *         receiver that received the message
      */
@@ -678,20 +666,20 @@ public class DefaultMuleEventContext implements MuleEventContext
         return event.getOutputStream();
     }
 
-    public EndpointURI getEndpointURI()
+    public URI getEndpointURI()
     {
-        return event.getEndpoint().getEndpointURI();
+        return event.getMessageSourceURI();
     }
-    
+
     public MessageExchangePattern getExchangePattern()
     {
-        return event.getEndpoint().getExchangePattern();
+        return event.getExchangePattern();
     }
 
     /**
      * Returns the transaction for the current event or null if there is no
      * transaction in progresss
-     * 
+     *
      * @return the transaction for the current event or null if there is no
      *         transaction in progresss
      */
@@ -702,7 +690,7 @@ public class DefaultMuleEventContext implements MuleEventContext
 
     /**
      * Get the timeout value associated with the event
-     * 
+     *
      * @return the timeout for the event
      */
     public int getTimeout()
@@ -715,7 +703,7 @@ public class DefaultMuleEventContext implements MuleEventContext
      * Information with the message, this method should be overriden to expose the
      * transport encoding, otherwise the default encoding in the Mule configuration
      * will be used
-     * 
+     *
      * @return the encoding for this message. This method must never return null
      */
     public String getEncoding()
