@@ -1,5 +1,5 @@
 /*
- * $Id: ExceptionListenerTestCase.java 20618 2010-12-10 16:23:35Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,36 +13,46 @@ package org.mule;
 import org.mule.api.endpoint.OutboundEndpoint;
 import org.mule.api.processor.MessageProcessor;
 import org.mule.exception.AbstractExceptionListener;
-import org.mule.exception.DefaultServiceExceptionStrategy;
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.exception.DefaultMessagingExceptionStrategy;
+import org.mule.tck.junit4.AbstractMuleTestCase;
 
 import java.util.ArrayList;
 import java.util.List;
 
+import org.junit.Test;
+import org.mockito.Mockito;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 public class ExceptionListenerTestCase extends AbstractMuleTestCase
 {
+
+    @Test
     public void testAddGoodEndpoint() throws Exception
     {
-        AbstractExceptionListener router = new DefaultServiceExceptionStrategy(muleContext);
-        OutboundEndpoint endpoint = getTestOutboundEndpoint("test");
+        AbstractExceptionListener router = new DefaultMessagingExceptionStrategy(null);
+        OutboundEndpoint endpoint = Mockito.mock(OutboundEndpoint.class);
         router.addEndpoint(endpoint);
         assertNotNull(router.getMessageProcessors());
         assertTrue(router.getMessageProcessors().contains(endpoint));
     }
 
+    @Test
     public void testSetGoodEndpoints() throws Exception
     {
         List<MessageProcessor> list = new ArrayList<MessageProcessor>();
-        list.add(getTestOutboundEndpoint("test"));
-        list.add(getTestOutboundEndpoint("test"));
-        
-        AbstractExceptionListener router = new DefaultServiceExceptionStrategy(muleContext);
+        list.add(Mockito.mock(OutboundEndpoint.class));
+        list.add(Mockito.mock(OutboundEndpoint.class));
+
+        AbstractExceptionListener router = new DefaultMessagingExceptionStrategy(null);
         assertNotNull(router.getMessageProcessors());
         assertEquals(0, router.getMessageProcessors().size());
-        
-        router.addEndpoint(getTestOutboundEndpoint("test"));
+
+        router.addEndpoint(Mockito.mock(OutboundEndpoint.class));
         assertEquals(1, router.getMessageProcessors().size());
-        
+
         router.setMessageProcessors(list);
         assertNotNull(router.getMessageProcessors());
         assertEquals(2, router.getMessageProcessors().size());
