@@ -1,5 +1,5 @@
 /*
- * $Id: MuleServer.java 21876 2011-05-11 11:06:10Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -28,6 +28,7 @@ import org.mule.context.DefaultMuleContextBuilder;
 import org.mule.context.DefaultMuleContextFactory;
 import org.mule.util.ClassUtils;
 import org.mule.util.IOUtils;
+import org.mule.util.JdkVersionUtils;
 import org.mule.util.MuleUrlStreamHandlerFactory;
 import org.mule.util.PropertiesUtils;
 import org.mule.util.StringMessageUtils;
@@ -90,7 +91,7 @@ public class MuleServer implements Runnable
     private static final Log logger = LogFactory.getLog(MuleServer.class);
 
     public static final String DEFAULT_CONFIGURATION = "mule-config.xml";
-    
+
     public static final String DEFAULT_APP_CONFIGURATION = "mule-app.properties";
 
     /**
@@ -99,7 +100,7 @@ public class MuleServer implements Runnable
     private String configurationResources = null;
 
     private String appConfigurationResource = null;
-    
+
     /**
      * A FQN of the #configBuilder class, required in case MuleServer is
      * reinitialised.
@@ -135,7 +136,6 @@ public class MuleServer implements Runnable
     {
         MuleServer server = new MuleServer(args);
         server.start(false, true);
-
     }
 
     public MuleServer()
@@ -161,6 +161,18 @@ public class MuleServer implements Runnable
 
     protected void init(String[] args) throws IllegalArgumentException
     {
+    	// validate the JDK version/vendor
+    	try
+    	{
+    		JdkVersionUtils.validateJdk();
+    	}
+    	catch (RuntimeException e)
+    	{
+    		System.out.println(CoreMessages.invalidJdk(SystemUtils.JAVA_VERSION, SystemUtils.JAVA_VENDOR, 
+    				JdkVersionUtils.getSupportedJdks()));
+            System.exit(-1);
+    	}
+    	
         Map<String, Object> commandlineOptions;
 
         try
@@ -198,7 +210,7 @@ public class MuleServer implements Runnable
         {
             setConfigurationResources(config);
         }
-        
+
         String appconfig = (String) commandlineOptions.get("appconfig");
         this.appConfigurationResource = appconfig;
 
@@ -355,8 +367,8 @@ public class MuleServer implements Runnable
         if (!cfgBuilder.isConfigured())
         {
             List<ConfigurationBuilder> configBuilders = new ArrayList<ConfigurationBuilder>(3);
-            
-            // need to add the annotations config builder before Spring so we can use Mule 
+
+            // need to add the annotations config builder before Spring so we can use Mule
             // annotations in Spring
             addAnnotationsConfigBuilder(configBuilders);
             addStartupPropertiesConfigBuilder(configBuilders);
@@ -386,14 +398,14 @@ public class MuleServer implements Runnable
     }
 
     /**
-     * If the annotations module is on the classpath, add the annotations config builder to the 
+     * If the annotations module is on the classpath, add the annotations config builder to the
      * list. This will enable annotations config for this instance.
      */
     protected void addAnnotationsConfigBuilder(List<ConfigurationBuilder> builders) throws Exception
     {
         if (ClassUtils.isClassOnPath(CLASSNAME_ANNOTATIONS_CONFIG_BUILDER, getClass()))
         {
-            Object configBuilder = ClassUtils.instanciateClass(CLASSNAME_ANNOTATIONS_CONFIG_BUILDER, 
+            Object configBuilder = ClassUtils.instanciateClass(CLASSNAME_ANNOTATIONS_CONFIG_BUILDER,
                 ClassUtils.NO_ARGS, getClass());
             builders.add((ConfigurationBuilder) configBuilder);
         }
@@ -406,7 +418,7 @@ public class MuleServer implements Runnable
         {
             startupProperties = PropertiesUtils.loadProperties(getStartupPropertiesFile(), getClass());
         }
-       
+
         builders.add(new SimpleConfigurationBuilder(startupProperties));
     }
 
@@ -421,7 +433,7 @@ public class MuleServer implements Runnable
         {
             appPropertiesFile = this.appConfigurationResource;
         }
-        
+
         return new PropertiesMuleConfigurationFactory(appPropertiesFile).createConfiguration();
     }
 
@@ -556,7 +568,7 @@ public class MuleServer implements Runnable
         {
             super();
         }
-        
+
         @Override
         public void run()
         {
