@@ -1,5 +1,5 @@
 /*
- * $Id: MuleContext.java 24041 2012-03-14 01:40:28Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -33,6 +33,8 @@ import org.mule.api.store.ListableObjectStore;
 import org.mule.context.notification.NotificationException;
 import org.mule.context.notification.ServerNotificationManager;
 import org.mule.management.stats.AllStatistics;
+import org.mule.management.stats.ProcessingTimeWatcher;
+import org.mule.util.lock.LockFactory;
 import org.mule.util.queue.QueueManager;
 
 import java.io.Serializable;
@@ -300,5 +302,19 @@ public interface MuleContext extends Lifecycle
      * @return 
      */
     ExpressionLanguage getExpressionLanguage();
+
+    /**
+     * Factory for creating locks for synchronizing mule components.
+     *
+     * Synchronization must be done using LockFactory locks in order for mule components to work in single servers as in a cluster
+     *
+     * @return a factory for creating locks
+     */
+    LockFactory getLockFactory();
+
+    /**
+     * @return {@link {ProcessingTimeWatcher} used to compute processing time of finalized events
+     */
+    ProcessingTimeWatcher getProcessorTimeWatcher();
 }
 
