@@ -1,5 +1,5 @@
 /*
- * $Id: MuleEvent.java 23806 2012-02-02 16:57:05Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -309,4 +309,17 @@ public interface MuleEvent extends Serializable
 
     void clearSessionVariables();
 
+    /**
+     * Indicates if notifications should be fired when processing this message.
+     *
+     * @return true if notifications are enabled, false otherwise
+     */
+    boolean isNotificationsEnabled();
+
+    /**
+     * Enables the firing of notifications when processing the message.
+     *
+     * @param enabled
+     */
+    void setEnableNotifications(boolean enabled);
 }
