@@ -1,5 +1,5 @@
 /*
- * $Id: TlsPropertiesSocketTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,11 +12,16 @@ package org.mule.api;
 
 import org.mule.api.security.tls.TlsConfiguration;
 import org.mule.api.security.tls.TlsPropertiesSocketFactory;
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleTestCase;
+
+import org.junit.Test;
+
+import static org.junit.Assert.assertTrue;
 
 public class TlsPropertiesSocketTestCase extends AbstractMuleTestCase
 {
 
+    @Test
     public void testSimpleSocket() throws Exception
     {
         TlsConfiguration configuration = new TlsConfiguration(TlsConfiguration.DEFAULT_KEYSTORE);
