@@ -1,5 +1,5 @@
 /*
- * $Id: InboundEndpoint.java 20433 2010-12-02 04:48:11Z mike.schilling $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -15,8 +15,10 @@ import org.mule.api.lifecycle.Startable;
 import org.mule.api.lifecycle.Stoppable;
 import org.mule.api.source.MessageSource;
 import org.mule.api.transport.MessageRequesting;
+import org.mule.processor.AbstractRedeliveryPolicy;
 
-public interface InboundEndpoint extends ImmutableEndpoint, MessageRequesting, MessageSource, FlowConstructAware, Startable, Stoppable
+public interface InboundEndpoint
+    extends ImmutableEndpoint, MessageRequesting, MessageSource, FlowConstructAware, Startable, Stoppable
 {
-    // empty
+    AbstractRedeliveryPolicy createDefaultRedeliveryPolicy(int maxRedelivery);
 }
