@@ -1,5 +1,5 @@
 /*
- * $Id: Authentication.java 21016 2011-01-13 22:12:53Z dandiep $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -29,9 +29,11 @@ public interface Authentication extends Serializable
 
     Object getPrincipal();
 
-    Map getProperties();
+    Map<String, Object> getProperties();
+
+    void setProperties(Map<String, Object> properties);
 
-    void setProperties(Map properties);
-    
     MuleEvent getEvent();
+
+    void setEvent(MuleEvent event);
 }
