@@ -1,5 +1,5 @@
 /*
- * $Id: UnsupportedAuthenticationSchemeException.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,7 +11,6 @@
 package org.mule.api.security;
 
 import org.mule.api.MuleEvent;
-import org.mule.api.MuleMessage;
 import org.mule.config.i18n.Message;
 
 /**
@@ -26,29 +25,11 @@ public class UnsupportedAuthenticationSchemeException extends SecurityException
      */
     private static final long serialVersionUID = 3281021140543598681L;
 
-    /**
-     * @deprecated use UnsupportedAuthenticationSchemeException(Message, MuleEvent)
-     */
-    @Deprecated
-    public UnsupportedAuthenticationSchemeException(Message message, MuleMessage muleMessage)
-    {
-        super(message, muleMessage);
-    }
-
     public UnsupportedAuthenticationSchemeException(Message message, MuleEvent event)
     {
         super(message, event);
     }
 
-    /**
-     * @deprecated use UnsupportedAuthenticationSchemeException(Message, MuleEvent, Throwable)
-     */
-    @Deprecated
-    public UnsupportedAuthenticationSchemeException(Message message, MuleMessage muleMessage, Throwable cause)
-    {
-        super(message, muleMessage, cause);
-    }
-
     public UnsupportedAuthenticationSchemeException(Message message, MuleEvent event, Throwable cause)
     {
         super(message, event, cause);
