@@ -1,5 +1,5 @@
 /*
- * $Id: SpringRegistryTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -19,6 +19,6 @@ public class SpringRegistryTestCase extends AbstractRegistryTestCase
     @Override
     public Registry getRegistry()
     {
-        return new SpringRegistry(new StaticApplicationContext(), muleContext);
+        return new SpringRegistry(new StaticApplicationContext(), null);
     }
 }
