@@ -1,5 +1,5 @@
 /*
- * $Id: MessageProcessorChainFactoryBean.java 21929 2011-05-17 14:26:50Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,7 +12,7 @@ package org.mule.config.spring.factories;
 
 import org.mule.api.processor.MessageProcessor;
 import org.mule.api.processor.MessageProcessorBuilder;
-import org.mule.api.processor.MessageProcessors;
+import org.mule.api.processor.MessageProcessorChainBuilder;
 import org.mule.processor.chain.DefaultMessageProcessorChainBuilder;
 
 import java.util.List;
@@ -37,8 +37,7 @@ public class MessageProcessorChainFactoryBean implements FactoryBean
 
     public Object getObject() throws Exception
     {
-        DefaultMessageProcessorChainBuilder builder = new DefaultMessageProcessorChainBuilder();
-        builder.setName("processor chain '"+name+"'");
+        MessageProcessorChainBuilder builder = getBuilderInstance();
         for (Object processor : processors)
         {
             if (processor instanceof MessageProcessor)
@@ -55,7 +54,14 @@ public class MessageProcessorChainFactoryBean implements FactoryBean
                     "MessageProcessorBuilder should only have MessageProcessor's or MessageProcessorBuilder's configured");
             }
         }
-        return MessageProcessors.lifecyleAwareMessageProcessorWrapper(builder.build());
+        return builder.build();
+    }
+
+    protected MessageProcessorChainBuilder getBuilderInstance()
+    {
+        DefaultMessageProcessorChainBuilder builder = new DefaultMessageProcessorChainBuilder();
+        builder.setName("processor chain '"+name+"'");
+        return builder;
     }
 
     public boolean isSingleton()
