@@ -1,5 +1,5 @@
 /*
- * $Id: MuleTransactionManagerFactoryBean.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -18,29 +18,36 @@ import org.springframework.beans.factory.BeanCreationException;
 import org.springframework.beans.factory.config.AbstractFactoryBean;
 
 /**
- * Creates a reference to the TransactionManager configured on the MuleContext.  This is useful when you need to inject
- * the TransactionManager into other objects such as XA data Sources.
- *
- * In order to use this factory bean you must have a transaction manager configured in the context i.e.
- * <code><jbossts:transaction-manager/></code>
+ * <p>
+ * Creates a reference to the TransactionManager configured on the MuleContext. This
+ * is useful when you need to inject the TransactionManager into other objects such
+ * as XA data Sources.
+ * </p>
+ * <p>
+ * In order to use this factory bean you must have a transaction manager configured
+ * in the context i.e. <code><jbossts:transaction-manager/></code>
+ * </p>
  */
-public class MuleTransactionManagerFactoryBean extends AbstractFactoryBean implements MuleContextAware
+public class MuleTransactionManagerFactoryBean extends AbstractFactoryBean<TransactionManager> implements MuleContextAware
 {
     private MuleContext muleContext;
 
+    @Override
     public void setMuleContext(MuleContext context)
     {
         muleContext = context;
     }
 
-    public Class getObjectType()
+    @Override
+    public Class<?> getObjectType()
     {
         return TransactionManager.class;
     }
 
-    protected Object createInstance() throws Exception
+    @Override
+    protected TransactionManager createInstance() throws Exception
     {
-        if(muleContext.getTransactionManager()==null)
+        if (muleContext.getTransactionManager() == null)
         {
             throw new BeanCreationException("you must have a transaction manager configured inside the context when using " + getClass().getName());
         }
