@@ -1,5 +1,5 @@
 /*
- * $Id: KeyStoreDefinitionParser.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,14 +12,18 @@ package org.mule.config.spring.parsers.specific.tls;
 
 import org.mule.config.spring.parsers.generic.ParentDefinitionParser;
 import org.mule.config.spring.parsers.AbstractMuleBeanDefinitionParser;
+import org.mule.config.spring.parsers.processors.CheckExclusiveAttributes;
 
 public class KeyStoreDefinitionParser extends ParentDefinitionParser
 {
 
     public KeyStoreDefinitionParser()
     {
+        registerPreProcessor(new CheckExclusiveAttributes(new String[][]{
+                new String[]{AbstractMuleBeanDefinitionParser.ATTRIBUTE_CLASS}, new String[]{"type"}}));
         addAlias("path", "keyStore");
         addAlias(AbstractMuleBeanDefinitionParser.ATTRIBUTE_CLASS, "keyStoreType");
+        addAlias("type", "keyStoreType");
         addAlias("storePassword", "keyStorePassword");
         addAlias("algorithm", "keyManagerAlgorithm");
     }
