@@ -1,5 +1,5 @@
 /*
- * $Id: TrustStoreDefinitionParser.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,16 +12,20 @@ package org.mule.config.spring.parsers.specific.tls;
 
 import org.mule.config.spring.parsers.generic.ParentDefinitionParser;
 import org.mule.config.spring.parsers.AbstractMuleBeanDefinitionParser;
+import org.mule.config.spring.parsers.processors.CheckExclusiveAttributes;
 
 public class TrustStoreDefinitionParser extends ParentDefinitionParser
 {
 
     public TrustStoreDefinitionParser()
     {
+        registerPreProcessor(new CheckExclusiveAttributes(new String[][]{
+                new String[]{AbstractMuleBeanDefinitionParser.ATTRIBUTE_CLASS}, new String[]{"type"}}));
         addAlias("path", "trustStore");
         addAlias("storePassword", "trustStorePassword");
         // these used by server trust store type
         addAlias(AbstractMuleBeanDefinitionParser.ATTRIBUTE_CLASS, "trustStoreType");
+        addAlias("type", "trustStoreType");
         addAlias("algorithm", "trustManagerAlgorithm");
         addAlias("factory", "trustManagerFactory");
         addAlias("explicitOnly", "explicitTrustStoreOnly");
