@@ -1,5 +1,5 @@
 /*
- * $Id: ValidatorBuilderTestCase.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,13 +10,18 @@
 
 package org.mule.construct.builder;
 
-import org.mule.construct.Validator;
-import org.mule.exception.DefaultServiceExceptionStrategy;
-import org.mule.routing.filters.PayloadTypeFilter;
-import org.mule.tck.AbstractMuleTestCase;
+import static org.junit.Assert.assertEquals;
 
-public class ValidatorBuilderTestCase extends AbstractMuleTestCase
+import org.mule.construct.Validator;
+import org.mule.exception.DefaultMessagingExceptionStrategy;
+import org.mule.routing.filters.PayloadTypeFilter;
+import org.mule.tck.junit4.AbstractMuleContextTestCase;
+
+import org.junit.Test;
+
+public class ValidatorBuilderTestCase extends AbstractMuleContextTestCase
 {
+    @Test
     public void testConfigurationWithoutErrorExpression() throws Exception
     {
         final Validator validator = new ValidatorBuilder().name("test-validator-no-error")
@@ -25,12 +30,13 @@ public class ValidatorBuilderTestCase extends AbstractMuleTestCase
             .ackExpression("#[string:GOOD:#[message:payload]]")
             .nackExpression("#[string:BAD:#[message:payload]]")
             .outboundAddress("test://foo.out")
-            .exceptionStrategy(new DefaultServiceExceptionStrategy(muleContext))
+            .exceptionStrategy(new DefaultMessagingExceptionStrategy(muleContext))
             .build(muleContext);
 
         assertEquals("test-validator-no-error", validator.getName());
     }
 
+    @Test
     public void testFullConfiguration() throws Exception
     {
         final Validator validator = new ValidatorBuilder().name("test-validator-full")
@@ -40,7 +46,7 @@ public class ValidatorBuilderTestCase extends AbstractMuleTestCase
             .nackExpression("#[string:BAD:#[message:payload]]")
             .errorExpression("#[string:ERROR:#[message:payload]]")
             .outboundAddress("test://foo.out")
-            .exceptionStrategy(new DefaultServiceExceptionStrategy(muleContext))
+            .exceptionStrategy(new DefaultMessagingExceptionStrategy(muleContext))
             .build(muleContext);
 
         assertEquals("test-validator-full", validator.getName());
