@@ -1,5 +1,5 @@
 /*
- * $Id: OptimisedNotificationHandler.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -21,23 +21,24 @@ public class OptimisedNotificationHandler implements ServerNotificationHandler
 {
 
     private ServerNotificationHandler delegate;
-    private Class type;
+    private Class<? extends ServerNotification> type;
     private boolean dynamic = false;
-    private boolean enabled = false;
+    private volatile Boolean enabled = null;
 
-    public OptimisedNotificationHandler(ServerNotificationHandler delegate, Class type)
+    public OptimisedNotificationHandler(ServerNotificationHandler delegate, Class<? extends ServerNotification> type)
     {
         this.delegate = delegate;
         this.type = type;
         dynamic = delegate.isNotificationDynamic();
-        enabled = delegate.isNotificationEnabled(type);
     }
 
+    @Override
     public boolean isNotificationDynamic()
     {
         return dynamic;
     }
 
+    @Override
     public boolean isListenerRegistered(ServerNotificationListener listener)
     {
         return delegate.isListenerRegistered(listener);
@@ -52,10 +53,16 @@ public class OptimisedNotificationHandler implements ServerNotificationHandler
      * @param notfnClass Either the notification class being generated or some superclass
      * @return false if there is no need to dispatch the notification
      */
-    public boolean isNotificationEnabled(Class notfnClass)
+    @Override
+    public boolean isNotificationEnabled(Class<? extends ServerNotification> notfnClass)
     {
         if ((!dynamic) && type.isAssignableFrom(notfnClass))
         {
+            if (enabled == null)
+            {
+                enabled = delegate.isNotificationEnabled(notfnClass);
+            }
+
             return enabled;
         }
         else
@@ -64,6 +71,7 @@ public class OptimisedNotificationHandler implements ServerNotificationHandler
         }
     }
 
+    @Override
     public void fireNotification(ServerNotification notification)
     {
         if (isNotificationEnabled(notification.getClass()))
@@ -71,5 +79,4 @@ public class OptimisedNotificationHandler implements ServerNotificationHandler
             delegate.fireNotification(notification);
         }
     }
-
 }
