@@ -1,5 +1,5 @@
 /*
- * $Id: EventVariableResolverFactory.java 24112 2012-03-21 17:15:46Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -16,7 +16,7 @@ import org.mule.api.construct.FlowConstruct;
 
 import org.mvel2.ParserContext;
 
-class EventVariableResolverFactory extends MessageVariableResolverFactory
+public class EventVariableResolverFactory extends MessageVariableResolverFactory
 {
 
     private static final long serialVersionUID = -6819292692339684915L;
@@ -24,7 +24,7 @@ class EventVariableResolverFactory extends MessageVariableResolverFactory
     public EventVariableResolverFactory(ParserContext parserContext, MuleContext muleContext, MuleEvent event)
     {
         super(parserContext, muleContext, event.getMessage());
-        addVariable("flow", new FlowContext(event.getFlowConstruct()));
+        addFinalVariable("flow", new FlowContext(event.getFlowConstruct()));
     }
 
     public static class FlowContext
