@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractEndpoint.java 22870 2011-09-05 20:41:52Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,6 +13,7 @@ package org.mule.endpoint;
 import org.mule.MessageExchangePattern;
 import org.mule.api.AnnotatedObject;
 import org.mule.api.MuleContext;
+import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.construct.FlowConstruct;
 import org.mule.api.endpoint.EndpointMessageProcessorChainFactory;
@@ -429,6 +430,10 @@ public abstract class AbstractEndpoint implements ImmutableEndpoint, Disposable,
      */
     public int getResponseTimeout()
     {
+        if (muleContext.getConfiguration().isDisableTimeouts())
+        {
+            return MuleEvent.TIMEOUT_WAIT_FOREVER;
+        }
         return responseTimeout;
     }
 
