@@ -1,5 +1,5 @@
 /*
- * $Id: DynamicOutboundEndpointTestCase.java 22779 2011-08-29 07:24:54Z pablo.kraan $
+ * $Id$
  * -------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,11 +10,24 @@
 
 package org.mule.endpoint.outbound;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNotSame;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 import org.mule.MessageExchangePattern;
+import org.mule.VoidMuleEvent;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
 import org.mule.api.config.MuleProperties;
+import org.mule.api.endpoint.EndpointBuilder;
 import org.mule.api.endpoint.OutboundEndpoint;
 import org.mule.api.registry.ServiceException;
 import org.mule.api.registry.ServiceType;
@@ -43,13 +56,6 @@ import java.util.concurrent.TimeUnit;
 import org.junit.Before;
 import org.junit.Test;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-
 /**
  * Tests flow of messages from {@link org.mule.endpoint.DynamicOutboundEndpoint#process(org.mule.api.MuleEvent)} down to
  * {@link org.mule.transport.AbstractMessageDispatcher} and the chain of MessageProcessor's that
@@ -98,7 +104,7 @@ public class DynamicOutboundEndpointTestCase extends AbstractMessageProcessorTes
         MuleEvent result = endpoint.process(testOutboundEvent);
 
         assertEventDispatched();
-        assertNull(result);
+        assertSame(VoidMuleEvent.getInstance(), result);
         assertMessageSentEqual(MyMessageDispatcherFactory.dispatcher.sensedDispatchEvent);
     }
 
@@ -154,7 +160,7 @@ public class DynamicOutboundEndpointTestCase extends AbstractMessageProcessorTes
     @Test
     public void testSendNotification() throws Exception
     {
-        TestEndpointMessageNotificationListener listener = new TestEndpointMessageNotificationListener();
+        TestEndpointMessageNotificationListener listener = new TestEndpointMessageNotificationListener(2);
         muleContext.registerListener(listener);
 
         OutboundEndpoint endpoint = createOutboundEndpoint(null, null, null, null, MessageExchangePattern.REQUEST_RESPONSE, null);
@@ -164,15 +170,21 @@ public class DynamicOutboundEndpointTestCase extends AbstractMessageProcessorTes
 
         assertEventSent();
         assertTrue(listener.latch.await(RECEIVE_TIMEOUT, TimeUnit.MILLISECONDS));
-        assertEquals(EndpointMessageNotification.MESSAGE_SENT, listener.messageNotification.getAction());
-        assertTrue(listener.messageNotification.getSource() instanceof MuleMessage);
-        assertEquals(outboundEvent.getMessage().getPayload(), listener.messageNotification.getSource().getPayload());
+        assertEquals(2, listener.messageNotificationList.size());
+        assertEquals(EndpointMessageNotification.MESSAGE_SEND_BEGIN, listener.messageNotificationList.get(0).getAction());
+        assertEquals(EndpointMessageNotification.MESSAGE_SEND_END, listener.messageNotificationList.get(1).getAction());
+        assertTrue(listener.messageNotificationList.get(0).getSource() instanceof MuleMessage);
+        assertTrue(listener.messageNotificationList.get(1).getSource() instanceof MuleMessage);
+        assertEquals(outboundEvent.getMessage().getPayload(),
+            listener.messageNotificationList.get(0).getSource().getPayload());
+        assertEquals(RESPONSE_MESSAGE,
+            listener.messageNotificationList.get(1).getSource().getPayload());
     }
 
     @Test
     public void testDispatchNotification() throws Exception
     {
-        TestEndpointMessageNotificationListener listener = new TestEndpointMessageNotificationListener();
+        TestEndpointMessageNotificationListener listener = new TestEndpointMessageNotificationListener(2);
         muleContext.registerListener(listener);
 
         OutboundEndpoint endpoint = createOutboundEndpoint(null, null, null, null, MessageExchangePattern.ONE_WAY, null);
@@ -182,9 +194,15 @@ public class DynamicOutboundEndpointTestCase extends AbstractMessageProcessorTes
 
         assertEventDispatched();
         assertTrue(listener.latch.await(RECEIVE_TIMEOUT, TimeUnit.MILLISECONDS));
-        assertEquals(EndpointMessageNotification.MESSAGE_DISPATCHED, listener.messageNotification.getAction());
-        assertTrue(listener.messageNotification.getSource() instanceof MuleMessage);
-        assertEquals(outboundEvent.getMessage().getPayload(), listener.messageNotification.getSource().getPayload());
+        assertEquals(2, listener.messageNotificationList.size());
+        assertEquals(EndpointMessageNotification.MESSAGE_DISPATCH_BEGIN, listener.messageNotificationList.get(0).getAction());
+        assertEquals(EndpointMessageNotification.MESSAGE_DISPATCH_END, listener.messageNotificationList.get(1).getAction());
+        assertTrue(listener.messageNotificationList.get(0).getSource() instanceof MuleMessage);
+        assertTrue(listener.messageNotificationList.get(1).getSource() instanceof MuleMessage);
+        assertEquals(outboundEvent.getMessage().getPayload(),
+            listener.messageNotificationList.get(0).getSource().getPayload());
+        assertEquals(outboundEvent.getMessage().getPayload(),
+            listener.messageNotificationList.get(1).getSource().getPayload());
     }
 
     @Test
@@ -237,6 +255,28 @@ public class DynamicOutboundEndpointTestCase extends AbstractMessageProcessorTes
         // TODO
     }
 
+    @Test
+    public void cachesResolvedStaticEndpoints() throws Exception
+    {
+        OutboundEndpoint prototypeEndpoint = mock(OutboundEndpoint.class);
+        when(prototypeEndpoint.getMuleContext()).thenReturn(muleContext);
+
+        EndpointBuilder staticEndpointBuilder = mock(EndpointBuilder.class);
+        when(staticEndpointBuilder.buildOutboundEndpoint()).thenReturn(prototypeEndpoint);
+
+        EndpointBuilder endpointBuilder = mock(EndpointBuilder.class);
+        when(endpointBuilder.buildOutboundEndpoint()).thenReturn(prototypeEndpoint);
+        when(endpointBuilder.clone()).thenReturn(staticEndpointBuilder);
+
+        DynamicOutboundEndpoint dynamicOutboundEndpoint = new DynamicOutboundEndpoint(endpointBuilder, "test://localhost:#[header:port]");
+
+        testOutboundEvent = createTestOutboundEvent();
+        dynamicOutboundEndpoint.process(testOutboundEvent);
+        dynamicOutboundEndpoint.process(testOutboundEvent);
+
+        verify(endpointBuilder, times(1)).buildOutboundEndpoint();
+    }
+
     protected void assertMessageSentEqual(MuleEvent event) throws MuleException
     {
         assertEquals(TEST_MESSAGE, event.getMessageAsString());
@@ -260,11 +300,13 @@ public class DynamicOutboundEndpointTestCase extends AbstractMessageProcessorTes
         Prober prober = new PollingProber();
         prober.check(new Probe()
         {
+            @Override
             public boolean isSatisfied()
             {
                 return MyMessageDispatcherFactory.dispatcher != null && MyMessageDispatcherFactory.dispatcher.dispatchedEvent;
             }
 
+            @Override
             public String describeFailure()
             {
                 return "Expected dispatcher was not called";
@@ -281,11 +323,13 @@ public class DynamicOutboundEndpointTestCase extends AbstractMessageProcessorTes
         Prober prober = new PollingProber();
         prober.check(new Probe()
         {
+            @Override
             public boolean isSatisfied()
             {
                 return MyMessageDispatcherFactory.dispatcher != null && MyMessageDispatcherFactory.dispatcher.sentEvent;
             }
 
+            @Override
             public String describeFailure()
             {
                 return "Expected dispatcher was not called";
