@@ -1,5 +1,5 @@
 /*
- * $Id: ExceptionHandler.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -17,19 +17,17 @@ import java.util.Iterator;
  */
 public interface ExceptionHandler
 {
-
     public ErrorManager getErrorManager();
 
     public void setErrorManager(ErrorManager errorManager);
 
     public void onException(ErrorMessage message) throws HandlerException;
 
-    public void registerException(Class exceptionClass);
+    public void registerException(Class<? extends Throwable> exceptionClass);
 
-    public void unRegisterException(Class exceptionClass);
+    public void unRegisterException(Class<? extends Throwable> exceptionClass);
 
-    public Iterator getRegisteredClasses();
-
-    public boolean isRegisteredFor(Class exceptionClass);
+    public Iterator<Class<? extends Throwable>> getRegisteredClasses();
 
+    public boolean isRegisteredFor(Class<? extends Throwable> exceptionClass);
 }
