@@ -1,5 +1,5 @@
 /*
- * $Id: VMLoanBrokerSynchronousFunctionalTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -14,6 +14,10 @@ import org.mule.api.service.Service;
 import org.mule.example.loanbroker.tests.AbstractLoanBrokerTestCase;
 import org.mule.model.seda.SedaModel;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 
 public class VMLoanBrokerSynchronousFunctionalTestCase extends AbstractLoanBrokerTestCase
 {
@@ -29,6 +33,7 @@ public class VMLoanBrokerSynchronousFunctionalTestCase extends AbstractLoanBroke
         return 1000;
     }
 
+    @Test
     public void testBasicParsing()
     {
         Object objModel = muleContext.getRegistry().lookupModel("loan-broker");
@@ -41,10 +46,9 @@ public class VMLoanBrokerSynchronousFunctionalTestCase extends AbstractLoanBroke
         assertComponent(model, "TheBankGateway");
     }
 
-    protected void assertComponent(SedaModel model, String name)
+    protected void assertComponent(SedaModel model, String serviceName)
     {
-        Service service = muleContext.getRegistry().lookupService(name);
-        assertNotNull(name + " missing", service);
+        Service service = muleContext.getRegistry().lookupService(serviceName);
+        assertNotNull(serviceName + " missing", service);
     }
-
 }
