@@ -1,5 +1,5 @@
 /*
- * $Id: BankQuotesResponseAggregator.java 22506 2011-07-21 16:30:40Z stephen.fenech $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -25,9 +25,9 @@ import org.mule.routing.correlation.EventCorrelatorCallback;
 public class BankQuotesResponseAggregator extends AbstractAggregator
 {
     @Override
-    protected EventCorrelatorCallback getCorrelatorCallback(MuleContext muleContext)
+    protected EventCorrelatorCallback getCorrelatorCallback(MuleContext context)
     {
-        return new CollectionCorrelatorCallback(muleContext,persistentStores,storePrefix)
+        return new CollectionCorrelatorCallback(context,persistentStores,storePrefix)
         {
             @Override
             public MuleEvent aggregateEvents(EventGroup events) throws AggregationException
