@@ -1,5 +1,5 @@
 /*
- * $Id: ComponentMessageNotificationMixin.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,12 +10,20 @@
 
 package org.mule.example.notifications;
 
+import org.mule.api.component.Component;
+import org.mule.api.construct.FlowConstruct;
+
 import org.codehaus.jackson.annotate.JsonIgnore;
 
 public interface ComponentMessageNotificationMixin
 {
     @JsonIgnore
     Object getSource();
+
+    @JsonIgnore
+    Component getComponent();
+
+    @JsonIgnore
+    FlowConstruct getFlowConstruct();
+
 }
-
-
