@@ -1,5 +1,5 @@
 /*
- * $Id: VariableExpressionEvaluator.java 20473 2010-12-06 18:30:34Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -38,11 +38,4 @@ public class VariableExpressionEvaluator implements ExpressionEvaluator
         return NAME;
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public void setName(String name)
-    {
-        throw new UnsupportedOperationException();
-    }
 }
