@@ -1,5 +1,5 @@
 /*
- * $Id: TransformerChainMule2131TestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,9 +10,17 @@
 
 package org.mule.issues;
 
+import org.junit.Test;
+
 public class TransformerChainMule2131TestCase extends TransformerChainMule2063TestCase
 {
 
+    public TransformerChainMule2131TestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
+    }
+
+    @Test
     public void testOutputTransformers() throws Exception
     {
         doTest("test3", TEST3_OUT);
