@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractLifecycleManager.java 21272 2011-02-14 22:08:21Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -187,6 +187,10 @@ public abstract class AbstractLifecycleManager<O> implements LifecycleManager
         {
             completedPhases.remove(Startable.PHASE_NAME);
         }
+        else  if (currentPhase.equals(Startable.PHASE_NAME))
+        {
+            completedPhases.remove(Stoppable.PHASE_NAME);
+        }
         else if (currentPhase.equals(Disposable.PHASE_NAME))
         {
             completedPhases.remove(Initialisable.PHASE_NAME);
