@@ -1,5 +1,5 @@
 /*
- * $Id: JmxAgentTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,29 +11,38 @@
 package org.mule.management.agents;
 
 import org.mule.api.context.MuleContextBuilder;
+import org.mule.component.simple.EchoComponent;
 import org.mule.config.DefaultMuleConfiguration;
 import org.mule.module.management.agent.FixedHostRmiClientSocketFactory;
 import org.mule.module.management.agent.JmxAgent;
 import org.mule.module.management.agent.RmiRegistryAgent;
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleContextTestCase;
 
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 
+import javax.management.InstanceAlreadyExistsException;
+import javax.management.MBeanRegistrationException;
 import javax.management.MBeanServerConnection;
+import javax.management.MalformedObjectNameException;
+import javax.management.NotCompliantMBeanException;
 import javax.management.remote.JMXConnector;
 import javax.management.remote.JMXConnectorFactory;
 import javax.management.remote.JMXServiceURL;
 import javax.management.remote.rmi.RMIConnectorServer;
 
-public class JmxAgentTestCase extends AbstractMuleTestCase
-{
+import org.junit.Test;
 
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
+public class JmxAgentTestCase extends AbstractMuleContextTestCase
+{
     private static final String[] VALID_AUTH_TOKEN = {"mule", "mulepassword"};
     private static final String DOMAIN = "JmxAgentTest";
-    
+
     private JMXServiceURL serviceUrl;
     private JmxAgent jmxAgent;
 
@@ -47,26 +56,33 @@ public class JmxAgentTestCase extends AbstractMuleTestCase
         contextBuilder.setMuleConfiguration(config);
     }
 
+    @Override
     protected void doSetUp() throws Exception
     {
         super.doSetUp();
         serviceUrl = new JMXServiceURL(JmxAgent.DEFAULT_REMOTING_URI);
         muleContext.getRegistry().registerAgent(new RmiRegistryAgent());
-        jmxAgent = (JmxAgent) muleContext.getRegistry().lookupObject(JmxAgent.class);
+        jmxAgent = muleContext.getRegistry().lookupObject(JmxAgent.class);
         jmxAgent.setConnectorServerUrl(JmxAgent.DEFAULT_REMOTING_URI);
     }
 
+    @Override
     protected void doTearDown()
     {
-        jmxAgent.dispose();
+        if (jmxAgent != null)
+        {
+            jmxAgent.dispose();
+        }
     }
 
+    @Test
     public void testDefaultProperties() throws Exception
     {
         jmxAgent.setCredentials(getValidCredentials());
         muleContext.start();
     }
 
+    @Test
     public void testSuccessfulRemoteConnection() throws Exception
     {
         configureProperties();
@@ -76,7 +92,7 @@ public class JmxAgentTestCase extends AbstractMuleTestCase
         JMXConnector connector = null;
         try
         {
-            Map props = Collections.singletonMap(JMXConnector.CREDENTIALS, VALID_AUTH_TOKEN);
+            Map<String, ?> props = Collections.singletonMap(JMXConnector.CREDENTIALS, VALID_AUTH_TOKEN);
             connector = JMXConnectorFactory.connect(serviceUrl, props);
             MBeanServerConnection connection = connector.getMBeanServerConnection();
             // is it the right server?
@@ -92,6 +108,7 @@ public class JmxAgentTestCase extends AbstractMuleTestCase
         }
     }
 
+    @Test
     public void testNoCredentialsProvided() throws Exception
     {
         configureProperties();
@@ -113,10 +130,11 @@ public class JmxAgentTestCase extends AbstractMuleTestCase
             if (connector != null)
             {
                 connector.close();
-            }            
+            }
         }
     }
 
+    @Test
     public void testNonRestrictedAccess() throws Exception
     {
         configureProperties();
@@ -140,9 +158,9 @@ public class JmxAgentTestCase extends AbstractMuleTestCase
         }
     }
 
-    protected Map getValidCredentials()
+    protected Map<String, String> getValidCredentials()
     {
-        final Map credentials = new HashMap(1);
+        final Map<String, String> credentials = new HashMap<String, String>(1);
         credentials.put(VALID_AUTH_TOKEN[0], VALID_AUTH_TOKEN[1]);
 
         return credentials;
@@ -152,10 +170,38 @@ public class JmxAgentTestCase extends AbstractMuleTestCase
     {
         // make multi-NIC dev box happy by sticking RMI clients to a single
         // local ip address
-        Map props = new HashMap();
+        Map<String, Object> props = new HashMap<String, Object>();
         props.put(RMIConnectorServer.RMI_CLIENT_SOCKET_FACTORY_ATTRIBUTE,
                   new FixedHostRmiClientSocketFactory("127.0.0.1"));
         jmxAgent.setConnectorServerProperties(props);
     }
-    
+
+    @Test
+    public void testServiceNameContainsColon() throws Exception
+    {
+        // create a service with an invalid name. It is registered in the registry as side effect
+        // so the JmxAgent will pick it up while registring services
+        getTestService("invalid:service:name", EchoComponent.class);
+
+        // when registering services, the one we just put into the registry will be exposed
+        // to the local MBean server, too. If a MalformedObjectNameException is thrown during
+        // this operation, this test will fail
+        TestJmxAgent agent = new TestJmxAgent();
+        agent.setMuleContext(muleContext);
+        agent.initialise();
+
+        agent.registerServiceServices();
+    }
+
+    private static class TestJmxAgent extends JmxAgent
+    {
+        /**
+         * Open up method for test access
+         */
+        @Override
+        public void registerServiceServices() throws NotCompliantMBeanException, MBeanRegistrationException, InstanceAlreadyExistsException, MalformedObjectNameException
+        {
+            super.registerServiceServices();
+        }
+    }
 }
