@@ -1,5 +1,5 @@
 /*
- * $Id: YourKitProfilerTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -14,6 +14,10 @@ import org.mule.module.management.mbean.YourKitProfilerServiceMBean;
 
 import java.lang.reflect.Method;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertTrue;
+
 
 public class YourKitProfilerTestCase extends AbstractMuleJmxTestCase
 {
@@ -24,6 +28,7 @@ public class YourKitProfilerTestCase extends AbstractMuleJmxTestCase
      *
      * @throws Exception
      */
+    @Test
     public void testMethodLenght() throws Exception
     {
         Method[] methods = YourKitProfilerServiceMBean.class.getMethods();
