@@ -1,5 +1,5 @@
 /*
- * $Id: NonRootCustomerTest.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -9,14 +9,18 @@
  */
 package org.mule.module.atom;
 
+import org.junit.Test;
+
 public class NonRootCustomerTest extends AbstractCustomerTest
 {
+
     @Override
     protected String getConfigResources()
     {
         return "customer-nonroot-conf.xml";
     }
 
+    @Test
     public void testCustomerProvider() throws Exception
     {
         testCustomerProvider("/base");
