@@ -1,5 +1,5 @@
 /*
- * $Id: ConfigurationTestCase.java 19456 2010-09-08 17:07:59Z esteban.robles $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,28 +10,50 @@
 
 package org.mule.module.cxf;
 
-import java.util.Iterator;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
+import org.mule.api.endpoint.InboundEndpoint;
+import org.mule.module.cxf.config.FlowConfiguringMessageProcessor;
+import org.mule.module.cxf.config.ProxyServiceFactoryBean;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
+
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.List;
 
 import org.apache.cxf.Bus;
 import org.apache.cxf.interceptor.Interceptor;
 import org.apache.cxf.interceptor.LoggingInInterceptor;
-import org.mule.api.endpoint.InboundEndpoint;
-import org.mule.module.cxf.config.FlowConfiguringMessageProcessor;
-import org.mule.module.cxf.config.ProxyServiceFactoryBean;
-import org.mule.tck.FunctionalTestCase;
+import org.apache.cxf.message.Message;
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
 
-public class ConfigurationTestCase extends FunctionalTestCase
+public class ConfigurationTestCase extends AbstractServiceAndFlowTestCase
 {
+    public ConfigurationTestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
+    }
+
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "configuration-conf-service.xml"},
+            {ConfigVariant.FLOW, "configuration-conf-flow.xml"}
+        });
+    }      
+    
+    @Test
     public void testBusConfiguration() throws Exception
     {
         CxfConfiguration config = muleContext.getRegistry().get("cxf");
 
-        Bus cxfBus = ((CxfConfiguration) config).getCxfBus();
+        Bus cxfBus = config.getCxfBus();
         boolean found = false;
-        for (Iterator itr2 = cxfBus.getInInterceptors().iterator(); itr2.hasNext();)
+        for (Interceptor<? extends Message> i : cxfBus.getInInterceptors())
         {
-            Interceptor i = (Interceptor) itr2.next();
             if (i instanceof LoggingInInterceptor)
             {
                 found = true;
@@ -41,19 +63,15 @@ public class ConfigurationTestCase extends FunctionalTestCase
 
         assertTrue("Did not find logging interceptor.", found);
     }
-    
+
+    @Test
     public void testSpringRefs() throws Exception
     {
         InboundEndpoint endpoint = muleContext.getRegistry().get("clientEndpoint");
         FlowConfiguringMessageProcessor processor = (FlowConfiguringMessageProcessor) endpoint.getMessageProcessors().get(0);
-        List inInterceptors = ((ProxyServiceFactoryBean) processor.getMessageProcessorBuilder()).getInInterceptors();
+        List<Interceptor<? extends Message>> inInterceptors =
+            ((ProxyServiceFactoryBean) processor.getMessageProcessorBuilder()).getInInterceptors();
         assertEquals(muleContext.getRegistry().get("foo1"), inInterceptors.get(0));
         assertEquals(muleContext.getRegistry().get("foo3"), inInterceptors.get(1));
     }
-
-    protected String getConfigResources()
-    {
-        return "configuration-conf.xml";
-    }
-
 }
