@@ -1,5 +1,5 @@
 /*
- * $Id: CxfWsdlTestCase.java 22377 2011-07-11 12:41:42Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,25 +10,23 @@
 
 package org.mule.module.cxf;
 
+import static org.junit.Assert.assertNotNull;
+
 import org.mule.DefaultMuleEvent;
 import org.mule.DefaultMuleMessage;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleMessage;
-import org.mule.api.MuleSession;
+import org.mule.api.construct.FlowConstruct;
 import org.mule.api.endpoint.EndpointBuilder;
 import org.mule.api.endpoint.OutboundEndpoint;
 import org.mule.endpoint.EndpointURIEndpointBuilder;
 import org.mule.module.client.MuleClient;
-import org.mule.session.DefaultMuleSession;
 import org.mule.tck.junit4.AbstractMuleContextTestCase;
-import org.mule.transport.AbstractConnector;
 
 import org.custommonkey.xmlunit.XMLAssert;
 import org.junit.Test;
 import org.w3c.dom.Document;
 
-import static org.junit.Assert.assertNotNull;
-
 public class CxfWsdlTestCase extends AbstractMuleContextTestCase
 {
     public static final String TEST_URL = "wsdl-cxf:http://localhost:8080/mule-tests-external-cxf/services/TestService?WSDL&method=getTest";
@@ -66,9 +64,7 @@ public class CxfWsdlTestCase extends AbstractMuleContextTestCase
             muleContext.getEndpointFactory().getOutboundEndpoint(endpointBuilder);
 
         MuleMessage message = new DefaultMuleMessage("test1", muleContext);
-        MuleSession session = new DefaultMuleSession(message,
-            ((AbstractConnector) endpoint.getConnector()).getSessionHandler(), muleContext);
-        MuleEvent event = new DefaultMuleEvent(message, endpoint.getExchangePattern(), session);
+        MuleEvent event = new DefaultMuleEvent(message, endpoint.getExchangePattern(),(FlowConstruct) null);
         MuleMessage reply = endpoint.process(event).getMessage();
 
         assertNotNull(reply);
