@@ -1,5 +1,5 @@
 /*
- * $Id: MtomProxyTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,14 +10,25 @@
 
 package org.mule.module.cxf;
 
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.runners.Parameterized.Parameters;
 
 public class MtomProxyTestCase extends MtomTestCase
 {
 
-    protected String getConfigResources()
+    public MtomProxyTestCase(ConfigVariant variant, String configResources)
     {
-        return "mtom-proxy-conf.xml";
+        super(variant, configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{            
+            {ConfigVariant.FLOW, "mtom-proxy-conf.xml"}
+        });
+    }          
 }
 
