@@ -1,5 +1,5 @@
 /*
- * $Id: StaxFeatureTestCase.java 21151 2011-01-31 21:53:23Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,37 +10,42 @@
 
 package org.mule.module.cxf;
 
-import org.mule.tck.DynamicPortTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
 
 import org.apache.cxf.Bus;
+import org.junit.Rule;
+import org.junit.Test;
 
-public class StaxFeatureTestCase extends DynamicPortTestCase
+import static org.junit.Assert.assertNotNull;
+
+public class StaxFeatureTestCase extends FunctionalTestCase
 {
+
+    @Rule
+    public DynamicPort dynamicPort = new DynamicPort("port1");
+
+    @Override
+    protected String getConfigResources()
+    {
+        return "stax-feature-conf.xml";
+    }
+
+    @Test
     public void testEchoService() throws Exception
     {
         CxfConfiguration cxfCon = (CxfConfiguration)muleContext.getRegistry().lookupObject(CxfConstants.DEFAULT_CXF_CONFIGURATION);
         assertNotNull(cxfCon);
 
         Bus cxfBus = cxfCon.getCxfBus();
-        
+
         // ensure that our interceptor is there
 //        assertEquals(2, cxfBus.getInInterceptors().size());
-//        
+//
 //        MuleClient client = new MuleClient();
 //        MuleMessage result = client.send("cxf:http://localhost:63081/services/Echo?method=echo", "Hello!", null);
 //        assertEquals("Hello!", result.getPayload());
     }
 
-    @Override
-    protected String getConfigResources() 
-    {
-        return "stax-feature-conf.xml";
-    }
-
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 1;
-    }
 }
 
