@@ -1,5 +1,5 @@
 /*
- * $Id: WebServiceMessageProcessorBuilder.java 22458 2011-07-19 20:03:32Z evangelinamrm $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -29,6 +29,8 @@ import org.mule.service.ServiceCompositeMessageSource;
 
 import java.util.List;
 
+import javax.xml.namespace.QName;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.cxf.aegis.databinding.AegisDatabinding;
@@ -52,7 +54,7 @@ public class WebServiceMessageProcessorBuilder
 {
     protected transient Log logger = LogFactory.getLog(getClass());
 
-    private List<DataBinding> databinding;
+    private DataBinding databinding;
     private String frontend = CxfConstants.JAX_WS_FRONTEND;
     private FlowConstruct flowConstruct;
     private Service muleService;
@@ -85,16 +87,21 @@ public class WebServiceMessageProcessorBuilder
         logger.info("Built CXF Inbound MessageProcessor for service class " + serviceClass.getName());
 
         // Configure Databinding
-        if (databinding != null && databinding.size() > 0)
+        if (databinding != null)
         {
-            // TODO: find a way to make this not a list
-            sfb.setDataBinding(databinding.get(0));
+            sfb.setDataBinding(databinding);
         }
 
         if (muleService != null && muleService.getComponent() instanceof JavaComponent)
         {
             sfb.setServiceBean(((JavaComponent) muleService.getComponent()).getObjectFactory().getInstance(muleContext));
         }
+
+        if(getService() != null && getNamespace() != null)
+        {
+            sfb.setServiceName(new QName(getNamespace(), getService()));
+        }
+
         return sfb;
     }
 
@@ -213,12 +220,12 @@ public class WebServiceMessageProcessorBuilder
         this.frontend = frontend;
     }
 
-    public List<DataBinding> getDatabinding()
+    public DataBinding getDatabinding()
     {
         return databinding;
     }
 
-    public void setDatabinding(List<DataBinding> databinding)
+    public void setDatabinding(DataBinding databinding)
     {
         this.databinding = databinding;
     }
