@@ -1,5 +1,5 @@
 /*
- * $Id: TreatNullPayloadAsVoidTestCase.java 21151 2011-01-31 21:53:23Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,6 +11,12 @@
 package org.mule.module.cxf.payload;
 
 
+import org.mule.tck.junit4.FunctionalTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
+
+import org.junit.Rule;
+import org.junit.Test;
+
 import static org.mule.module.cxf.payload.PayloadTestConstants.emptyOjbectArrayPayload;
 import static org.mule.module.cxf.payload.PayloadTestConstants.greetMeOutEndpointName;
 import static org.mule.module.cxf.payload.PayloadTestConstants.nullPayload;
@@ -21,14 +27,23 @@ import static org.mule.module.cxf.payload.PayloadTestConstants.strArrayPayloadRe
 import static org.mule.module.cxf.payload.PayloadTestConstants.strPayload;
 import static org.mule.module.cxf.payload.PayloadTestConstants.strPayloadResult;
 
-import org.mule.tck.DynamicPortTestCase;
-
 /**
  * This tests the payloadToArguments attribute on the cxf outbound endpoints for the
  * case it is supplied with value nullPayloadAsVoid.
  */
-public class TreatNullPayloadAsVoidTestCase extends DynamicPortTestCase
+public class TreatNullPayloadAsVoidTestCase extends FunctionalTestCase
 {
+
+    @Rule
+    public DynamicPort dynamicPort = new DynamicPort("port1");
+
+    @Override
+    protected String getConfigResources()
+    {
+        return "messagedispatcher/null-payload-add-as-void.xml";
+    }
+
+    @Test
     public void testRunAllScenarios() throws Exception
     {
         CallAndExpect[] callAndExpectArray = {
@@ -52,17 +67,4 @@ public class TreatNullPayloadAsVoidTestCase extends DynamicPortTestCase
             callAndExpect.callEndpointAndExecuteAsserts();
         }
     }
-
-    @Override
-    protected String getConfigResources()
-    {
-        return "messagedispatcher/null-payload-add-as-void.xml";
-    }
-
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 1;
-    }
-
 }
