@@ -1,5 +1,5 @@
 /*
- * $Id: WebServiceSecurityException.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -19,7 +19,7 @@ public class WebServiceSecurityException extends org.mule.api.security.SecurityE
     {
         super(MessageFactory.createStaticMessage(
             "Security exception occurred invoking web service\nEndpoint = " 
-            + event.getEndpoint().getEndpointURI() 
+            + event.getMessageSourceURI()
             + "\nSecurity provider(s) = " + event.getMuleContext().getSecurityManager().getProviders()
             + "\nEvent = " + event),
             event, cause);
