@@ -1,5 +1,5 @@
 /*
- * $Id: CopyAttachmentInInterceptor.java 21251 2011-02-11 00:23:49Z dandiep $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -35,7 +35,8 @@ public class CopyAttachmentInInterceptor extends AbstractPhaseInterceptor
         MuleEvent event = (MuleEvent) message.getExchange().get(CxfConstants.MULE_EVENT);
         MuleMessage muleMsg = event.getMessage();
         Collection<Attachment> atts = message.getAttachments();
-        if (atts != null)
+
+        if (atts != null && !atts.isEmpty())
         {
             muleMsg.setInvocationProperty(CxfConstants.ATTACHMENTS, atts);
             muleMsg.setOutboundProperty(HttpConstants.HEADER_CONTENT_TYPE, muleMsg.getInboundProperty(HttpConstants.HEADER_CONTENT_TYPE));
