@@ -1,5 +1,5 @@
 /*
- * $Id: Echo.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,20 +10,33 @@
 
 package org.mule.module.cxf.testmodels;
 
+import javax.annotation.Resource;
 import javax.jws.WebMethod;
 import javax.jws.WebParam;
 import javax.jws.WebResult;
 import javax.jws.WebService;
+import javax.xml.ws.WebServiceContext;
+
+import org.junit.Assert;
 
 @WebService
 public class Echo
 {
-
+    @Resource
+    private WebServiceContext context;
+    
     @WebResult(name = "text")
     @WebMethod
-    public String echo(@WebParam(name = "text")
-    String s)
+    public String echo(@WebParam(name = "text") String s)
     {
         return s;
     }
+
+    @WebResult(name = "output")
+    @WebMethod
+    public String ensureWebSerivceContextIsSet(@WebParam(name = "input") String input)
+    {
+        Assert.assertNotNull(context);
+        return input;
+    }
 }
