@@ -1,5 +1,5 @@
 /*
- * $Id: TestCxfComponent.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,6 +10,8 @@
 
 package org.mule.module.cxf.testmodels;
 
+import org.apache.cxf.interceptor.Fault;
+
 public class TestCxfComponent
 {
     public String testCxfException(String data) throws CxfEnabledFaultMessage
@@ -19,6 +21,11 @@ public class TestCxfComponent
         throw new CxfEnabledFaultMessage("Cxf Exception Message", fault);
     }
 
+    public String testFault(String data)
+    {
+        throw new Fault(new IllegalArgumentException("Invalid data argument"));
+    }
+
     public String testNonCxfException(String data)
     {
         throw new UnsupportedOperationException("Non-Cxf Enabled Exception");
