@@ -1,5 +1,5 @@
 /*
- * $Id: MuleUniversalConduit.java 22542 2011-07-22 20:50:01Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -14,19 +14,21 @@ import static org.apache.cxf.message.Message.DECOUPLED_CHANNEL_MESSAGE;
 
 import org.mule.DefaultMuleEvent;
 import org.mule.DefaultMuleMessage;
+import org.mule.VoidMuleEvent;
+import org.mule.api.DefaultMuleException;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
-import org.mule.api.MuleSession;
+import org.mule.api.construct.FlowConstruct;
 import org.mule.api.endpoint.OutboundEndpoint;
 import org.mule.api.transformer.TransformerException;
 import org.mule.api.transport.OutputHandler;
+import org.mule.config.i18n.MessageFactory;
 import org.mule.module.cxf.CxfConfiguration;
 import org.mule.module.cxf.CxfConstants;
 import org.mule.module.cxf.CxfOutboundMessageProcessor;
 import org.mule.module.cxf.support.DelegatingOutputStream;
-import org.mule.session.DefaultMuleSession;
 import org.mule.transformer.types.DataTypeFactory;
 import org.mule.transport.NullPayload;
 import org.mule.transport.http.HttpConnector;
@@ -152,19 +154,18 @@ public class MuleUniversalConduit extends AbstractConduit
         
         OutboundEndpoint ep = null;
         
-        if (event == null || decoupled)
+        if (event == null || VoidMuleEvent.getInstance().equals(event) || decoupled)
         {
             // we've got an out of band WS-RM message or a message from a standalone client
             MuleContext muleContext = configuration.getMuleContext();
             MuleMessage muleMsg = new DefaultMuleMessage(handler, muleContext);
-            MuleSession session = new DefaultMuleSession(muleContext);
             
             String url = setupURL(message);
             
             try
             {
                 ep = getEndpoint(muleContext, url);
-                event = new DefaultMuleEvent(muleMsg, ep.getExchangePattern(), session);
+                event = new DefaultMuleEvent(muleMsg, ep.getExchangePattern(), (FlowConstruct) null);
             }
             catch (Exception e)
             {
@@ -192,7 +193,7 @@ public class MuleUniversalConduit extends AbstractConduit
                 {
                     dispatchMuleMessage(m, finalEvent, finalEndpoint);
                 }
-                catch (IOException e)
+                catch (MuleException e)
                 {
                     throw new Fault(e);
                 }
@@ -242,15 +243,15 @@ public class MuleUniversalConduit extends AbstractConduit
         return result;
     }
     
-    protected void dispatchMuleMessage(Message m, MuleEvent reqEvent, OutboundEndpoint endpoint) throws IOException {
+    protected void dispatchMuleMessage(Message m, MuleEvent reqEvent, OutboundEndpoint endpoint) throws MuleException {
         try
-        {   
+        {
             MuleMessage req = reqEvent.getMessage();
             req.setOutboundProperty(HttpConnector.HTTP_DISABLE_STATUS_CODE_EXCEPTION_CHECK, Boolean.TRUE.toString());
 
             MuleEvent resEvent = processNext(reqEvent, m.getExchange(), endpoint);
 
-            if (resEvent == null)
+            if (resEvent == null || VoidMuleEvent.getInstance().equals(resEvent))
             {
                 m.getExchange().put(ClientImpl.FINISHED, Boolean.TRUE);
                 return;
@@ -279,16 +280,13 @@ public class MuleUniversalConduit extends AbstractConduit
                 getMessageObserver().onMessage(inMessage);
             }
         }
+        catch(MuleException me)
+        {
+            throw me;
+        }
         catch (Exception e)
         {
-            if (e instanceof IOException)
-            {
-                throw (IOException) e;
-            }
-
-            IOException ex = new IOException("Could not send message to Mule.");
-            ex.initCause(e);
-            throw ex;
+            throw new DefaultMuleException(MessageFactory.createStaticMessage("Could not send message to Mule."), e);
         }
     }
 
@@ -329,7 +327,7 @@ public class MuleUniversalConduit extends AbstractConduit
             return target.getAddress().getValue();
         }
 
-        return endpoint.getAddress().toString();
+        return endpoint.getAddress();
     }
 
     public void onClose(final Message m) throws IOException
