@@ -1,5 +1,5 @@
 /*
- * $Id: JaasAuthentication.java 23743 2012-01-28 05:23:23Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -25,8 +25,8 @@ public class JaasAuthentication implements Authentication
     private String user;
     private Map<String, Object> properties;
     private Subject subject;
-    private MuleEvent event;
-
+    transient private MuleEvent event;
+    
     public JaasAuthentication(Credentials credentials)
     {
         this.user = credentials.getUsername();
