@@ -1,5 +1,5 @@
 /*
- * $Id: JaasAuthenticationWithNtLoginModule.java 22526 2011-07-22 11:13:49Z justin.calleja $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -19,7 +19,11 @@ import java.util.Map;
 
 import org.junit.Test;
 import org.junit.runners.Parameterized.Parameters;
+
+import org.mule.api.MuleEvent;
+import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
+import org.mule.api.processor.MessageProcessor;
 import org.mule.util.SystemUtils;
 
 public class JaasAuthenticationWithNtLoginModule extends AbstractJaasFunctionalTestCase
