@@ -1,5 +1,5 @@
 /*
- * $Id: JerseyNamespaceHandler.java 21492 2011-03-08 04:25:31Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -17,12 +17,17 @@ import org.mule.module.jersey.JerseyResourcesComponent;
 
 public class JerseyNamespaceHandler extends AbstractMuleNamespaceHandler
 {
+    @Override
     public void init()
     {
         ChildDefinitionParser exceptionMapperParser = new ChildDefinitionParser("exceptionMapper",
             null, null, true);
         registerBeanDefinitionParser("exception-mapper", exceptionMapperParser);
 
+        ChildDefinitionParser contextResolverParser = new ChildDefinitionParser("contextResolver",
+            null, null, true);
+        registerBeanDefinitionParser("context-resolver", contextResolverParser);
+
         ComponentDefinitionParser parser = new ComponentDefinitionParser(JerseyResourcesComponent.class);
         registerBeanDefinitionParser("resources", parser);
     }
