@@ -1,5 +1,5 @@
 /*
- * $Id: JsonData.java 21831 2011-05-06 17:49:35Z dandiep $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -141,7 +141,7 @@ public class JsonData implements Serializable
         JsonNode node = get(expression);
         if (node.isValueNode())
         {
-            return node.getValueAsText();
+            return node.asText();
         }
         else
         {
