@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractFileWatcher.java 21433 2011-03-03 17:08:00Z aperepel $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,6 +11,10 @@
 package org.mule.module.launcher;
 
 import java.io.File;
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.Map;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -20,29 +24,50 @@ public abstract class AbstractFileWatcher implements Runnable
 
     protected Log logger = LogFactory.getLog(getClass());
 
-    private long timeStamp;
-    private File file;
+    private Collection<File> files;
+    private Map<File, Long> timestamps = new HashMap<File, Long>();
 
     public AbstractFileWatcher(File file)
     {
-        this.file = file;
-        this.timeStamp = file.lastModified();
+        this(Arrays.asList(file));
     }
 
+    public AbstractFileWatcher(Collection<File> files)
+    {
+        this.files = files;
+
+        for (File file : files)
+        {
+            timestamps.put(file, file.lastModified());
+        }
+    }
+
+    @Override
     public final void run()
     {
-        long timeStamp = file.lastModified();
+        File latestFile = null;
 
-        if (this.timeStamp != timeStamp)
+        for (File file : files)
+        {
+            long originalTimestamp = timestamps.get(file);
+            long currentTimestamp = file.lastModified();
+
+            if (originalTimestamp != currentTimestamp)
+            {
+                timestamps.put(file, currentTimestamp);
+                latestFile = file;
+            }
+        }
+
+        if (latestFile != null)
         {
-            this.timeStamp = timeStamp;
             try
             {
-                onChange(file);
+                onChange(latestFile);
             }
             catch (Throwable t)
             {
-                logger.error(String.format("Monitor for %s threw an exception", file), t);
+                logger.error(String.format("Monitor for %s threw an exception", latestFile), t);
             }
         }
     }
