@@ -1,5 +1,5 @@
 /*
- * $Id: DeploymentServiceTestCase.java 24356 2012-04-26 00:29:58Z pablo.kraan $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -14,56 +14,52 @@ import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
-
-import org.mule.MuleCoreExtension;
+import static org.junit.Assert.fail;
+import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.reset;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
 import org.mule.api.MuleContext;
-import org.mule.api.component.JavaComponent;
 import org.mule.api.config.MuleProperties;
-import org.mule.api.construct.FlowConstruct;
 import org.mule.api.registry.MuleRegistry;
 import org.mule.config.StartupContext;
-import org.mule.construct.SimpleService;
 import org.mule.module.launcher.application.Application;
-import org.mule.module.launcher.application.ApplicationWrapper;
-import org.mule.module.launcher.application.PriviledgedMuleApplication;
+import org.mule.module.launcher.application.MuleApplicationClassLoaderFactory;
+import org.mule.module.launcher.application.TestApplicationFactory;
 import org.mule.tck.junit4.AbstractMuleContextTestCase;
 import org.mule.tck.probe.PollingProber;
 import org.mule.tck.probe.Probe;
 import org.mule.tck.probe.Prober;
+import org.mule.tck.probe.file.FileDoesNotExists;
 import org.mule.util.CollectionUtils;
 import org.mule.util.FileUtils;
 import org.mule.util.StringUtils;
-import org.mule.util.concurrent.Latch;
 
 import java.io.File;
 import java.io.IOException;
 import java.net.URL;
 import java.net.URLDecoder;
 import java.util.Arrays;
-import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.io.filefilter.DirectoryFileFilter;
 import org.junit.Test;
 
 public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
 {
-    protected static final int LATCH_TIMEOUT = 20000;
+    protected static final int DEPLOYMENT_TIMEOUT = 20000;
     protected static final String[] NONE = new String[0];
+    protected static final int ONE_HOUR_IN_MILLISECONDS = 3600000;
 
     protected File muleHome;
     protected File appsDir;
-    protected DeploymentService deploymentService;
-    // these latches are re-created during the test, thus need to be declared volatile
-    protected volatile Latch deployLatch;
-    protected volatile Latch installLatch;
-    protected volatile Latch undeployLatch;
+    protected MuleDeploymentService deploymentService;
+    protected DeploymentListener deploymentListener;
 
     @Override
     protected void doSetUp() throws Exception
@@ -78,11 +74,9 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
 
         new File(muleHome, "lib/shared/default").mkdirs();
 
-        deploymentService = new DeploymentService(new HashMap<Class<? extends MuleCoreExtension>, MuleCoreExtension>());
-        deploymentService.setDeployer(new TestDeployer());
-        installLatch = new Latch();
-        deployLatch = new Latch();
-        undeployLatch = new Latch();
+        deploymentListener = mock(DeploymentListener.class);
+        deploymentService = new MuleDeploymentService(new MulePluginClassLoaderManager());
+        deploymentService.addDeploymentListener(deploymentListener);
     }
 
     @Override
@@ -102,63 +96,6 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
         Thread.currentThread().setContextClassLoader(ClassLoader.getSystemClassLoader());
     }
 
-    @Test
-    public void testPriviledgedApp() throws Exception
-    {
-        final URL url = getClass().getResource("/priviledged-dummy-app.zip");
-        assertNotNull("Test app file not found " + url, url);
-        addAppArchive(url);
-
-        deploymentService.start();
-
-        assertTrue("Deployer never invoked", deployLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
-
-        assertAppsDir(NONE, new String[] {"priviledged-dummy-app"}, true);
-
-        final Application app = findApp("priviledged-dummy-app", 1);
-        // now that we're sure it's the app we wanted, assert the registry has everything
-        // a 'privileged' app would have had
-        final Object obj = app.getMuleContext().getRegistry().lookupObject(PriviledgedMuleApplication.REGISTRY_KEY_DEPLOYMENT_SERVICE);
-        assertNotNull("Privileged objects have not been registered", obj);
-        assertTrue(((ApplicationWrapper) app).getDelegate() instanceof PriviledgedMuleApplication);
-    }
-
-    @Test
-    public void testPriviledgedCrossAppAccess() throws Exception
-    {
-        URL url = getClass().getResource("/priviledged-dummy-app.zip");
-        assertNotNull("Test app file not found " + url, url);
-        addAppArchive(url);
-
-        url = getClass().getResource("/dummy-app.zip");
-        assertNotNull("Test app file not found " + url, url);
-        addAppArchive(url);
-
-        deploymentService.start();
-
-        // a basic latch isn't ideal here, as there are 2 apps to deploy
-        assertTrue("Deployer never invoked", deployLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
-
-        assertAppsDir(NONE, new String[] {"dummy-app", "priviledged-dummy-app"}, true);
-
-        final Application privApp = findApp("priviledged-dummy-app", 2);
-        final Application dummyApp = findApp("dummy-app", 2);
-        assertTrue(((ApplicationWrapper) privApp).getDelegate() instanceof PriviledgedMuleApplication);
-
-        final MuleContext muleContext1 = privApp.getMuleContext();
-        System.out.println("muleContext1 = " + muleContext1);
-        assertNotSame(muleContext1, muleContext);
-        assertNotSame(privApp.getDeploymentClassLoader(), dummyApp.getDeploymentClassLoader());
-        final Collection<FlowConstruct> flowConstructs = dummyApp.getMuleContext().getRegistry().lookupObjects(FlowConstruct.class);
-        assertFalse("No FlowConstructs found in the sibling app", flowConstructs.isEmpty());
-        FlowConstruct fc = flowConstructs.iterator().next();
-        assertTrue(fc instanceof SimpleService);
-        SimpleService service = (SimpleService) fc;
-        // note that we don't have this class available to this test directly
-        Class<?> clazz = ((JavaComponent) service.getComponent()).getObjectType();
-        assertEquals("Wrong component implementation class", "org.mule.module.launcher.EchoTest", clazz.getName());
-    }
-
     @Test
     public void testDeployZipOnStartup() throws Exception
     {
@@ -168,16 +105,13 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
 
         deploymentService.start();
 
-        assertTrue("Deployer never invoked", deployLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
+        assertDeploymentSuccess(deploymentListener, "dummy-app");
 
         assertAppsDir(NONE, new String[] {"dummy-app"}, true);
 
         // just assert no privileged entries were put in the registry
         final Application app = findApp("dummy-app", 1);
         final MuleRegistry registry = app.getMuleContext().getRegistry();
-        final Object obj = registry.lookupObject(PriviledgedMuleApplication.REGISTRY_KEY_DEPLOYMENT_SERVICE);
-        assertNull(obj);
-        assertFalse(((ApplicationWrapper) app).getDelegate() instanceof PriviledgedMuleApplication);
 
         // mule-app.properties from the zip archive must have loaded properly
         assertEquals("mule-app.properties should have been loaded.", "someValue", registry.get("myCustomProp"));
@@ -192,15 +126,41 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
 
         deploymentService.start();
 
-        assertTrue("Deployer never invoked", deployLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
+        assertDeploymentSuccess(deploymentListener, "dummy-app");
+
         assertAppsDir(NONE, new String[] {"dummy-app"}, true);
         assertEquals("Application has not been properly registered with Mule", 1, deploymentService.getApplications().size());
 
-        // set up a new deployment latch (can't reuse the old one)
-        deployLatch = new Latch();
+        reset(deploymentListener);
         addAppArchive(url);
-        assertTrue("Undeploy never invoked", undeployLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
-        assertTrue("Deployer never invoked", deployLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
+
+        assertUndeploymentSuccess(deploymentListener, "dummy-app");
+        assertDeploymentSuccess(deploymentListener, "dummy-app");
+        assertEquals("Application has not been properly registered with Mule", 1, deploymentService.getApplications().size());
+        assertAppsDir(NONE, new String[]{"dummy-app"}, true);
+    }
+
+    @Test
+    public void redeploysAppWhenConfigChanges() throws Exception
+    {
+        final URL url = getClass().getResource("/dummy-app.zip");
+        assertNotNull("Test app file not found " + url, url);
+        addAppArchive(url);
+
+        deploymentService.start();
+
+        assertDeploymentSuccess(deploymentListener, "dummy-app");
+
+        assertAppsDir(NONE, new String[] {"dummy-app"}, true);
+        assertEquals("Application has not been properly registered with Mule", 1, deploymentService.getApplications().size());
+
+        reset(deploymentListener);
+
+        File configFile = new File(appsDir + "/dummy-app", "mule-config.xml");
+        configFile.setLastModified(configFile.lastModified() + 1000);
+
+        assertUndeploymentSuccess(deploymentListener, "dummy-app");
+        assertDeploymentSuccess(deploymentListener, "dummy-app");
         assertEquals("Application has not been properly registered with Mule", 1, deploymentService.getApplications().size());
         assertAppsDir(NONE, new String[]{"dummy-app"}, true);
     }
@@ -229,10 +189,8 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
 
         deploymentService.start();
 
-        assertTrue("Install never invoked", installLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
-
-        // Resets the latch to detect a new attempt to deploy the zip file
-        installLatch = new Latch();
+        assertDeploymentFailure(deploymentListener, "broken-app.zip");
+        reset(deploymentListener);
 
         // let the file system's write-behind cache commit the delete operation?
         Thread.sleep(1000);
@@ -249,7 +207,14 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
         assertTrue("Invalid lastModified value for file URL.", zombie.getValue() != -1);
 
         // Checks that the invalid zip was not deployed again
-        assertFalse("Install was invoked again for the broken application file", installLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
+        try
+        {
+            assertDeploymentFailure(deploymentListener, "broken-app.zip");
+            fail("Install was invoked again for the broken application file");
+        }
+        catch (AssertionError expected)
+        {
+        }
     }
 
     @Test
@@ -259,14 +224,8 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
         assertNotNull("Test app file not found " + url, url);
         addAppArchive(url, "app with spaces.zip");
 
-        try
-        {
-            deploymentService.start();
-        }
-        catch (DeploymentInitException e)
-        {
-            assertTrue(e.getMessage().contains("may not contain spaces"));
-        }
+        deploymentService.start();
+        assertDeploymentFailure(deploymentListener, "app with spaces.zip");
 
         // zip stays intact, no app dir created
         assertAppsDir(new String[] {"app with spaces.zip"}, NONE, true);
@@ -288,13 +247,14 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
 
         deploymentService.start();
 
-        assertTrue("Deployer never invoked", deployLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
-        deployLatch = new Latch();
+        assertDeploymentSuccess(deploymentListener, "empty-app.zip");
+        reset(deploymentListener);
+
         assertAppsDir(NONE, new String[] {"empty-app.zip"}, true);
         assertEquals("Application has not been properly registered with Mule", 1, deploymentService.getApplications().size());
 
         // Checks that the empty-app.zip folder is not processed as a zip file
-        assertNoDeploymentInvoked();
+        assertNoDeploymentInvoked(deploymentListener);
     }
 
     @Test
@@ -312,8 +272,9 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
 
         deploymentService.start();
 
-        assertTrue("Deployer never invoked", deployLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
-
+        assertDeploymentSuccess(deploymentListener, "1");
+        assertDeploymentSuccess(deploymentListener, "2");
+        assertDeploymentSuccess(deploymentListener, "3");
         assertAppsDir(NONE, new String[] {"1", "2", "3"}, true);
 
         // When apps are passed as -app app1:app2:app3 the startup order matters
@@ -338,30 +299,292 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
 
         deploymentService.start();
 
-        assertTrue("Deployer never invoked", deployLatch.await(LATCH_TIMEOUT, TimeUnit.MILLISECONDS));
+        assertDeploymentSuccess(deploymentListener, "dummy-app");
         assertAppsDir(NONE, new String[] {"dummy-app"}, true);
 
         List<Application> applications = deploymentService.getApplications();
         assertEquals(1, applications.size());
     }
 
-    private void assertNoDeploymentInvoked()
+    @Test
+    public void testTracksAppConfigUpdateTime() throws Exception
+    {
+        final URL url = getClass().getResource("/dummy-app.zip");
+        File appFolder = new File(appsDir.getPath(), "dummy-app");
+        FileUtils.unzip(new File(url.toURI()), appFolder);
+
+        // Sets a modification time in the future
+        File configFile = new File(appFolder, "mule-config.xml");
+        configFile.setLastModified(System.currentTimeMillis() + ONE_HOUR_IN_MILLISECONDS);
+
+        deploymentService.start();
+        assertDeploymentSuccess(deploymentListener, "dummy-app");
+        reset(deploymentListener);
+
+        assertNoDeploymentInvoked(deploymentListener);
+    }
+
+    @Test
+    public void receivesMuleContextDeploymentNotifications() throws Exception
+    {
+        // NOTE: need an integration test like this because DefaultMuleApplication
+        // class cannot be unit tested.
+        final URL url = getClass().getResource("/dummy-app.zip");
+        assertNotNull("Test app file not found " + url, url);
+        addAppArchive(url);
+
+        deploymentService.start();
+
+        assertDeploymentSuccess(deploymentListener, "dummy-app");
+        assertMuleContextCreated(deploymentListener, "dummy-app");
+        assertMuleContextInitialized(deploymentListener, "dummy-app");
+        assertMuleContextConfigured(deploymentListener, "dummy-app");
+    }
+
+    @Test
+    public void undeploysStoppedApp() throws Exception
+    {
+        final URL url = getClass().getResource("/dummy-app.zip");
+        assertNotNull("Test app file not found " + url, url);
+        addAppArchive(url);
+
+        deploymentService.start();
+
+        assertDeploymentSuccess(deploymentListener, "dummy-app");
+        final Application app = findApp("dummy-app", 1);
+        app.stop();
+
+        deploymentService.undeploy(app);
+    }
+
+    @Test
+    public void undeploysApplicationRemovingAnchorFile() throws Exception
+    {
+        final URL url = getClass().getResource("/dummy-app.zip");
+        assertNotNull("Test app file not found " + url, url);
+
+        addAppArchive(url);
+        deploymentService.start();
+
+        assertDeploymentSuccess(deploymentListener, "dummy-app");
+
+        assertTrue("Unable to remove anchor file", removeAnchorFile("dummy-app"));
+
+        assertUndeploymentSuccess(deploymentListener, "dummy-app");
+    }
+
+    @Test
+    public void undeploysAppCompletelyEvenOnStoppingException() throws Exception
+    {
+        final URL url = getClass().getResource("/empty-app.zip");
+        assertNotNull("Test app file not found " + url, url);
+        addAppArchive(url);
+
+        TestApplicationFactory appFactory = new TestApplicationFactory(new MuleApplicationClassLoaderFactory());
+        appFactory.setFailOnStopApplication(true);
+
+        deploymentService.setAppFactory(appFactory);
+        deploymentService.start();
+
+        assertDeploymentSuccess(deploymentListener, "empty-app");
+
+        assertTrue("Unable to remove anchor file", removeAnchorFile("empty-app"));
+
+        assertUndeploymentSuccess(deploymentListener, "empty-app");
+
+        assertAppFolderIsDeleted("empty-app");
+    }
+
+    @Test
+    public void undeploysAppCompletelyEvenOnDisposingException() throws Exception
+    {
+        final URL url = getClass().getResource("/empty-app.zip");
+        assertNotNull("Test app file not found " + url, url);
+        addAppArchive(url);
+
+        TestApplicationFactory appFactory = new TestApplicationFactory(new MuleApplicationClassLoaderFactory());
+        appFactory.setFailOnDisposeApplication(true);
+        deploymentService.setAppFactory(appFactory);
+        deploymentService.start();
+
+        assertDeploymentSuccess(deploymentListener, "empty-app");
+
+        assertTrue("Unable to remove anchor file", removeAnchorFile("empty-app"));
+
+        assertUndeploymentSuccess(deploymentListener, "empty-app");
+
+        assertAppFolderIsDeleted("empty-app");
+    }
+
+    private void assertDeploymentSuccess(final DeploymentListener listener, final String appName)
+    {
+        Prober prober = new PollingProber(DEPLOYMENT_TIMEOUT, 100);
+        prober.check(new Probe()
+        {
+            public boolean isSatisfied()
+            {
+                try{
+                    verify(listener, times(1)).onDeploymentSuccess(appName);
+                    return true;
+                }
+                catch (AssertionError e)
+                {
+                    return false;
+                }
+            }
+
+            public String describeFailure()
+            {
+                return "Failed to deploy application: " + appName;
+            }
+        });
+    }
+
+    private void assertMuleContextCreated(final DeploymentListener listener, final String appName)
+    {
+        Prober prober = new PollingProber(DEPLOYMENT_TIMEOUT, 100);
+        prober.check(new Probe()
+        {
+            public boolean isSatisfied()
+            {
+                try{
+                    verify(listener, times(1)).onMuleContextCreated(eq(appName), any(MuleContext.class));
+                    return true;
+                }
+                catch (AssertionError e)
+                {
+                    return false;
+                }
+            }
+
+            public String describeFailure()
+            {
+                return String .format("Did not received notification '%s' for app '%s'", "onMuleContextCreated", appName);
+            }
+        });
+    }
+
+    private void assertMuleContextInitialized(final DeploymentListener listener, final String appName)
+    {
+        Prober prober = new PollingProber(DEPLOYMENT_TIMEOUT, 100);
+        prober.check(new Probe()
+        {
+            public boolean isSatisfied()
+            {
+                try{
+                    verify(listener, times(1)).onMuleContextInitialised(eq(appName), any(MuleContext.class));
+                    return true;
+                }
+                catch (AssertionError e)
+                {
+                    return false;
+                }
+            }
+
+            public String describeFailure()
+            {
+                return String .format("Did not received notification '%s' for app '%s'", "onMuleContextInitialised", appName);
+            }
+        });
+    }
+
+    private void assertMuleContextConfigured(final DeploymentListener listener, final String appName)
+    {
+        Prober prober = new PollingProber(DEPLOYMENT_TIMEOUT, 100);
+        prober.check(new Probe()
+        {
+            public boolean isSatisfied()
+            {
+                try{
+                    verify(listener, times(1)).onMuleContextConfigured(eq(appName), any(MuleContext.class));
+                    return true;
+                }
+                catch (AssertionError e)
+                {
+                    return false;
+                }
+            }
+
+            public String describeFailure()
+            {
+                return String .format("Did not received notification '%s' for app '%s'", "onMuleContextConfigured", appName);
+            }
+        });
+    }
+
+    private void assertUndeploymentSuccess(final DeploymentListener listener, final String appName)
+    {
+        Prober prober = new PollingProber(DEPLOYMENT_TIMEOUT, 100);
+        prober.check(new Probe()
+        {
+            public boolean isSatisfied()
+            {
+                try{
+                    verify(listener, times(1)).onUndeploymentSuccess(appName);
+                    return true;
+                }
+                catch (AssertionError e)
+                {
+                    return false;
+                }
+            }
+
+            public String describeFailure()
+            {
+                return "Failed to undeploy application: " + appName;
+            }
+        });
+    }
+
+    private void assertDeploymentFailure(final DeploymentListener listener, final String appName)
+    {
+        Prober prober = new PollingProber(DEPLOYMENT_TIMEOUT, 100);
+        prober.check(new Probe()
+        {
+            public boolean isSatisfied()
+            {
+                try{
+                    verify(listener, times(1)).onDeploymentFailure(eq(appName), any(Throwable.class));
+                    return true;
+                }
+                catch (AssertionError e)
+                {
+                    return false;
+                }
+            }
+
+            public String describeFailure()
+            {
+                return "Application deployment was supposed to fail for: " + appName;
+            }
+        });
+    }
+
+    private void assertNoDeploymentInvoked(final DeploymentListener deploymentListener)
     {
         //TODO(pablo.kraan): look for a better way to test this
         boolean invoked;
-        Prober prober = new PollingProber(DeploymentService.DEFAULT_CHANGES_CHECK_INTERVAL_MS * 2, 100);
+        Prober prober = new PollingProber(MuleDeploymentService.DEFAULT_CHANGES_CHECK_INTERVAL_MS * 2, 100);
         try
         {
             prober.check(new Probe()
             {
                 public boolean isSatisfied()
                 {
-                    return deploymentService.getZombieMap().size() == 1;
+                    try
+                    {
+                        verify(deploymentListener, times(1)).onDeploymentStart(any(String.class));
+                        return true;
+                    }
+                    catch (AssertionError e)
+                    {
+                        return false;
+                    }
                 }
 
                 public String describeFailure()
                 {
-                    return "App was never redeployed";
+                    return "No deployment has started";
                 }
             });
 
@@ -369,10 +592,10 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
         }
         catch (AssertionError e)
         {
-           invoked = false;
+            invoked = false;
         }
 
-        assertFalse("Deployer was invoked", invoked);
+        assertFalse("A deployment was started", invoked);
     }
 
     /**
@@ -391,7 +614,7 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
 
     private void assertAppsDir(String[] expectedZips, String[] expectedApps, boolean performValidation)
     {
-        final String[] actualZips = appsDir.list(DeploymentService.ZIP_APPS_FILTER);
+        final String[] actualZips = appsDir.list(MuleDeploymentService.ZIP_APPS_FILTER);
         if (performValidation) {
             assertArrayEquals("Invalid Mule application archives set", expectedZips, actualZips);
         }
@@ -422,48 +645,23 @@ public class DeploymentServiceTestCase extends AbstractMuleContextTestCase
         tempFile.renameTo(new File(StringUtils.removeEnd(tempFile.getAbsolutePath(), ".part")));
     }
 
-
-    private class TestDeployer implements MuleDeployer
+    /**
+     * Removes a given application anchor file in order to start application undeployment
+     * @param appName name of application to undeploy
+     * @return true if anchor file was deleted, false otherwise
+     */
+    private boolean removeAnchorFile(String appName)
     {
+        String anchorFileName = appName + MuleDeploymentService.APP_ANCHOR_SUFFIX;
+        File anchorFile = new File(appsDir, anchorFileName);
 
-        final DefaultMuleDeployer delegate;
+        return anchorFile.delete();
+    }
 
-        public TestDeployer()
-        {
-            delegate = new DefaultMuleDeployer();
-            delegate.setApplicationFactory(deploymentService.getAppFactory());
-        }
-
-        @Override
-        public void deploy(Application app)
-        {
-            System.out.println("DeploymentServiceTestCase$TestDeployer.deploy");
-            delegate.deploy(app);
-            deployLatch.release();
-        }
-
-        @Override
-        public void undeploy(Application app)
-        {
-            System.out.println("DeploymentServiceTestCase$TestDeployer.undeploy");
-            delegate.undeploy(app);
-            undeployLatch.release();
-        }
-
-        @Override
-        public Application installFromAppDir(String packedMuleAppFileName) throws IOException
-        {
-            installLatch.release();
-            System.out.println("DeploymentServiceTestCase$TestDeployer.installFromAppDir");
-            return delegate.installFromAppDir(packedMuleAppFileName);
-        }
-
-        @Override
-        public Application installFrom(URL url) throws IOException
-        {
-            installLatch.release();
-            System.out.println("DeploymentServiceTestCase$TestDeployer.installFrom");
-            return delegate.installFrom(url);
-        }
+    private void assertAppFolderIsDeleted(String appName)
+    {
+        Prober prober = new PollingProber(DEPLOYMENT_TIMEOUT, 100);
+        File appFolder = new File(appsDir, appName);
+        prober.check(new FileDoesNotExists(appFolder));
     }
 }
