@@ -1,5 +1,5 @@
 /*
- * $Id: JmxAgent.java 21733 2011-04-26 20:16:36Z mike.schilling $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -58,6 +58,7 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.atomic.AtomicBoolean;
 
 import javax.management.InstanceAlreadyExistsException;
 import javax.management.MBeanRegistrationException;
@@ -71,8 +72,6 @@ import javax.management.remote.JMXConnectorServerFactory;
 import javax.management.remote.JMXServiceURL;
 import javax.management.remote.rmi.RMIConnectorServer;
 
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicBoolean;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
@@ -128,6 +127,9 @@ public class JmxAgent extends AbstractAgent
      */
     private Map<String, String> credentials = new HashMap<String, String>();
 
+    private JmxAgent.MuleContextStartedListener muleContextStartedListener;
+    private JmxAgent.MuleContextStoppedListener muleContextStoppedListener;
+
     static
     {
         Map<String, String> props = new HashMap<String, String>(1);
@@ -212,9 +214,11 @@ public class JmxAgent extends AbstractAgent
         try
         {
             // We need to register all the services once the server has initialised
-            muleContext.registerListener(new MuleContextStartedListener());
+            muleContextStartedListener = new MuleContextStartedListener();
+            muleContext.registerListener(muleContextStartedListener);
             // and unregister once context stopped
-            muleContext.registerListener(new MuleContextStoppedListener());
+            muleContextStoppedListener = new MuleContextStoppedListener();
+            muleContext.registerListener(muleContextStoppedListener);
         }
         catch (NotificationException e)
         {
@@ -278,8 +282,8 @@ public class JmxAgent extends AbstractAgent
             }
             if (!credentials.isEmpty())
             {
-				connectorServerProperties.put(JMXConnectorServer.AUTHENTICATOR,
-						this.getJmxAuthenticator());
+                connectorServerProperties.put(JMXConnectorServer.AUTHENTICATOR,
+                        this.getJmxAuthenticator());
             }
             connectorServer = JMXConnectorServerFactory.newJMXConnectorServer(url,
                                                                               connectorServerProperties,
@@ -317,6 +321,7 @@ public class JmxAgent extends AbstractAgent
     public void dispose()
     {
         unregisterMBeansIfNecessary();
+        unregisterListeners();
         if (serverCreated.get())
         {
             MBeanServerFactory.releaseMBeanServer(mBeanServer);
@@ -326,6 +331,12 @@ public class JmxAgent extends AbstractAgent
         initialized.set(false);
     }
 
+    private void unregisterListeners()
+    {
+        muleContext.unregisterListener(muleContextStartedListener);
+        muleContext.unregisterListener(muleContextStoppedListener);
+    }
+
     /**
      * Register a Java Service Wrapper agent.
      *
