@@ -1,5 +1,5 @@
 /*
- * $Id: ServiceStatsMBean.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,11 +13,10 @@ package org.mule.module.management.mbean;
 /**
  * <code>ServiceStatsMBean</code> TODO
  */
-public interface ServiceStatsMBean
+@Deprecated
+public interface ServiceStatsMBean extends FlowConstructStatsMBean
 {
 
-    void clearStatistics();
-
     long getAverageExecutionTime();
 
     long getAverageQueueSize();
@@ -26,18 +25,12 @@ public interface ServiceStatsMBean
 
     long getMaxExecutionTime();
 
-    long getFatalErrors();
-
     long getMinExecutionTime();
 
     long getTotalExecutionTime();
 
     long getQueuedEvents();
 
-    long getAsyncEventsReceived();
-
-    long getSyncEventsReceived();
-
     long getReplyToEventsSent();
 
     long getSyncEventsSent();
@@ -46,9 +39,6 @@ public interface ServiceStatsMBean
 
     long getTotalEventsSent();
 
-    long getTotalEventsReceived();
-
     long getExecutedEvents();
 
-    long getExecutionErrors();
 }
