@@ -1,5 +1,5 @@
 /*
- * $Id: FeedConsumeAndSplitExplicitNonHttpTestCase.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id$
  * -------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -9,10 +9,16 @@
  */
 package org.mule.module.rss;
 
-import org.mule.api.client.LocalMuleClient;
-import org.mule.tck.FunctionalTestCase;
 import org.mule.tck.functional.CounterCallback;
 import org.mule.tck.functional.FunctionalTestComponent;
+import org.mule.tck.junit4.FunctionalTestCase;
+import org.mule.tck.probe.PollingProber;
+import org.mule.tck.probe.Probe;
+import org.mule.tck.probe.Prober;
+
+import org.junit.Test;
+
+import static org.mule.module.rss.SampleFeed.ENTRIES_IN_RSS_FEED;
 
 public class FeedConsumeAndSplitExplicitNonHttpTestCase extends FunctionalTestCase
 {
@@ -31,13 +37,26 @@ public class FeedConsumeAndSplitExplicitNonHttpTestCase extends FunctionalTestCa
         comp.setEventCallback(counter);
     }
 
+    @Test
     public void testConsume() throws Exception
     {
-        LocalMuleClient client = muleContext.getClient();
-        String feed = loadResourceAsString("sample-feed.rss");
-        client.dispatch("vm://feed.in", feed, null);
-        Thread.sleep(2000);
-        int count = counter.getCallbackCount();
-        assertEquals(25, count);
+        String feed = SampleFeed.feedAsString();
+        muleContext.getClient().dispatch("vm://feed.in", feed, null);
+
+        Prober prober = new PollingProber(10000, 100);
+        prober.check(new Probe()
+        {
+            public boolean isSatisfied()
+            {
+                return counter.getCallbackCount() == ENTRIES_IN_RSS_FEED;
+            }
+
+            public String describeFailure()
+            {
+                return String.format("Did not receive %d feed entries (only got %d)",
+                    SampleFeed.ENTRIES_IN_RSS_FEED, counter.getCallbackCount());
+            }
+        });
     }
+
 }
