@@ -1,5 +1,5 @@
 /*
- * $Id: GroovyRegistryLookupTestCase.java 21599 2011-03-22 02:06:16Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,11 +12,16 @@ package org.mule.module.scripting;
 
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
 
 public class GroovyRegistryLookupTestCase extends FunctionalTestCase
 {
+
     @Override
     protected String getConfigResources()
     {
@@ -31,6 +36,7 @@ public class GroovyRegistryLookupTestCase extends FunctionalTestCase
         muleContext.getRegistry().registerObject("hello", new Hello());
     }
 
+    @Test
     public void testBindingCallout() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
