@@ -1,5 +1,5 @@
 /*
- * $Id: ScriptingConfigErrorTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,23 +13,18 @@ package org.mule.module.scripting.config;
 import org.mule.api.config.ConfigurationException;
 import org.mule.api.lifecycle.InitialisationException;
 import org.mule.context.DefaultMuleContextFactory;
+import org.mule.tck.junit4.AbstractMuleTestCase;
 
-import junit.framework.TestCase;
+import org.junit.Test;
 
-public class ScriptingConfigErrorTestCase extends TestCase
+public class ScriptingConfigErrorTestCase extends AbstractMuleTestCase
 {
-    public void testMissingEngine() throws InitialisationException
+
+    @Test(expected = ConfigurationException.class)
+    public void testMissingEngine() throws InitialisationException, ConfigurationException
     {
-        try
-        {
-            new DefaultMuleContextFactory().createMuleContext("config-error.xml");
-            fail("This config should have thrown an exception because the 'engine' attribute is required");
-        }
-        catch (ConfigurationException e)
-        {
-            // expected
-        }
-    }    
+        new DefaultMuleContextFactory().createMuleContext("config-error.xml");
+    }
 }
 
 
