@@ -1,5 +1,5 @@
 /*
- * $Id: ScriptTransformer.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -37,6 +37,8 @@ public class ScriptTransformer extends AbstractMessageTransformer
         catch (ScriptException e)
         {
             throw new TransformerException(this, e);
+        } finally {
+            bindings.clear();
         }
     }
 
