@@ -1,5 +1,5 @@
 /*
- * $Id: SingletonObjectFactoryTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,6 +10,9 @@
 
 package org.mule.object;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertSame;
+
 public class SingletonObjectFactoryTestCase extends AbstractObjectFactoryTestCase
 {
 
