@@ -1,5 +1,5 @@
 /*
- * $Id: AsyncInterceptingMessageProcessor.java 24265 2012-04-16 06:54:00Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -15,14 +15,17 @@ import org.mule.api.MessagingException;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.config.ThreadingProfile;
+import org.mule.api.construct.Pipeline;
 import org.mule.api.context.WorkManager;
 import org.mule.api.context.WorkManagerSource;
+import org.mule.api.exception.MessagingExceptionHandler;
 import org.mule.api.execution.ExecutionCallback;
 import org.mule.api.execution.ExecutionTemplate;
 import org.mule.api.lifecycle.Startable;
 import org.mule.api.lifecycle.Stoppable;
 import org.mule.api.processor.MessageProcessor;
 import org.mule.config.i18n.CoreMessages;
+import org.mule.context.notification.AsyncMessageNotification;
 import org.mule.execution.TransactionalErrorHandlingExecutionTemplate;
 import org.mule.interceptor.ProcessingTimeInterceptor;
 import org.mule.transaction.MuleTransactionConfig;
@@ -39,6 +42,9 @@ import org.mule.work.MuleWorkManager;
 public class AsyncInterceptingMessageProcessor extends AbstractInterceptingMessageProcessor
     implements Startable, Stoppable
 {
+
+    public static final String SYNCHRONOUS_EVENT_ERROR_MESSAGE = "Unable to process a synchronous event asynchronously";
+
     protected WorkManagerSource workManagerSource;
     protected boolean doThreading = true;
     protected WorkManager workManager;
@@ -128,7 +134,7 @@ public class AsyncInterceptingMessageProcessor extends AbstractInterceptingMessa
         if (event.isSynchronous() || event.isTransacted())
         {
             throw new MessagingException(
-                CoreMessages.createStaticMessage("Unable to process a synchonrous event asyncronously"),
+                CoreMessages.createStaticMessage(SYNCHRONOUS_EVENT_ERROR_MESSAGE),
                 event, this);
         }
         return doThreading && !event.isSynchronous();
@@ -140,6 +146,7 @@ public class AsyncInterceptingMessageProcessor extends AbstractInterceptingMessa
         {
             workManagerSource.getWorkManager().scheduleWork(new AsyncMessageProcessorWorker(event),
                 WorkManager.INDEFINITE, null, new AsyncWorkListener(next));
+            fireAsyncScheduledNotification(event);
         }
         catch (Exception e)
         {
@@ -148,6 +155,16 @@ public class AsyncInterceptingMessageProcessor extends AbstractInterceptingMessa
         }
     }
 
+    protected void fireAsyncScheduledNotification(MuleEvent event)
+    {
+        if (event.getFlowConstruct() instanceof Pipeline)
+        {
+            muleContext.getNotificationManager().fireNotification(
+                new AsyncMessageNotification((Pipeline) event.getFlowConstruct(), event, next,
+                    AsyncMessageNotification.PROCESS_ASYNC_SCHEDULED));
+        }
+    }
+
     class AsyncMessageProcessorWorker extends AbstractMuleEventWork
     {
         public AsyncMessageProcessorWorker(MuleEvent event)
@@ -158,7 +175,10 @@ public class AsyncInterceptingMessageProcessor extends AbstractInterceptingMessa
         @Override
         protected void doRun()
         {
-            ExecutionTemplate<MuleEvent> executionTemplate = TransactionalErrorHandlingExecutionTemplate.createMainExecutionTemplate(muleContext, new MuleTransactionConfig(), event.getFlowConstruct().getExceptionListener());
+            MessagingExceptionHandler exceptionHandler = event.getFlowConstruct() != null ? event.getFlowConstruct().getExceptionListener() : null;
+            ExecutionTemplate<MuleEvent> executionTemplate = TransactionalErrorHandlingExecutionTemplate.createMainExecutionTemplate(
+                    muleContext, new MuleTransactionConfig(), exceptionHandler);
+
             try
             {
                 executionTemplate.execute(new ExecutionCallback<MuleEvent>()
@@ -166,15 +186,24 @@ public class AsyncInterceptingMessageProcessor extends AbstractInterceptingMessa
                     @Override
                     public MuleEvent process() throws Exception
                     {
+                        MessagingException exceptionThrown = null;
                         try
                         {
                             processNextTimed(event);
-                        } catch (MessagingException e)
+                        }
+                        catch (MessagingException e)
                         {
+                            exceptionThrown = e;
                             throw e;
-                        } catch (Exception e)
+                        }
+                        catch (Exception e)
                         {
-                            throw new MessagingException(event, e, next);
+                            exceptionThrown = new MessagingException(event, e, next);
+                            throw exceptionThrown;
+                        }
+                        finally
+                        {
+                            firePipelineNotification(event, exceptionThrown);
                         }
                         return VoidMuleEvent.getInstance();
                     }
@@ -182,7 +211,7 @@ public class AsyncInterceptingMessageProcessor extends AbstractInterceptingMessa
             }
             catch (MessagingException e)
             {
-                //Already handled by TransactionTemplate
+                // Already handled by TransactionTemplate
             }
             catch (Exception e)
             {
@@ -191,4 +220,14 @@ public class AsyncInterceptingMessageProcessor extends AbstractInterceptingMessa
         }
     }
 
+    protected void firePipelineNotification(MuleEvent event, MessagingException exception)
+    {
+        if (event.getFlowConstruct() instanceof Pipeline)
+        {
+            muleContext.getNotificationManager().fireNotification(
+                new AsyncMessageNotification((Pipeline) event.getFlowConstruct(), event,
+                    next, AsyncMessageNotification.PROCESS_ASYNC_COMPLETE, exception));
+        }
+    }
+
 }
