@@ -1,5 +1,5 @@
 /*
- * $Id: IdempotentRedeliveryPolicy.java 24514 2012-06-06 03:47:15Z svacas $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,24 +11,27 @@ package org.mule.processor;
 
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
+import org.mule.api.config.MuleProperties;
 import org.mule.api.exception.MessageRedeliveredException;
 import org.mule.api.lifecycle.Disposable;
 import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.lifecycle.Startable;
 import org.mule.api.processor.MessageProcessor;
-import org.mule.api.store.ObjectAlreadyExistsException;
+import org.mule.api.store.ObjectStore;
 import org.mule.api.store.ObjectStoreException;
+import org.mule.api.store.ObjectStoreManager;
 import org.mule.api.transformer.TransformerException;
 import org.mule.config.i18n.CoreMessages;
 import org.mule.transformer.simple.ByteArrayToHexString;
 import org.mule.transformer.simple.ObjectToByteArray;
-import org.mule.util.store.AbstractMonitoredObjectStore;
-import org.mule.util.store.InMemoryObjectStore;
+import org.mule.util.lock.LockFactory;
+import org.mule.util.store.ObjectStorePartition;
 
 import java.io.InputStream;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 import java.util.concurrent.atomic.AtomicInteger;
+import java.util.concurrent.locks.Lock;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -49,7 +52,9 @@ public class IdempotentRedeliveryPolicy extends AbstractRedeliveryPolicy
     private boolean useSecureHash;
     private String messageDigestAlgorithm;
     private String idExpression;
-    private AbstractMonitoredObjectStore<AtomicInteger> store;
+    private ObjectStore<AtomicInteger> store;
+    private LockFactory lockFactory;
+    private String idrId;
 
     @Override
     public void initialise() throws InitialisationException
@@ -95,18 +100,18 @@ public class IdempotentRedeliveryPolicy extends AbstractRedeliveryPolicy
             }
         }
 
+        String appName = muleContext.getConfiguration().getId();
+        String flowName = flowConstruct.getName();
+        idrId = String.format("%s-%s-%s",appName,flowName,"idr");
+        lockFactory = muleContext.getLockFactory();
         store = createStore();
     }
 
-    private AbstractMonitoredObjectStore<AtomicInteger> createStore() throws InitialisationException
+    private ObjectStore<AtomicInteger> createStore() throws InitialisationException
     {
-        AbstractMonitoredObjectStore s = new InMemoryObjectStore<AtomicInteger>();
-        s.setName(flowConstruct.getName() + "." + getClass().getName());
-        s.setMaxEntries(-1);
-        s.setEntryTTL(60 * 5 * 1000);
-        s.setExpirationInterval(6000);
-        s.initialise();
-        return s;
+        ObjectStoreManager objectStoreManager = (ObjectStoreManager) muleContext.getRegistry().get(
+                                MuleProperties.OBJECT_STORE_MANAGER);
+        return objectStoreManager.getObjectStore(flowConstruct.getName() + "." + getClass().getName(), false, -1,  60 * 5 * 1000, 6000 );
     }
 
 
@@ -117,7 +122,17 @@ public class IdempotentRedeliveryPolicy extends AbstractRedeliveryPolicy
 
         if (store != null)
         {
-            store.dispose();
+            if (store instanceof ObjectStorePartition)
+            {
+                try
+                {
+                    ((ObjectStorePartition)store).close();
+                }
+                catch (ObjectStoreException e)
+                {
+                    logger.warn("error closing object store: " + e.getMessage(), e);
+                }
+            }
             store = null;
         }
 
@@ -159,92 +174,100 @@ public class IdempotentRedeliveryPolicy extends AbstractRedeliveryPolicy
             exceptionSeen = true;
         }
 
-        if (!exceptionSeen)
-        {
-            counter = getCounter(messageId, null, false);
-            tooMany = counter != null && counter.get() > maxRedeliveryCount;
-        }
-
-        if (tooMany || exceptionSeen)
-        {
-            try
-            {
-                if (deadLetterQueue != null)
-                {
-                    return deadLetterQueue.process(event);
-                }
-                else
-                {
-                    throw new MessageRedeliveredException(messageId,counter.get(),maxRedeliveryCount,null,event);
-                }
-            }
-            catch (MessageRedeliveredException ex)
-            {
-                throw ex;
-            }
-            catch (Exception ex)
-            {
-                logger.info("Exception thrown from failed message processing for message " + messageId, ex);
-            }
-            return null;
-        }
-
+        Lock lock = lockFactory.createLock(idrId + "-" + messageId);
+        lock.lock();
         try
         {
-            MuleEvent returnEvent = processNext(event);
-            counter = getCounter(messageId, counter, false);
-            if (counter != null)
+
+            if (!exceptionSeen)
             {
-                counter.set(0);
+                counter = findCounter(messageId);
+                tooMany = counter != null && counter.get() > maxRedeliveryCount;
+            }
+
+            if (tooMany || exceptionSeen)
+            {
+                try
+                {
+                    if (deadLetterQueue != null)
+                    {
+                        return deadLetterQueue.process(event);
+                    }
+                    else
+                    {
+                        throw new MessageRedeliveredException(messageId,counter.get(),maxRedeliveryCount,null,event);
+                    }
+                }
+                catch (MessageRedeliveredException ex)
+                {
+                    throw ex;
+                }
+                catch (Exception ex)
+                {
+                    logger.info("Exception thrown from failed message processing for message " + messageId, ex);
+                }
+                return null;
+            }
+
+            try
+            {
+                MuleEvent returnEvent = processNext(event);
+                counter = findCounter(messageId);
+                if (counter != null)
+                {
+                    resetCounter(messageId);
+                }
+                return returnEvent;
+            }
+            catch (MuleException ex)
+            {
+                incrementCounter(messageId);
+                throw ex;
+            }
+            catch (RuntimeException ex)
+            {
+                incrementCounter(messageId);
+                throw ex;
             }
-            return returnEvent;
         }
-        catch (MuleException ex)
+        finally
         {
-            incrementCounter(messageId, counter);
-            throw ex;
-        }
-        catch (RuntimeException ex)
-        {
-            incrementCounter(messageId, counter);
-            throw ex;
+            lock.unlock();
         }
+
     }
 
-
-    private AtomicInteger incrementCounter(String messageId, AtomicInteger counter) throws ObjectStoreException
+    private void resetCounter(String messageId) throws ObjectStoreException
     {
-        counter = getCounter(messageId,  counter, true);
-        counter.incrementAndGet();
-        return counter;
+        store.remove(messageId);
+        store.store(messageId, new AtomicInteger());
     }
 
-    private AtomicInteger getCounter(String messageId, AtomicInteger counter, boolean create) throws ObjectStoreException
+    public AtomicInteger findCounter(String messageId) throws ObjectStoreException
     {
-        if (counter != null)
-        {
-            return counter;
-        }
         boolean counterExists = store.contains(messageId);
         if (counterExists)
         {
             return store.retrieve(messageId);
         }
-        if (create)
-        {
-            try
-            {
-                counter = new AtomicInteger();
-                store.store(messageId, counter);
-            }
-            catch (ObjectAlreadyExistsException e)
-            {
-                counter = store.retrieve(messageId);
-            }
-        }
-        return counter;
+        return null;
     }
 
+    private AtomicInteger incrementCounter(String messageId) throws ObjectStoreException
+    {
+        AtomicInteger counter = findCounter(messageId);
+        if (counter == null)
+        {
+            counter = new AtomicInteger();
+        }
+        else
+        {
+            store.remove(messageId);
+        }
+        counter.incrementAndGet();
+        store.store(messageId,counter);
+        return counter;
+    }
 
     private String getIdForEvent(MuleEvent event) throws Exception
     {
@@ -302,3 +325,4 @@ public class IdempotentRedeliveryPolicy extends AbstractRedeliveryPolicy
         this.deadLetterQueue = processor;
     }
 }
+
