@@ -1,5 +1,5 @@
 /*
- * $Id: InvokerMessageProcessor.java 21301 2011-02-17 00:29:42Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
  *
@@ -12,6 +12,7 @@ package org.mule.processor;
 
 import org.mule.DefaultMuleEvent;
 import org.mule.DefaultMuleMessage;
+import org.mule.api.AnnotatedObject;
 import org.mule.api.MessagingException;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
@@ -43,6 +44,9 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.concurrent.ConcurrentHashMap;
+
+import javax.xml.namespace.QName;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -56,14 +60,14 @@ import org.apache.commons.logging.LogFactory;
  * methods with the same name and same number of arguments are not supported
  * currently.
  */
-public class InvokerMessageProcessor implements MessageProcessor, Initialisable, MuleContextAware
+public class InvokerMessageProcessor implements MessageProcessor, Initialisable, MuleContextAware, AnnotatedObject
 {
     protected final transient Log logger = LogFactory.getLog(getClass());
 
     protected Object object;
     protected Class<?> objectType;
     protected String methodName;
-    protected List<?> arguments = new ArrayList<Object>();;
+    protected List<?> arguments = new ArrayList<Object>();
     protected Class<?>[] argumentTypes;
     protected String name;
     protected PatternInfo patternInfo = TemplateParser.createMuleStyleParser().getStyle();
@@ -71,7 +75,9 @@ public class InvokerMessageProcessor implements MessageProcessor, Initialisable,
     protected Method method;
     protected ExpressionManager expressionManager;
     protected MuleContext muleContext;
+    private final Map<QName, Object> annotations = new ConcurrentHashMap<QName, Object>();
 
+    @Override
     public void initialise() throws InitialisationException
     {
         if (object == null)
@@ -151,6 +157,7 @@ public class InvokerMessageProcessor implements MessageProcessor, Initialisable,
         }
     }
 
+    @Override
     public MuleEvent process(MuleEvent event) throws MuleException
     {
         MuleEvent resultEvent = event;
@@ -172,7 +179,7 @@ public class InvokerMessageProcessor implements MessageProcessor, Initialisable,
         }
         catch (Exception e)
         {
-            throw new MessagingException(CoreMessages.failedToInvoke(object.toString()), event, e);
+            throw new MessagingException(CoreMessages.failedToInvoke(object.toString()), event, e, this);
         }
         return resultEvent;
     }
@@ -198,7 +205,7 @@ public class InvokerMessageProcessor implements MessageProcessor, Initialisable,
         }
         catch (TransformerException e)
         {
-            throw new MessagingException(event, e);
+            throw new MessagingException(event, e, this);
         }
     }
 
@@ -345,6 +352,7 @@ public class InvokerMessageProcessor implements MessageProcessor, Initialisable,
             name, object, methodName, arguments, argumentTypes);
     }
 
+    @Override
     public void setMuleContext(MuleContext context)
     {
         this.muleContext = context;
@@ -355,4 +363,19 @@ public class InvokerMessageProcessor implements MessageProcessor, Initialisable,
         this.objectType = objectType;
     }
 
+    public final Object getAnnotation(QName name)
+    {
+        return annotations.get(name);
+    }
+
+    public final Map<QName, Object> getAnnotations()
+    {
+        return Collections.unmodifiableMap(annotations);
+    }
+
+    public synchronized final void setAnnotations(Map<QName, Object> newAnnotations)
+    {
+        annotations.clear();
+        annotations.putAll(newAnnotations);
+    }
 }
