@@ -1,5 +1,5 @@
 /*
- * $Id: SedaStageInterceptingMessageProcessor.java 22870 2011-09-05 20:41:52Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,7 +11,7 @@
 package org.mule.processor;
 
 import org.mule.DefaultMuleEvent;
-import org.mule.RequestContext;
+import org.mule.OptimizedRequestContext;
 import org.mule.api.MessagingException;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
@@ -19,7 +19,7 @@ import org.mule.api.MuleException;
 import org.mule.api.NameableObject;
 import org.mule.api.config.ThreadingProfile;
 import org.mule.api.context.WorkManager;
-import org.mule.api.exception.MessagingExceptionHandler;
+import org.mule.api.execution.ExecutionCallback;
 import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.lifecycle.Lifecycle;
 import org.mule.api.lifecycle.LifecycleCallback;
@@ -29,6 +29,7 @@ import org.mule.api.service.FailedToQueueEventException;
 import org.mule.config.QueueProfile;
 import org.mule.config.i18n.CoreMessages;
 import org.mule.config.i18n.MessageFactory;
+import org.mule.execution.TransactionalErrorHandlingExecutionTemplate;
 import org.mule.lifecycle.EmptyLifecycleCallback;
 import org.mule.management.stats.QueueStatistics;
 import org.mule.service.Pausable;
@@ -37,7 +38,6 @@ import org.mule.util.concurrent.WaitableBoolean;
 import org.mule.util.queue.Queue;
 import org.mule.util.queue.QueueConfiguration;
 import org.mule.util.queue.QueueSession;
-import org.mule.work.AbstractMuleEventWork;
 import org.mule.work.MuleWorkManager;
 
 import java.text.MessageFormat;
@@ -116,6 +116,7 @@ public class SedaStageInterceptingMessageProcessor extends AsyncInterceptingMess
                 getStageDescription(), event));
         }
         queue.put(event);
+        fireAsyncScheduledNotification(event);
     }
 
     protected MuleEvent dequeue() throws Exception
@@ -163,44 +164,6 @@ public class SedaStageInterceptingMessageProcessor extends AsyncInterceptingMess
         }
     }
 
-    private class SedaStageWorker extends AbstractMuleEventWork
-    {
-        public SedaStageWorker(MuleEvent event)
-        {
-            super(event);
-        }
-
-        @Override
-        protected void doRun()
-        {
-            try
-            {
-                // Create a copy of the event for the new thread
-                event = RequestContext.setEvent(event);
-                doWork();
-            }
-            catch (MuleException e)
-            {
-                MessagingExceptionHandler exceptionListener = event.getFlowConstruct().getExceptionListener();
-                if (e instanceof MessagingException)
-                {
-                    exceptionListener.handleException(e, event);
-                }
-                else
-                {
-                    exceptionListener.handleException(
-                        new MessagingException(CoreMessages.eventProcessingFailedFor(getStageDescription()),
-                            event, e), event);
-                }
-            }
-        }
-
-        public void doWork() throws MuleException
-        {
-            processNextTimed(event);
-        }
-    }
-
     /**
      * While the service isn't stopped this runs a continuous loop checking for new events in the queue.
      */
@@ -256,57 +219,54 @@ public class SedaStageInterceptingMessageProcessor extends AsyncInterceptingMess
 
             if (event != null)
             {
-                if (isStatsEnabled())
+                final MuleEvent eventToProcess = event;
+                TransactionalErrorHandlingExecutionTemplate executionTemplate = TransactionalErrorHandlingExecutionTemplate.createMainExecutionTemplate(muleContext, event.getFlowConstruct().getExceptionListener());
+                ExecutionCallback<MuleEvent> processingCallback = new ExecutionCallback<MuleEvent>()
                 {
-                    queueStatistics.decQueuedEvent();
-                }
 
-                if (logger.isDebugEnabled())
-                {
-                    logger.debug(MessageFormat.format("{0}: Dequeued event from {1}", getStageDescription(),
-                        getQueueName()));
-                }
-                SedaStageWorker work = new SedaStageWorker(event);
-                if (doThreading)
-                {
-                    try
+                    @Override
+                    public MuleEvent process() throws Exception
                     {
-                        // TODO Remove this thread handoff to ensure Zero Message Loss
-                        workManagerSource.getWorkManager().scheduleWork(work, WorkManager.INDEFINITE, null,
-                            new AsyncWorkListener(next));
-                    }
-                    catch (Exception e)
-                    {
-                        // This is a work manager exception, not a Mule event-related exception
-                        event.getFlowConstruct().getExceptionListener().handleException(e, event);
-                    }
-                }
-                else
-                {
-                    try
-                    {
-                        work.doWork();
-                    }
-                    catch (MuleException e)
-                    {
-                        MessagingExceptionHandler exceptionListener = event.getFlowConstruct()
-                            .getExceptionListener();
-                        if (e instanceof MessagingException)
+                        if (isStatsEnabled())
                         {
-                            exceptionListener.handleException(e, event);
-                        }
-                        else
-                        {
-                            exceptionListener.handleException(
-                                new MessagingException(
-                                    CoreMessages.eventProcessingFailedFor(getStageDescription()), event, e),
-                                event);
+                            queueStatistics.decQueuedEvent();
                         }
 
-                        // TODO Enable this to ensure Zero Message Loss
-                        // (although it will cause an infinite loop without some kind of redelivery policy)
-                        // rollbackDequeue(event);
+                        if (logger.isDebugEnabled())
+                        {
+                            logger.debug(MessageFormat.format("{0}: Dequeued event from {1}",
+                                getStageDescription(), getQueueName()));
+                        }
+                        AsyncMessageProcessorWorker work = new AsyncMessageProcessorWorker(eventToProcess);
+                        try
+                        {
+                            // TODO Remove this thread handoff to ensure Zero Message Loss
+                            workManagerSource.getWorkManager().scheduleWork(work, WorkManager.INDEFINITE,
+                                null, new AsyncWorkListener(next));
+                        }
+                        catch (Exception e)
+                        {
+                            // because dequeued event may still be owned by a previuos
+                            // thread we need to use the copy created in AsyncMessageProcessorWorker
+                            // constructor.
+                            OptimizedRequestContext.unsafeSetEvent(work.getEvent());
+                            throw new MessagingException(work.getEvent(), e, SedaStageInterceptingMessageProcessor.this);
+                        }
+                        return null;
                     }
+                };
+
+                try
+                {
+                    executionTemplate.execute(processingCallback);
+                }
+                catch (MessagingException e)
+                {
+                    //Already handled by processing template
+                }
+                catch (Exception e)
+                {
+                    muleContext.getExceptionListener().handleException(e);
                 }
             }
         }
