@@ -1,5 +1,5 @@
 /*
- * $Id: IdempotentSecureHashMessageFilter.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -44,9 +44,11 @@ public class IdempotentSecureHashMessageFilter extends IdempotentMessageFilter
     {
         try
         {
+            Object payload = event.getMessage().getPayload();
+            byte[] bytes = (byte[]) objectToByteArray.transform(payload);
             MessageDigest md = MessageDigest.getInstance(messageDigestAlgorithm);
-            return (String)byteArrayToHexString.transform(md.digest((byte[]) objectToByteArray.transform(event.getMessage()
-                .getPayload())));
+            byte[] digestedBytes = md.digest(bytes);
+            return (String)byteArrayToHexString.transform(digestedBytes);
         }
         catch (NoSuchAlgorithmException nsa)
         {
