@@ -1,5 +1,5 @@
 /*
- * $Id: ServiceCatchAllStrategy.java 20343 2010-11-24 21:02:10Z mike.schilling $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,6 +10,7 @@
 
 package org.mule.routing;
 
+import org.mule.VoidMuleEvent;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.routing.RoutingException;
@@ -36,11 +37,11 @@ public class ServiceCatchAllStrategy extends AbstractCatchAllStrategy
         logger.debug("Catch all strategy handling event: " + event);
         try
         {
-            if (event.getEndpoint().getExchangePattern().hasResponse())
+            if (event.getExchangePattern().hasResponse())
             {
                 if (statistics.isEnabled())
                 {
-                    statistics.incrementRoutedMessage(event.getEndpoint());
+                    statistics.incrementRoutedMessage(event.getMessageSourceName());
                 }
                 return ((Service) event.getFlowConstruct()).sendEvent(event);
             }
@@ -48,10 +49,10 @@ public class ServiceCatchAllStrategy extends AbstractCatchAllStrategy
             {
                 if (statistics.isEnabled())
                 {
-                    statistics.incrementRoutedMessage(event.getEndpoint());
+                    statistics.incrementRoutedMessage(event.getMessageSourceName());
                 }
                 ((Service) event.getFlowConstruct()).dispatchEvent(event);
-                return null;
+                return VoidMuleEvent.getInstance();
             }
         }
         catch (MuleException e)
