@@ -1,5 +1,5 @@
 /*
- * $Id: SimpleCollectionAggregator.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -7,6 +7,7 @@
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
+
 package org.mule.routing;
 
 import org.mule.api.MuleContext;
@@ -14,17 +15,18 @@ import org.mule.routing.correlation.CollectionCorrelatorCallback;
 import org.mule.routing.correlation.EventCorrelatorCallback;
 
 /**
- * This router will return all aggregated events as a {@link org.mule.api.MuleMessageCollection}.
- * This allows the service itself to act upon the events rather that the user having to write a custom
- * aggregator.  This may feel more natural for some users.
- *
- * <b>EIP Reference:</b> <a href="http://www.eaipatterns.com/Aggregator.html">http://www.eaipatterns.com/Aggregator.html</a>
+ * This router will return all aggregated events as a
+ * {@link org.mule.api.MuleMessageCollection}. This allows the service itself to act
+ * upon the events rather that the user having to write a custom aggregator. This may
+ * feel more natural for some users. <b>EIP Reference:</b> <a
+ * href="http://www.eaipatterns.com/Aggregator.html"
+ * >http://www.eaipatterns.com/Aggregator.html</a>
  */
 public class SimpleCollectionAggregator extends AbstractAggregator
 {
     @Override
     protected EventCorrelatorCallback getCorrelatorCallback(MuleContext muleContext)
     {
-        return new CollectionCorrelatorCallback(muleContext);
+        return new CollectionCorrelatorCallback(muleContext, persistentStores, storePrefix);
     }
 }
