@@ -10,13 +10,21 @@
 
 package org.mule.routing;
 
-import org.mule.RequestContext;
+import org.mule.DefaultMuleEvent;
+import org.mule.OptimizedRequestContext;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.processor.MessageProcessor;
 import org.mule.api.routing.filter.Filter;
 import org.mule.processor.AbstractFilteringMessageProcessor;
-import org.mule.processor.AbstractMessageObserver;
+import org.mule.processor.AbstractMessageProcessorOwner;
+import org.mule.util.ObjectUtils;
+
+import java.util.Collections;
+import java.util.List;
+
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 
 /**
  * The <code>WireTap</code> MessageProcessor allows inspection of messages in a flow.
@@ -32,32 +40,34 @@ import org.mule.processor.AbstractMessageObserver;
  * <p>
  * <b>EIP Reference:</b> <a href="http://www.eaipatterns.com/WireTap.html">http://www.eaipatterns.com/WireTap.html<a/>
  */
-public class WireTap extends AbstractMessageObserver
-
+public class WireTap extends AbstractMessageProcessorOwner implements MessageProcessor
 {
+    protected final transient Log logger = LogFactory.getLog(getClass());
     protected volatile MessageProcessor tap;
     protected volatile Filter filter;
 
     protected MessageProcessor filteredTap = new WireTapFilter();
 
-    @Override
-    public void observe(MuleEvent event)
+    public MuleEvent process(MuleEvent event) throws MuleException
     {
         if (tap == null)
         {
-            return;
+            return event;
         }
 
         try
         {
-            // Do we need this?
-            RequestContext.setEvent(null);
-            filteredTap.process(RequestContext.cloneAndUpdateEventEndpoint(event, tap));
+            MuleEvent tapEvent = DefaultMuleEvent.copy(event);
+            OptimizedRequestContext.unsafeSetEvent(tapEvent);
+            filteredTap.process(tapEvent);
+            OptimizedRequestContext.unsafeSetEvent(event);
         }
         catch (MuleException e)
         {
             logger.error("Exception sending to wiretap output " + tap, e);
         }
+
+        return event;
     }
 
     public MessageProcessor getTap()
@@ -110,6 +120,24 @@ public class WireTap extends AbstractMessageObserver
             }
             return null;
         }
+
+        @Override
+        public String toString()
+        {
+            return ObjectUtils.toString(this);
+        }
+    }
+
+    @Override
+    public String toString()
+    {
+        return ObjectUtils.toString(this);
+    }
+
+        @Override
+    protected List<MessageProcessor> getOwnedMessageProcessors()
+    {
+        return Collections.singletonList(tap);
     }
 
 }
