@@ -1,5 +1,5 @@
 /*
- * $Id: ResequenceCorrelatorCallback.java 22506 2011-07-21 16:30:40Z stephen.fenech $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -65,7 +65,7 @@ public class ResequenceCorrelatorCallback extends CollectionCorrelatorCallback
         {
             try
             {
-                results = events.toArray();
+                results = events.toArray(false);
             }
             catch (ObjectStoreException e)
             {
