@@ -1,5 +1,5 @@
 /*
- * $Id: MessagePropertyFilterTestCase.java 22377 2011-07-11 12:41:42Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,9 +10,13 @@
 
 package org.mule.routing.filters;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+
+import org.mule.DefaultMuleEvent;
 import org.mule.DefaultMuleMessage;
 import org.mule.MessageExchangePattern;
-import org.mule.RequestContext;
 import org.mule.api.MuleMessage;
 import org.mule.api.transport.PropertyScope;
 import org.mule.tck.junit4.AbstractMuleContextTestCase;
@@ -22,10 +26,6 @@ import java.util.Map;
 
 import org.junit.Test;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-
 public class MessagePropertyFilterTestCase extends AbstractMuleContextTestCase
 {
     @Test
@@ -42,7 +42,9 @@ public class MessagePropertyFilterTestCase extends AbstractMuleContextTestCase
     public void testMessagePropertyFilterSessionScope() throws Exception
     {
         MuleMessage message = new DefaultMuleMessage("blah", muleContext);
-        RequestContext.setEvent(getTestEvent(message));
+        // An event/session is needed otherwise the session properties set on the message go nowhere.
+        new DefaultMuleEvent(message, getTestInboundEndpoint(MessageExchangePattern.ONE_WAY),
+            getTestService());
         MessagePropertyFilter filter = new MessagePropertyFilter("foo=bar");
         filter.setScope(PropertyScope.SESSION_NAME);
         assertFalse(filter.accept(message));
@@ -54,7 +56,6 @@ public class MessagePropertyFilterTestCase extends AbstractMuleContextTestCase
     public void testMessagePropertyFilterInboundScope() throws Exception
     {
         DefaultMuleMessage message = new DefaultMuleMessage("blah", muleContext);
-        RequestContext.setEvent(getTestEvent(message));
         MessagePropertyFilter filter = new MessagePropertyFilter("inbound:foo=bar");
         assertEquals("inbound", filter.getScope());
 
@@ -67,7 +68,6 @@ public class MessagePropertyFilterTestCase extends AbstractMuleContextTestCase
     public void testMessagePropertyFilterWithURL() throws Exception
     {
         DefaultMuleMessage message = new DefaultMuleMessage("blah", muleContext);
-        RequestContext.setEvent(getTestEvent(message));
         MessagePropertyFilter filter = new MessagePropertyFilter("inbound:foo=http://foo.com");
         assertEquals("inbound", filter.getScope());
 
@@ -78,9 +78,9 @@ public class MessagePropertyFilterTestCase extends AbstractMuleContextTestCase
         message = new DefaultMuleMessage("blah", inboundProps, null, null, muleContext);
         assertTrue("Filter didn't accept the message", filter.accept(message));
 
-        //Checking here that a ':' in the value doesn't throw things off
+        // Checking here that a ':' in the value doesn't throw things off
         filter = new MessagePropertyFilter("bar=http://bar.com");
-        //default scope
+        // default scope
         assertEquals("outbound", filter.getScope());
 
         assertFalse(filter.accept(message));
@@ -125,7 +125,6 @@ public class MessagePropertyFilterTestCase extends AbstractMuleContextTestCase
         assertTrue("Filter didn't accept the message", filter.accept(message));
     }
 
-
     @Test
     public void testMessagePropertyFilterWithWildcard() throws Exception
     {
@@ -163,7 +162,6 @@ public class MessagePropertyFilterTestCase extends AbstractMuleContextTestCase
         assertFalse(filter.accept(message));
     }
 
-
     @Test
     public void testMessagePropertyFilterPropertyExists() throws Exception
     {
