@@ -1,5 +1,5 @@
 /*
- * $Id: OGNLFilterTestCase.java 20527 2010-12-08 21:13:02Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,17 +10,31 @@
 
 package org.mule.routing.filters;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.fail;
+
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
 import org.mule.DefaultMuleMessage;
 import org.mule.api.MuleMessage;
 import org.mule.api.config.ConfigurationException;
 import org.mule.api.routing.OutboundRouterCollection;
+import org.mule.construct.Flow;
 import org.mule.module.client.MuleClient;
 import org.mule.module.ognl.filters.OGNLFilter;
+import org.mule.routing.MessageFilter;
 import org.mule.routing.outbound.FilteringOutboundRouter;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 
-public class OGNLFilterTestCase extends FunctionalTestCase
+public class OGNLFilterTestCase extends AbstractServiceAndFlowTestCase
 {
+
     public static final String DEFAULT_INPUT_QUEUE = "vm://in";
     public static final String DEFUALT_OUTPUT_QUEUE = "vm://out";
     public static final String FIRST_MESSAGE = "foo";
@@ -30,12 +44,19 @@ public class OGNLFilterTestCase extends FunctionalTestCase
     public static final String OGNL_EXSPRESSION = " equals(\"foo\") || content.endsWith(\"bar\") ";
     public static final String SERVICE_NAME = "OGNLServiceWrapper1";
 
-    protected String getConfigResources()
+    private OGNLFilter filter;
+
+    public OGNLFilterTestCase(ConfigVariant variant, String configResources)
     {
-        return "ognl-functional-test.xml";
+        super(variant, configResources);
     }
 
-    private OGNLFilter filter;
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{{ConfigVariant.SERVICE, "ognl-functional-test-service.xml"},
+            {ConfigVariant.FLOW, "ognl-functional-test-flow.xml"}});
+    }
 
     @Override
     protected void doSetUp() throws Exception
@@ -49,32 +70,47 @@ public class OGNLFilterTestCase extends FunctionalTestCase
         filter = null;
     }
 
+    @Test
     public void testNewFilter()
     {
         assertFalse(filter.accept(null));
     }
 
+    @Test
     public void testNoExpressionEmptyMessage()
     {
         MuleMessage message = new DefaultMuleMessage(null, muleContext);
         assertFalse(filter.accept(message));
     }
 
+    @Test
     public void testNoExpressionValidMessage()
     {
         MuleMessage message = new DefaultMuleMessage("foo", muleContext);
         assertFalse(filter.accept(message));
     }
 
+    @Test
     public void testNamespaceHandler()
     {
-        String expression = ((OGNLFilter) ((FilteringOutboundRouter) ((OutboundRouterCollection) muleContext.getRegistry()
-            .lookupService(SERVICE_NAME)
-            .getOutboundMessageProcessor()).getRoutes().get(0)).getFilter()).getExpression();
+        String expression;
+
+        if (variant.equals(ConfigVariant.SERVICE))
+        {
+            expression = ((OGNLFilter) ((FilteringOutboundRouter) ((OutboundRouterCollection) muleContext.getRegistry()
+                .lookupService(SERVICE_NAME)
+                .getOutboundMessageProcessor()).getRoutes().get(0)).getFilter()).getExpression();
+        }
+        else
+        {
+            expression = ((OGNLFilter) ((MessageFilter) ((Flow) muleContext.getRegistry()
+                .lookupFlowConstruct(SERVICE_NAME)).getMessageProcessors().get(0)).getFilter()).getExpression();
+        }
 
         assertEquals(expression, OGNL_EXSPRESSION);
     }
 
+    @Test
     public void testFunctionalTest() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -104,10 +140,9 @@ public class OGNLFilterTestCase extends FunctionalTestCase
         {
             client.dispose();
         }
-
     }
 
-
+    @Test
     public void testFunctionalTestUsingExpressionFilter() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -137,9 +172,9 @@ public class OGNLFilterTestCase extends FunctionalTestCase
         {
             client.dispose();
         }
-
     }
 
+    @Test
     public void testInvalidObjectExpression()
     {
         try
