@@ -1,5 +1,5 @@
 /*
- * $Id: OutboundRoutingTestEvent.java 23797 2012-02-02 04:07:49Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -336,4 +336,14 @@ public class OutboundRoutingTestEvent implements MuleEvent
     {
     }
 
+    @Override
+    public boolean isNotificationsEnabled()
+    {
+        return true;
+    }
+
+    @Override
+    public void setEnableNotifications(boolean enabled)
+    {
+    }
 }
