@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractAuthenticationFilter.java 21251 2011-02-11 00:23:49Z dandiep $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,9 +10,7 @@
 
 package org.mule.security;
 
-import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
-import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.security.AuthenticationFilter;
 import org.mule.api.security.CredentialsAccessor;
@@ -26,11 +24,9 @@ import org.mule.api.security.UnknownAuthenticationTypeException;
  * <code>AbstractEndpointSecurityFilter</code> provides a framework to perform inbound
  * or outbound authentication for messages.
  */
-
 public abstract class AbstractAuthenticationFilter extends AbstractSecurityFilter implements AuthenticationFilter
 {
     private boolean authenticate;
-    protected MuleContext muleContext;
     private CredentialsAccessor credentialsAccessor;
 
     public CredentialsAccessor getCredentialsAccessor()
@@ -60,26 +56,9 @@ public abstract class AbstractAuthenticationFilter extends AbstractSecurityFilte
         authenticate(event);
     }
 
-    public void authenticate(MuleEvent event)
+    public abstract void authenticate(MuleEvent event)
             throws SecurityException, UnknownAuthenticationTypeException, CryptoFailureException,
             SecurityProviderNotFoundException, EncryptionStrategyNotFoundException,
-            InitialisationException
-    {
-        if (event.getEndpoint() instanceof InboundEndpoint)
-        {
-            authenticateInbound(event);
-        }
-        else
-        {
-            authenticateOutbound(event);
-        }
-    }
-
-    protected abstract void authenticateInbound(MuleEvent event)
-            throws SecurityException, CryptoFailureException, SecurityProviderNotFoundException,
-            EncryptionStrategyNotFoundException, UnknownAuthenticationTypeException;
-
-    protected abstract void authenticateOutbound(MuleEvent event)
-            throws SecurityException, SecurityProviderNotFoundException, CryptoFailureException;
+            InitialisationException;
 
 }
