@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractMuleTestCase.java 22606 2011-08-07 14:19:00Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -71,7 +71,9 @@ import org.apache.commons.logging.LogFactory;
 /**
  * <code>AbstractMuleTestCase</code> is a base class for Mule testcases. This
  * implementation provides services to test code for creating mock and test objects.
+ * @deprecated Use {@link org.mule.tck.junit4.AbstractMuleTestCase}
  */
+@Deprecated
 public abstract class AbstractMuleTestCase extends TestCase implements TestCaseWatchdogTimeoutHandler
 {
 
@@ -950,8 +952,6 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
     /**
      * Determines if the test case should perform graceful shutdown or not.
      * Default is false so that tests run more quickly.
-     *
-     * @return
      */
     protected boolean isGracefulShutdown()
     {
