@@ -15,7 +15,10 @@ package org.mule.tck;
  * Extend this class instead of FunctionalTestCase to add dynamic port support to
  * your tests. The test will need to only implement 'getNumPortsToFind' to tell this
  * class how many free test ports to find.
+ *
+ * @deprecated: use {@link org.mule.tck.junit4.rule.DynamicPort} in a JUnit 4 test.
  */
+@Deprecated
 public abstract class DynamicPortTestCase extends FunctionalTestCase
 {
     protected abstract int getNumPortsToFind();
@@ -23,8 +26,8 @@ public abstract class DynamicPortTestCase extends FunctionalTestCase
     public DynamicPortTestCase()
     {
         super();
-        
-        // each test class sets the number of free ports to find 
+
+        // each test class sets the number of free ports to find
         numPorts = getNumPortsToFind();
     }
 
@@ -32,8 +35,6 @@ public abstract class DynamicPortTestCase extends FunctionalTestCase
     protected void doSetUp() throws Exception
     {
         super.doSetUp();
-        // see if the ports are available, tests should fail if they are not
-        //checkPorts(false, "SETUP");
     }
 
     @Override
@@ -42,11 +43,6 @@ public abstract class DynamicPortTestCase extends FunctionalTestCase
         super.doTearDown();
         // make sure that the ports have been freed. It's not a fatal error, but we
         // want to track down why it's not being released
-        checkPorts(false, "TEARDOWN");
-        
-        //find a new set of ports so the next test does not fail, regardless of the current ports not being available
-        //ports = findFreePorts(getNumPortsToFind());
-        // this will propagate to the mule configuration
-        //setPortProperties();        
+        PortUtils.checkPorts(false, "TEARDOWN", getPorts());
     }
 }
