@@ -1,5 +1,5 @@
 /*
- * $Id: MuleTestUtils.java 21929 2011-05-17 14:26:50Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,7 +10,6 @@
 
 package org.mule.tck;
 
-import org.mule.DefaultMuleContext;
 import org.mule.DefaultMuleEvent;
 import org.mule.MessageExchangePattern;
 import org.mule.RequestContext;
@@ -24,22 +23,17 @@ import org.mule.api.component.JavaComponent;
 import org.mule.api.construct.FlowConstruct;
 import org.mule.api.context.MuleContextAware;
 import org.mule.api.endpoint.EndpointBuilder;
-import org.mule.api.endpoint.EndpointURI;
 import org.mule.api.endpoint.ImmutableEndpoint;
 import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.api.endpoint.OutboundEndpoint;
 import org.mule.api.routing.filter.Filter;
 import org.mule.api.service.Service;
-import org.mule.api.transaction.Transaction;
 import org.mule.api.transaction.TransactionConfig;
-import org.mule.api.transaction.TransactionFactory;
 import org.mule.api.transformer.Transformer;
 import org.mule.api.transport.Connector;
-import org.mule.api.transport.MessageDispatcher;
-import org.mule.api.transport.MessageDispatcherFactory;
 import org.mule.api.transport.MuleMessageFactory;
 import org.mule.component.DefaultJavaComponent;
-import org.mule.construct.SimpleFlowConstruct;
+import org.mule.construct.Flow;
 import org.mule.endpoint.EndpointURIEndpointBuilder;
 import org.mule.endpoint.MuleEndpointURI;
 import org.mule.model.seda.SedaModel;
@@ -56,8 +50,6 @@ import org.mule.transaction.MuleTransactionConfig;
 import org.mule.transport.AbstractConnector;
 import org.mule.util.ClassUtils;
 
-import com.mockobjects.dynamic.Mock;
-
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -113,6 +105,7 @@ public final class MuleTestUtils
     {
         return (InboundEndpoint) getTestEndpoint(name, null, null, null, null, context, new EndpointSource()
         {
+            @Override
             public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
             {
                 return context.getEndpointFactory().getInboundEndpoint(builder);
@@ -125,6 +118,7 @@ public final class MuleTestUtils
     {
         return (OutboundEndpoint) getTestEndpoint(name, null, null, null, null, context, new EndpointSource()
         {
+            @Override
             public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
             {
                 return context.getEndpointFactory().getOutboundEndpoint(builder);
@@ -143,6 +137,7 @@ public final class MuleTestUtils
         return (InboundEndpoint) getTestEndpoint(name, uri, transformers, filter, properties, context,
             new EndpointSource()
             {
+                @Override
                 public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
                 {
                     return context.getEndpointFactory().getInboundEndpoint(builder);
@@ -160,6 +155,7 @@ public final class MuleTestUtils
         return (OutboundEndpoint) getTestEndpoint(name, uri, transformers, filter, properties, context,
             new EndpointSource()
             {
+                @Override
                 public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
                 {
                     return context.getEndpointFactory().getOutboundEndpoint(builder);
@@ -167,6 +163,24 @@ public final class MuleTestUtils
             }, null);
     }
 
+    public static InboundEndpoint getTestInboundEndpoint(String name,
+                                                           final MuleContext context,
+                                                           String uri,
+                                                           List<Transformer> transformers,
+                                                           Filter filter,
+                                                           Map<Object, Object> properties) throws Exception
+    {
+        return (InboundEndpoint) getTestEndpoint(name, uri, transformers, filter, properties, context,
+            new EndpointSource()
+            {
+                @Override
+                public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
+                {
+                    return context.getEndpointFactory().getInboundEndpoint(builder);
+                }
+            }, null);
+    }
+
     public static OutboundEndpoint getTestOutboundEndpoint(String name,
                                                            final MuleContext context,
                                                            String uri,
@@ -178,6 +192,7 @@ public final class MuleTestUtils
         return (OutboundEndpoint) getTestEndpoint(name, uri, transformers, filter, properties, context,
             new EndpointSource()
             {
+                @Override
                 public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
                 {
                     builder.setConnector(connector);
@@ -193,6 +208,7 @@ public final class MuleTestUtils
     {
         return (OutboundEndpoint) getTestEndpoint(null, uri, null, null, null, context, new EndpointSource()
         {
+            @Override
             public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
             {
                 builder.setConnector(connector);
@@ -208,6 +224,7 @@ public final class MuleTestUtils
     {
         return (OutboundEndpoint) getTestEndpoint(name, null, null, null, null, context, new EndpointSource()
         {
+            @Override
             public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
             {
                 builder.setExchangePattern(mep);
@@ -221,6 +238,7 @@ public final class MuleTestUtils
     {
         return (OutboundEndpoint) getTestEndpoint(null, null, null, null, null, context, new EndpointSource()
         {
+            @Override
             public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
             {
                 builder.setExchangePattern(mep);
@@ -236,6 +254,7 @@ public final class MuleTestUtils
     {
         return (InboundEndpoint) getTestEndpoint(name, null, null, null, null, context, new EndpointSource()
         {
+            @Override
             public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
             {
                 builder.setExchangePattern(mep);
@@ -249,6 +268,7 @@ public final class MuleTestUtils
     {
         return (InboundEndpoint) getTestEndpoint(null, null, null, null, null, context, new EndpointSource()
         {
+            @Override
             public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
             {
                 builder.setExchangePattern(mep);
@@ -256,17 +276,17 @@ public final class MuleTestUtils
             }
         }, null);
     }
-    
+
     public static InboundEndpoint getTestTransactedInboundEndpoint(final MessageExchangePattern mep,
                                                          final MuleContext context) throws Exception
     {
         return (InboundEndpoint) getTestEndpoint(null, null, null, null, null, context, new EndpointSource()
         {
+            @Override
             public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
             {
                 builder.setExchangePattern(mep);
-                TransactionConfig txConfig = new MuleTransactionConfig();
-                txConfig.setAction(TransactionConfig.ACTION_BEGIN_OR_JOIN);
+                TransactionConfig txConfig = new MuleTransactionConfig(TransactionConfig.ACTION_BEGIN_OR_JOIN);
                 txConfig.setFactory(new TestTransactionFactory());
                 builder.setTransactionConfig(txConfig);
                 return context.getEndpointFactory().getInboundEndpoint(builder);
@@ -364,6 +384,7 @@ public final class MuleTestUtils
     {
         return getTestSchemeMetaInfoEndpoint(name, protocol, context, new EndpointSource()
         {
+            @Override
             public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
             {
                 return context.getEndpointFactory().getInboundEndpoint(builder);
@@ -378,6 +399,7 @@ public final class MuleTestUtils
     {
         return getTestSchemeMetaInfoEndpoint(name, protocol, context, new EndpointSource()
         {
+            @Override
             public ImmutableEndpoint getEndpoint(EndpointBuilder builder) throws MuleException
             {
                 return context.getEndpointFactory().getOutboundEndpoint(builder);
@@ -422,24 +444,25 @@ public final class MuleTestUtils
     {
         return getTestEvent(data, getTestFlow(context), mep, context);
     }
-    
-    public static MuleEvent getTestInboundEvent(Object data, MuleContext context) throws Exception
-    {
-        return getTestInboundEvent(data, getTestService(context), MessageExchangePattern.REQUEST_RESPONSE,
-            context);
-    }
 
-    public static MuleEvent getTestInboundEvent(Object data, MessageExchangePattern mep, MuleContext context)
-        throws Exception
-    {
-        return getTestInboundEvent(data, getTestService(context), mep, context);
-    }
+//    public static MuleEvent getTestInboundEvent(Object data, MuleContext context) throws Exception
+//    {
+//        return getTestInboundEvent(data, getTestService(context), MessageExchangePattern.REQUEST_RESPONSE,
+//            context);
+//    }
+//
+//    public static MuleEvent getTestInboundEvent(Object data, MessageExchangePattern mep, MuleContext context)
+//        throws Exception
+//    {
+//        return getTestInboundEvent(data, getTestService(context), mep, context);
+//    }
 
     /** Supply service but no endpoint */
+    @Deprecated
     public static MuleEvent getTestEvent(Object data, Service service, MuleContext context) throws Exception
     {
-        return getTestEvent(data, service, getTestOutboundEndpoint("test1",
-            MessageExchangePattern.REQUEST_RESPONSE, context), context);
+        return getTestEvent(data, service, getTestInboundEndpoint("test1",
+            MessageExchangePattern.REQUEST_RESPONSE, context, null), context);
     }
 
     public static MuleEvent getTestEvent(Object data,
@@ -447,26 +470,26 @@ public final class MuleTestUtils
                                          MessageExchangePattern mep,
                                          MuleContext context) throws Exception
     {
-        return getTestEvent(data, flowConstruct, getTestOutboundEndpoint("test1", mep, context), context);
+        return getTestEvent(data, flowConstruct, getTestInboundEndpoint("test1", mep, context, null), context);
     }
 
-    public static MuleEvent getTestInboundEvent(Object data, Service service, MuleContext context)
-        throws Exception
-    {
-        return getTestEvent(data, service, getTestInboundEndpoint("test1",
-            MessageExchangePattern.REQUEST_RESPONSE, context, null), context);
-    }
-
-    public static MuleEvent getTestInboundEvent(Object data,
-                                                Service service,
-                                                MessageExchangePattern mep,
-                                                MuleContext context) throws Exception
-    {
-        return getTestEvent(data, service, getTestInboundEndpoint("test1", mep, context, null), context);
-    }
+//    public static MuleEvent getTestInboundEvent(Object data, Service service, MuleContext context)
+//        throws Exception
+//    {
+//        return getTestEvent(data, service, getTestInboundEndpoint("test1",
+//            MessageExchangePattern.REQUEST_RESPONSE, context, null), context);
+//    }
+//
+//    public static MuleEvent getTestInboundEvent(Object data,
+//                                                Service service,
+//                                                MessageExchangePattern mep,
+//                                                MuleContext context) throws Exception
+//    {
+//        return getTestEvent(data, service, getTestInboundEndpoint("test1", mep, context, null), context);
+//    }
 
     /** Supply endpoint but no service */
-    public static MuleEvent getTestEvent(Object data, ImmutableEndpoint endpoint, MuleContext context)
+    public static MuleEvent getTestEvent(Object data, InboundEndpoint endpoint, MuleContext context)
         throws Exception
     {
         return getTestEvent(data, getTestService(context), endpoint, context);
@@ -474,7 +497,7 @@ public final class MuleTestUtils
 
     public static MuleEvent getTestEvent(Object data,
                                          FlowConstruct flowConstruct,
-                                         ImmutableEndpoint endpoint,
+                                         InboundEndpoint endpoint,
                                          MuleContext context) throws Exception
     {
         final MuleSession session = getTestSession(flowConstruct, context);
@@ -482,10 +505,10 @@ public final class MuleTestUtils
         final MuleMessageFactory factory = endpoint.getConnector().createMuleMessageFactory();
         final MuleMessage message = factory.create(data, endpoint.getEncoding());
 
-        return new DefaultMuleEvent(message, endpoint, session);
+        return new DefaultMuleEvent(message, endpoint, flowConstruct, session);
     }
 
-    public static MuleEvent getTestInboundEvent(Object data, MuleSession session, MuleContext context)
+    public static MuleEvent getTestEvent(Object data, MuleSession session, MuleContext context)
         throws Exception
     {
         final InboundEndpoint endpoint = getTestInboundEndpoint("test1",
@@ -493,7 +516,7 @@ public final class MuleTestUtils
         final MuleMessageFactory factory = endpoint.getConnector().createMuleMessageFactory();
         final MuleMessage message = factory.create(data, endpoint.getEncoding());
 
-        return new DefaultMuleEvent(message, endpoint, session);
+        return new DefaultMuleEvent(message, endpoint, getTestService(context), session);
     }
 
     public static MuleEventContext getTestEventContext(Object data,
@@ -521,7 +544,7 @@ public final class MuleTestUtils
 
     public static MuleSession getTestSession(FlowConstruct flowConstruct, MuleContext context)
     {
-        return new DefaultMuleSession(flowConstruct, context);
+        return new DefaultMuleSession();
     }
 
     public static MuleSession getTestSession(MuleContext context)
@@ -537,32 +560,36 @@ public final class MuleTestUtils
         return testConnector;
     }
 
+    @Deprecated
     public static Service getTestService(MuleContext context) throws Exception
     {
         return getTestService("appleService", Apple.class, context);
     }
-    
-    public static SimpleFlowConstruct getTestFlow(MuleContext context) throws Exception
+
+    public static Flow getTestFlow(MuleContext context) throws Exception
     {
         return getTestFlow("appleFlow", context);
     }
 
+    @Deprecated
     public static Service getTestService(String name, Class<?> clazz, MuleContext context) throws Exception
     {
         return getTestService(name, clazz, null, context);
     }
 
+    @Deprecated
     public static Service getTestService(String name, Class<?> clazz, Map props, MuleContext context)
         throws Exception
     {
         return getTestService(name, clazz, props, context, true);
     }
 
-    public static SimpleFlowConstruct getTestFlow(String name, MuleContext context) throws Exception
+    public static Flow getTestFlow(String name, MuleContext context) throws Exception
     {
         return getTestFlow(name, context, true);
     }
 
+    @Deprecated
     public static Service getTestService(String name,
                                          Class<?> clazz,
                                          Map props,
@@ -588,11 +615,11 @@ public final class MuleTestUtils
 
         return service;
     }
-    
-    public static SimpleFlowConstruct getTestFlow(String name, MuleContext context, boolean initialize)
+
+    public static Flow getTestFlow(String name, MuleContext context, boolean initialize)
         throws Exception
     {
-        final SimpleFlowConstruct flow = new SimpleFlowConstruct(name, context);
+        final Flow flow = new Flow(name, context);
         if (initialize)
         {
             context.getRegistry().registerFlowConstruct(flow);
@@ -607,60 +634,4 @@ public final class MuleTestUtils
         t.initialise();
         return t;
     }
-
-    public static Mock getMockSession()
-    {
-        return new Mock(MuleSession.class, "umoSession");
-    }
-
-    public static Mock getMockMessageDispatcher()
-    {
-        return new Mock(MessageDispatcher.class, "umoMessageDispatcher");
-    }
-
-    public static Mock getMockMessageDispatcherFactory()
-    {
-        return new Mock(MessageDispatcherFactory.class, "umoMessageDispatcherFactory");
-    }
-
-    public static Mock getMockConnector()
-    {
-        return new Mock(Connector.class, "umoConnector");
-    }
-
-    public static Mock getMockEvent()
-    {
-        return new Mock(MuleEvent.class, "umoEvent");
-    }
-
-    public static Mock getMockMuleContext()
-    {
-        return new Mock(DefaultMuleContext.class, "muleMuleContext");
-    }
-
-    public static Mock getMockInboundEndpoint()
-    {
-        return new Mock(InboundEndpoint.class, "umoEndpoint");
-    }
-
-    public static Mock getMockOutboundEndpoint()
-    {
-        return new Mock(OutboundEndpoint.class, "umoEndpoint");
-    }
-
-    public static Mock getMockEndpointURI()
-    {
-        return new Mock(EndpointURI.class, "umoEndpointUri");
-    }
-
-    public static Mock getMockTransaction()
-    {
-        return new Mock(Transaction.class, "umoTransaction");
-    }
-
-    public static Mock getMockTransactionFactory()
-    {
-        return new Mock(TransactionFactory.class, "umoTransactionFactory");
-    }
-
 }
