@@ -1,5 +1,5 @@
 /*
- * $Id: MockEncryptionStrategy.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -14,6 +14,9 @@ import org.mule.api.EncryptionStrategy;
 import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.security.CryptoFailureException;
 
+import java.io.ByteArrayInputStream;
+import java.io.InputStream;
+
 /**
  * Empty mock for tests
  */
@@ -35,4 +38,14 @@ public class MockEncryptionStrategy extends Named implements EncryptionStrategy
         // nothing to do
     }
 
+    public InputStream decrypt(InputStream data, Object info) throws CryptoFailureException
+    {
+        return new ByteArrayInputStream(new byte[0]);
+    }
+
+    public InputStream encrypt(InputStream data, Object info) throws CryptoFailureException
+    {
+        return new ByteArrayInputStream(new byte[0]);
+    }
+
 }
