@@ -1,5 +1,5 @@
 /*
- * $Id: TestTransaction.java 21939 2011-05-18 13:32:09Z aperepel $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,6 +13,7 @@ import org.mule.api.MuleContext;
 import org.mule.api.transaction.TransactionException;
 import org.mule.transaction.AbstractSingleResourceTransaction;
 
+import javax.transaction.Transaction;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 /**
@@ -25,12 +26,31 @@ public class TestTransaction extends AbstractSingleResourceTransaction
     private AtomicBoolean rolledBack = new AtomicBoolean(false);
 
     private String testProperty;
+    private boolean isXA;
 
     public TestTransaction(MuleContext muleContext)
     {
         super(muleContext);
     }
 
+    @Override
+    protected Class getResourceType()
+    {
+        return null;  //To change body of implemented methods use File | Settings | File Templates.
+    }
+
+    @Override
+    protected Class getKeyType()
+    {
+        return null;  //To change body of implemented methods use File | Settings | File Templates.
+    }
+
+    public TestTransaction(MuleContext mockMuleContext, boolean isXa)
+    {
+        super(mockMuleContext);
+        this.isXA = isXa;
+    }
+
     /**
      * Really begin the transaction. Note that resources are enlisted yet.
      *
@@ -73,4 +93,36 @@ public class TestTransaction extends AbstractSingleResourceTransaction
     {
         this.testProperty = testProperty;
     }
+
+    @Override
+    public boolean isXA()
+    {
+        return isXA;
+    }
+
+
+    public void setXA(boolean xa)
+    {
+        isXA = xa;
+    }
+
+    @Override
+    public Transaction suspend() throws TransactionException
+    {
+        if (isXA)
+        {
+            return null;
+        }
+        return super.suspend();
+    }
+
+    @Override
+    public void resume() throws TransactionException
+    {
+        if (isXA)
+        {
+            return;
+        }
+        super.suspend();
+    }
 }
