@@ -1,5 +1,5 @@
 /*
- * $Id: DataTypesTestCase.java 22377 2011-07-11 12:41:42Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,6 +11,7 @@ package org.mule.transformer;
 
 import org.mule.api.transformer.DataType;
 import org.mule.tck.junit4.AbstractMuleTestCase;
+import org.mule.tck.size.SmallTest;
 import org.mule.transformer.types.CollectionDataType;
 import org.mule.transformer.types.DataTypeFactory;
 import org.mule.transformer.types.MimeTypes;
@@ -27,6 +28,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
+@SmallTest
 public class DataTypesTestCase extends AbstractMuleTestCase
 {
     //Just used for testing
