@@ -1,5 +1,5 @@
 /*
- * $Id: ConnectableLifecycleManager.java 20696 2010-12-14 07:53:32Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -55,7 +55,7 @@ public class ConnectableLifecycleManager<O> extends SimpleLifecycleManager<O>
     public void fireStopPhase(LifecycleCallback<O> callback) throws MuleException
     {
         // We are sometimes stopped by our owner when already stopped
-        if (currentPhase == Stoppable.PHASE_NAME)
+        if (currentPhase.equals(Stoppable.PHASE_NAME))
         {
             return;
         }
