@@ -1,5 +1,5 @@
 /*
- * $Id: RetrieveMessageReceiver.java 24172 2012-03-26 15:09:22Z saveli.vassiliev $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -54,6 +54,8 @@ public class RetrieveMessageReceiver extends AbstractPollingMessageReceiver impl
     private Folder moveToFolder = null;
     private boolean backupEnabled;
     private String backupFolder = null;
+    // A lock to protect concurrent access to the folder.
+    private final Object folderLock = new Object();
 
     public RetrieveMessageReceiver(Connector connector,
                                    FlowConstruct flowConstruct,
@@ -109,9 +111,12 @@ public class RetrieveMessageReceiver extends AbstractPollingMessageReceiver impl
     @Override
     protected void doStop()
     {
-        if (folder != null)
+        synchronized (folderLock)
         {
-            folder.removeMessageCountListener(this);
+            if (folder != null)
+            {
+                folder.removeMessageCountListener(this);
+            }
         }
     }
 
@@ -119,7 +124,10 @@ public class RetrieveMessageReceiver extends AbstractPollingMessageReceiver impl
     protected void doStart() throws MuleException
     {
         super.doStart();
-        folder.addMessageCountListener(this);
+        synchronized (folderLock)
+        {
+            folder.addMessageCountListener(this);
+        }
     }
 
     public void messagesAdded(MessageCountEvent event) 
@@ -133,7 +141,7 @@ public class RetrieveMessageReceiver extends AbstractPollingMessageReceiver impl
                 MuleMessage message = null;
                 for (int i = 0; i < messages.length; i++)
                 {
-                    if (getLifecycleState().isStopping())
+                    if (getLifecycleState().isStopping() || getLifecycleState().isStopped())
                     {
                         break;
                     }
@@ -249,15 +257,15 @@ public class RetrieveMessageReceiver extends AbstractPollingMessageReceiver impl
     }
 
     /** @param folder */
-    public synchronized void setFolder(Folder folder)
+    public void setFolder(Folder folder)
     {
-        if (folder == null)
-        {
-            throw new IllegalArgumentException("Mail folder cannot be null");
-        }
-        this.folder = folder;
-        synchronized (this.folder)
+        synchronized (folderLock)
         {
+            if (folder == null)
+            {
+                throw new IllegalArgumentException("Mail folder cannot be null");
+            }
+            this.folder = folder;
             if (!this.folder.isOpen())
             {
                 try
@@ -315,62 +323,65 @@ public class RetrieveMessageReceiver extends AbstractPollingMessageReceiver impl
     }
 
     @Override
-    public synchronized void poll()
+    public void poll()
     {
         boolean done = false;
         while (!done)
         {
-            if (getLifecycleState().isStopping())
-            {
-                break;
-            }
-            try
+            synchronized (folderLock)
             {
+                if (getLifecycleState().isStopping() || getLifecycleState().isStopped())
+                {
+                    break;
+                }
                 try
                 {
-                    if (!folder.isOpen())
+                    try
                     {
-                        folder.open(Folder.READ_WRITE);
+                        if (!folder.isOpen())
+                        {
+                            folder.open(Folder.READ_WRITE);
+                        }
                     }
-                }
-                catch (Exception e)
-                {
-                    if (logger.isDebugEnabled())
+                    catch (Exception e)
                     {
-                        logger.debug("ignoring exception: " + e.getMessage());
+                        if (logger.isDebugEnabled())
+                        {
+                            logger.debug("ignoring exception: " + e.getMessage());
+                        }
                     }
-                }
 
-                int count = folder.getMessageCount();
-                int batchSize = getBatchSize(count);
-                if (count > 0)
-                {
-                    Message[] messages = folder.getMessages(1, batchSize);
-                    MessageCountEvent event = new MessageCountEvent(folder, MessageCountEvent.ADDED, true,
-                        messages);
-                    messagesAdded(event);
+                    int count = folder.getMessageCount();
+                    int batchSize = getBatchSize(count);
+                    if (count > 0)
+                    {
+                        Message[] messages = folder.getMessages(1, batchSize);
+                        MessageCountEvent event = new MessageCountEvent(folder, MessageCountEvent.ADDED, true,
+                            messages);
+                        messagesAdded(event);
+                    }
+                    else if (count == -1)
+                    {
+                        throw new MessagingException("Cannot monitor folder: " + folder.getFullName()
+                            + " as folder is closed");
+                    }
+                    done = batchSize >= count;
                 }
-                else if (count == -1)
+                catch (MessagingException e)
                 {
-                    throw new MessagingException("Cannot monitor folder: " + folder.getFullName()
-                        + " as folder is closed");
+                    done = true;
+                    getConnector().getMuleContext().getExceptionListener().handleException(e);
                 }
-                done = batchSize >= count;
-            }
-            catch (MessagingException e)
-            {
-                done = true;
-                getConnector().getMuleContext().getExceptionListener().handleException(e);
-            }
-            finally
-            {
-                try
+                finally
                 {
-                    folder.close(true); // close and expunge deleted messages
-                }
-                catch (Exception e)
-                {
-                    logger.error("Failed to close pop3  inbox: " + e.getMessage());
+                    try
+                    {
+                        folder.close(true); // close and expunge deleted messages
+                    }
+                    catch (Exception e)
+                    {
+                        logger.error("Failed to close pop3  inbox: " + e.getMessage());
+                    }
                 }
             }
         }
@@ -386,19 +397,21 @@ public class RetrieveMessageReceiver extends AbstractPollingMessageReceiver impl
     @Override
     protected void doDispose()
     {
-        if (null != folder)
+        synchronized (folderLock)
         {
-            folder.removeMessageCountListener(this);
-            if (folder.isOpen())
+            if (null != folder)
             {
-                try
+                folder.removeMessageCountListener(this);
+                if (folder.isOpen())
                 {
-
-                    folder.close(true);
-                }
-                catch (Exception e)
-                {
-                    logger.debug("ignoring exception: " + e.getMessage(), e);
+                    try
+                    {
+                        folder.close(true);
+                    }
+                    catch (Exception e)
+                    {
+                        logger.debug("ignoring exception: " + e.getMessage(), e);
+                    }
                 }
             }
         }
