@@ -1,5 +1,5 @@
 /*
- * $Id: Pop3ConnectorTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -23,7 +23,7 @@ public class Pop3ConnectorTestCase extends AbstractReceivingMailConnectorTestCas
 
     public Pop3ConnectorTestCase()
     {
-        super(ServerSetup.PROTOCOL_POP3, 50010);
+        super(ServerSetup.PROTOCOL_POP3);
     }
 
     public Connector createConnector() throws Exception
