@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractEmailFunctionalTestCase.java 20799 2010-12-19 05:56:37Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,21 +10,31 @@
 
 package org.mule.transport.email.functional;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import org.mule.DefaultMuleMessage;
+import org.mule.api.MuleContext;
 import org.mule.api.MuleMessage;
 import org.mule.config.i18n.LocaleMessageHandler;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
 import org.mule.transport.email.GreenMailUtilities;
 import org.mule.transport.email.ImapConnector;
 import org.mule.transport.email.MailProperties;
 import org.mule.transport.email.Pop3Connector;
 import org.mule.util.SystemUtils;
 
+import com.icegreen.greenmail.user.GreenMailUser;
 import com.icegreen.greenmail.util.GreenMail;
 import com.icegreen.greenmail.util.ServerSetup;
 
+import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
@@ -35,7 +45,9 @@ import javax.mail.Message;
 import javax.mail.internet.MimeMessage;
 import javax.mail.internet.MimeMultipart;
 
-public abstract class AbstractEmailFunctionalTestCase extends DynamicPortTestCase
+import org.junit.Rule;
+
+public abstract class AbstractEmailFunctionalTestCase extends AbstractServiceAndFlowTestCase
 {
     public static final long DELIVERY_DELAY_MS = 10000;
 
@@ -47,11 +59,11 @@ public abstract class AbstractEmailFunctionalTestCase extends DynamicPortTestCas
     protected static final String DEFAULT_USER = "bob";
     protected static final String DEFAULT_MESSAGE = "Test email message";
     protected static final String DEFAULT_PASSWORD = "password";
-
+    protected static final String DEFAULT_PROCESSED_MAILBOX = "processed";
+    
     private String protocol;
     private boolean isMimeMessage;
-    private int port;
-    private String configFile;
+    private int port;    
     protected GreenMail server;
     private String email;
     private String user;
@@ -59,53 +71,68 @@ public abstract class AbstractEmailFunctionalTestCase extends DynamicPortTestCas
     private String password;
     private String charset;
     private boolean addAttachments;
+    protected ServerSetup setup = null;
+    // for tests which need to send emails in addition to receiving them
+    protected ServerSetup smtpSetup = null;
+    private int smtpPort;
+    private boolean addSmtp = false;
 
-    protected AbstractEmailFunctionalTestCase(boolean isMimeMessage, String protocol)
+    @Rule
+    public DynamicPort dynamicPort1 = new DynamicPort("port1");
+
+    @Rule
+    public DynamicPort dynamicPort2 = new DynamicPort("port2");
+
+
+    protected AbstractEmailFunctionalTestCase(ConfigVariant variant, boolean isMimeMessage, String protocol)
     {
-        this(isMimeMessage, protocol, protocol + CONFIG_BASE, null, null);
+        this(variant, isMimeMessage, protocol, protocol + CONFIG_BASE, null, null);
     }
 
-    protected AbstractEmailFunctionalTestCase(boolean isMimeMessage, String protocol, Locale locale, String charset)
+    protected AbstractEmailFunctionalTestCase(ConfigVariant variant, boolean isMimeMessage, String protocol, Locale locale, String charset)
     {
-        this(isMimeMessage, protocol, protocol + CONFIG_BASE, locale, charset);
+        this(variant, isMimeMessage, protocol, protocol + CONFIG_BASE, locale, charset);
     }
 
-    protected AbstractEmailFunctionalTestCase(boolean isMimeMessage, String protocol, String configFile)
+    protected AbstractEmailFunctionalTestCase(ConfigVariant variant, boolean isMimeMessage, String protocol, String configResources)
     {
-        this(isMimeMessage, protocol, configFile, null, null);
+        this(variant, isMimeMessage, protocol, configResources, null, null);
     }
 
-    protected AbstractEmailFunctionalTestCase(boolean isMimeMessage, String protocol, String configFile, Locale locale, String charset)
+    protected AbstractEmailFunctionalTestCase(ConfigVariant variant, boolean isMimeMessage, String protocol, String configResources, boolean addSmtp)
     {
-        this(isMimeMessage, protocol, configFile,
+        this(variant, isMimeMessage, protocol, configResources, null, null);
+        this.addSmtp = addSmtp;
+    }    
+    
+    protected AbstractEmailFunctionalTestCase(ConfigVariant variant, boolean isMimeMessage, String protocol, String configResources, Locale locale, String charset)
+    {
+        this(variant, isMimeMessage, protocol, configResources,
                 DEFAULT_EMAIL, DEFAULT_USER, (locale == null ? DEFAULT_MESSAGE : getMessage(locale)), DEFAULT_PASSWORD, charset);
     }
 
-    protected AbstractEmailFunctionalTestCase(boolean isMimeMessage, String protocol,
-        String configFile, String email, String user, String message, String password, String charset)
+    protected AbstractEmailFunctionalTestCase(ConfigVariant variant, boolean isMimeMessage, String protocol,
+        String configResources, String email, String user, String message, String password, String charset)
     {
+        super(variant, configResources);
         this.isMimeMessage = isMimeMessage;
-        this.protocol = protocol;
-        this.configFile = configFile;
+        this.protocol = protocol;        
         this.email = email;
         this.user = user;
         this.message = message;
         this.password = password;
         this.charset = charset;
     }
-
+    
     @Override
-    protected String getConfigResources()
+    protected MuleContext createMuleContext() throws Exception
     {
-        return configFile;
-    }
-
-    @Override
-    protected void suitePreSetUp() throws Exception
-    {
-        this.port = getPorts().get(0);
+        this.port = dynamicPort1.getNumber();
+        this.smtpPort = dynamicPort2.getNumber();
         startServer();
         initDefaultCommandMap();
+
+        return super.createMuleContext();
     }
 
     /**
@@ -123,9 +150,9 @@ public abstract class AbstractEmailFunctionalTestCase extends DynamicPortTestCas
     }
 
     @Override
-    protected void suitePostTearDown() throws Exception
+    public void doTearDown()
     {
-        stopServer();
+        server.stop();
     }
 
     protected void doSend() throws Exception
@@ -223,18 +250,61 @@ public abstract class AbstractEmailFunctionalTestCase extends DynamicPortTestCas
     private void startServer() throws Exception
     {
         logger.debug("starting server on port " + port);
-        ServerSetup setup = new ServerSetup(port, null, protocol);
-        server = new GreenMail(setup);
+        
+        setup = new ServerSetup(port, null, protocol);
+        if(addSmtp)
+        {
+            smtpSetup = new ServerSetup(smtpPort, null, "smtp");
+            server = new GreenMail(new ServerSetup[]{setup, smtpSetup});
+        }
+        else
+        {
+            server = new GreenMail(setup);
+        }           
+        
+        server.getManagers().getUserManager().createUser(email, user, password);
+        GreenMailUser gmUser = server.getManagers().getUserManager().getUser(user);
+        assert null != gmUser;
+        server.getManagers().getImapHostManager().createMailbox(
+                server.getManagers().getUserManager().getUser(DEFAULT_USER), 
+                DEFAULT_PROCESSED_MAILBOX);
+        
         server.start();
         if (protocol.startsWith(Pop3Connector.POP3) || protocol.startsWith(ImapConnector.IMAP))
         {
-            GreenMailUtilities.storeEmail(server.getManagers().getUserManager(),
-                    email, user, password,
-                    GreenMailUtilities.toMessage(message, email, charset));
+            generateAndStoreEmail();
         }
         logger.debug("server started for protocol " + protocol);
     }
 
+    /**
+     * Generates and store emails on the server.
+     *
+     * @throws Exception If there's a problem with the storing of the messages in the server.
+     */
+    protected void generateAndStoreEmail() throws Exception
+    {
+        List<MimeMessage> messages = new ArrayList<MimeMessage>();
+        messages.add(GreenMailUtilities.toMessage(message, email, charset));
+        storeEmail(messages);
+    }
+
+    /**
+     * Helper method to store email on the server. Can be overriden by subclasses if other tests want to store
+     * a different list of messages.
+     *
+     * @param messages The list of messages to be stored.
+     * @throws Exception If there's a problem with the storing of the messages in the server.
+     */
+    protected void storeEmail(List<MimeMessage> messages) throws Exception
+    {
+        for (MimeMessage message : messages)
+        {
+            GreenMailUtilities.storeEmail(server.getManagers().getUserManager(),
+                                          email, user, password, message);
+        }
+    }
+
     private void stopServer()
     {
         server.stop();
@@ -245,12 +315,6 @@ public abstract class AbstractEmailFunctionalTestCase extends DynamicPortTestCas
         return LocaleMessageHandler.getString("test-data", locale, "AbstractEmailFunctionalTestCase.getMessage", new Object[] {});
     }
 
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 1;
-    }
-
     public void setAddAttachments(boolean addAttachments)
     {
         this.addAttachments = addAttachments;
