@@ -1,5 +1,5 @@
 /*
- * $Id: ImapFunctionalTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,17 +10,32 @@
 
 package org.mule.transport.email.functional;
 
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
 public class ImapFunctionalTestCase extends AbstractEmailFunctionalTestCase
 {
 
-    public ImapFunctionalTestCase()
+    public ImapFunctionalTestCase(ConfigVariant variant, String configResources)
     {
-        super(65433, STRING_MESSAGE, "imap");
+        super(variant, STRING_MESSAGE, "imap", configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "imap-functional-test-service.xml"},
+            {ConfigVariant.FLOW, "imap-functional-test-flow.xml"}
+        });
+    }      
+    
+    @Test
     public void testRequest() throws Exception
     {
         doRequest();
     }
-
 }
