@@ -1,5 +1,5 @@
 /*
- * $Id: ImapMessageRequesterTestCase.java 20738 2010-12-15 02:42:53Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,52 +12,33 @@ package org.mule.transport.email.functional;
 
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
 import org.mule.transport.email.GreenMailUtilities;
 import org.mule.transport.email.ImapConnector;
-import org.mule.transport.email.Pop3Connector;
 
 import com.icegreen.greenmail.util.GreenMail;
 import com.icegreen.greenmail.util.ServerSetup;
 
-public class ImapMessageRequesterTestCase extends DynamicPortTestCase
+import org.junit.Rule;
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
+public class ImapMessageRequesterTestCase extends FunctionalTestCase
 {
     private static final String EMAIL = "bob@example.com";
     private static final String MESSAGE = "Test email message";
     private static final String PASSWORD = "password";
     private static int PORT = -1;
     private static final String USER = "bob";
-    
+
     private GreenMail server;
 
-    public ImapMessageRequesterTestCase()
-    {
-        super();
-    }
+    @Rule
+    public DynamicPort dynamicPort = new DynamicPort("port1");
 
-    @Override
-    protected void suitePreSetUp() throws Exception
-    {
-        super.doSetUp();
-        PORT = getPorts().get(0);
-        startGreenmailServer();
-    }    
-    
-    private void startGreenmailServer() throws Exception
-    {
-        ServerSetup setup = new ServerSetup(PORT, null, ImapConnector.IMAP);
-        server = new GreenMail(setup);
-        server.start();
-        GreenMailUtilities.storeEmail(server.getManagers().getUserManager(), EMAIL, USER, PASSWORD,
-            GreenMailUtilities.toMessage(MESSAGE, EMAIL, null));
-    }
-            
-    @Override
-    protected void doTearDown() throws Exception
-    {
-        server.stop();
-        super.doTearDown();
-    }
 
     @Override
     protected String getConfigResources()
@@ -65,6 +46,31 @@ public class ImapMessageRequesterTestCase extends DynamicPortTestCase
         return "imap-message-requester.xml";
     }
 
+    @Override
+    protected void doSetUp() throws Exception
+    {
+        super.doSetUp();
+        PORT = dynamicPort.getNumber();
+        startGreenmailServer();
+    }
+
+    private void startGreenmailServer() throws Exception
+    {
+        ServerSetup setup = new ServerSetup(PORT, "localhost", ImapConnector.IMAP);
+        server = new GreenMail(setup);
+        server.start();
+        GreenMailUtilities.storeEmail(server.getManagers().getUserManager(), EMAIL, USER, PASSWORD,
+            GreenMailUtilities.toMessage(MESSAGE, EMAIL, null));
+    }
+
+    @Override
+    protected void doTearDown() throws Exception
+    {
+        server.stop();
+        super.doTearDown();
+    }
+
+    @Test
     public void testMessageRequester() throws Exception
     {
         String imapUri = String.format("imap://%1s:%2s@localhost:%3d/INBOX", USER, PASSWORD, PORT);
@@ -76,11 +82,6 @@ public class ImapMessageRequesterTestCase extends DynamicPortTestCase
         assertEquals(MESSAGE, message.getPayload());
     }
 
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 1;
-    }
 }
 
 
