@@ -1,5 +1,5 @@
 /*
- * $Id: ImapsFunctionalTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,13 +11,30 @@
 package org.mule.transport.email.functional;
 
 
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
 public class ImapsFunctionalTestCase extends AbstractEmailFunctionalTestCase
 {
-    public ImapsFunctionalTestCase()
+
+    public ImapsFunctionalTestCase(ConfigVariant variant, String configResources)
     {
-        super(STRING_MESSAGE, "imaps");
+        super(variant, STRING_MESSAGE, "imaps", configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "imaps-functional-test-service.xml"},
+            {ConfigVariant.FLOW, "imaps-functional-test-flow.xml"}
+        });
+    }      
+    
+    @Test
     public void testRequest() throws Exception
     {
         doRequest();
