@@ -1,5 +1,5 @@
 /*
- * $Id: Pop3FunctionalTestCase.java 19873 2010-10-08 23:54:59Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,14 +10,30 @@
 
 package org.mule.transport.email.functional;
 
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
 public class Pop3FunctionalTestCase extends AbstractEmailFunctionalTestCase
 {
 
-    public Pop3FunctionalTestCase()
+    public Pop3FunctionalTestCase(ConfigVariant variant, String configResources)
     {
-        super(STRING_MESSAGE, "pop3");
+        super(variant, STRING_MESSAGE, "pop3", configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "pop3-functional-test-service.xml"},
+            {ConfigVariant.FLOW, "pop3-functional-test-flow.xml"}
+        });
+    }      
+    
+    @Test
     public void testRequest() throws Exception
     {
         doRequest();
