@@ -1,5 +1,5 @@
 /*
- * $Id: Pop3sFunctionalTestCase.java 19873 2010-10-08 23:54:59Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,15 +11,33 @@
 package org.mule.transport.email.functional;
 
 
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
 public class Pop3sFunctionalTestCase extends AbstractEmailFunctionalTestCase
 {
-    public Pop3sFunctionalTestCase()
+
+    public Pop3sFunctionalTestCase(ConfigVariant variant, String configResources)
     {
-        super(STRING_MESSAGE, "pop3s");
+        super(variant, STRING_MESSAGE, "pop3s", configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "pop3s-functional-test-service.xml"},
+            {ConfigVariant.FLOW, "pop3s-functional-test-flow.xml"}
+        });
+    }      
+    
+    @Test
     public void testRequest() throws Exception
     {
         doRequest();
     }
+
 }
