@@ -1,5 +1,5 @@
 /*
- * $Id: SmtpMimeNonAsciiFunctionalTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,16 +10,31 @@
 
 package org.mule.transport.email.functional;
 
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.Locale;
 
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
 public class SmtpMimeNonAsciiFunctionalTestCase extends AbstractEmailFunctionalTestCase
 {
 
-    public SmtpMimeNonAsciiFunctionalTestCase()
+    public SmtpMimeNonAsciiFunctionalTestCase(ConfigVariant variant, String configResources)
     {
-        super(65438, MIME_MESSAGE, "smtp", "smtp-mime-functional-test.xml", Locale.JAPAN, "iso-2022-jp");
+        super(variant, MIME_MESSAGE, "smtp", configResources, Locale.JAPAN, "iso-2022-jp");
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "smtp-mime-functional-test-service.xml"},
+            {ConfigVariant.FLOW, "smtp-mime-functional-test-flow.xml"}
+        });
+    }      
+    
+    @Test
     public void testSend() throws Exception
     {
         doSend();
