@@ -1,5 +1,5 @@
 /*
- * $Id: SmtpNonAsciiFunctionalTestCase.java 19874 2010-10-09 00:00:10Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,16 +10,31 @@
 
 package org.mule.transport.email.functional;
 
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.Locale;
 
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
 public class SmtpNonAsciiFunctionalTestCase extends AbstractEmailFunctionalTestCase
 {
 
-    public SmtpNonAsciiFunctionalTestCase()
+    public SmtpNonAsciiFunctionalTestCase(ConfigVariant variant, String configResources)
     {
-        super(STRING_MESSAGE, "smtp", Locale.JAPAN, "iso-2022-jp");
+        super(variant, STRING_MESSAGE, "smtp", configResources, Locale.JAPAN, "iso-2022-jp");
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "smtp-functional-test-service.xml"},
+            {ConfigVariant.FLOW, "smtp-functional-test-flow.xml"}
+        });
+    }      
+    
+    @Test
     public void testSend() throws Exception
     {
         doSend();
