@@ -1,5 +1,5 @@
 /*
- * $Id: ExceptionHandlingMule2167TestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,19 +12,31 @@ package org.mule.transport.email.issues;
 
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
 
-public class ExceptionHandlingMule2167TestCase extends DynamicPortTestCase
+import org.junit.Rule;
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
+public class ExceptionHandlingMule2167TestCase extends FunctionalTestCase
 {
 
     public static final String MESSAGE = "a message";
     public static final long WAIT_MS = 3000L;
 
+    @Rule
+    public DynamicPort dynamicPort = new DynamicPort("port1");
+
+    @Override
     protected String getConfigResources()
     {
         return "exception-handling-mule-2167-test.xml";
     }
 
+    @Test
     public void testDefaultConfig() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -35,10 +47,4 @@ public class ExceptionHandlingMule2167TestCase extends DynamicPortTestCase
         assertEquals(MESSAGE, message.getPayloadAsString());
     }
 
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 1;
-    }
-
 }
