@@ -1,5 +1,5 @@
 /*
- * $Id: ObjectToMimeMessage.java 19965 2010-10-18 21:40:52Z mike.schilling $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,6 +13,7 @@ package org.mule.transport.email.transformers;
 import org.mule.api.MuleMessage;
 import org.mule.api.transformer.TransformerException;
 import org.mule.transformer.simple.SerializableToByteArray;
+import org.mule.transformer.types.DataTypeFactory;
 import org.mule.transport.email.AbstractMailConnector;
 import org.mule.util.StringUtils;
 
@@ -40,6 +41,24 @@ public class ObjectToMimeMessage extends StringToEmailMessage
     private boolean useInboundAttachments = true;
     private boolean useOutboundAttachments = true;
 
+    public ObjectToMimeMessage()
+    {
+        this.registerSourceType(DataTypeFactory.create(Message.class));
+    }
+
+    @Override
+    public Object transformMessage(MuleMessage message, String outputEncoding) throws TransformerException
+    {
+        if (message.getPayload() instanceof Message)
+        {
+            return message.getPayload();
+        }
+        else
+        {
+            return super.transformMessage(message, outputEncoding);
+        }
+    }
+
     @Override
     protected void setContent(Object payload, Message msg, String contentType, MuleMessage message)
         throws Exception
