@@ -1,5 +1,5 @@
 /*
- * $Id: FileMessageReceiver.java 21465 2011-03-04 17:13:16Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,19 +13,29 @@ package org.mule.transport.file;
 import org.mule.DefaultMuleMessage;
 import org.mule.api.DefaultMuleException;
 import org.mule.api.MessagingException;
+import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
 import org.mule.api.config.MuleProperties;
 import org.mule.api.construct.FlowConstruct;
 import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.api.lifecycle.CreateException;
+import org.mule.api.lifecycle.InitialisationException;
+import org.mule.api.store.ObjectAlreadyExistsException;
+import org.mule.api.store.ObjectStore;
+import org.mule.api.store.ObjectStoreException;
+import org.mule.api.store.ObjectStoreManager;
 import org.mule.api.transport.Connector;
 import org.mule.api.transport.PropertyScope;
-import org.mule.config.i18n.Message;
+import org.mule.api.execution.ExecutionCallback;
+import org.mule.api.execution.ExecutionTemplate;
+import org.mule.construct.Flow;
+import org.mule.processor.strategy.SynchronousProcessingStrategy;
 import org.mule.transport.AbstractPollingMessageReceiver;
 import org.mule.transport.ConnectException;
 import org.mule.transport.file.i18n.FileMessages;
 import org.mule.util.FileUtils;
+import org.mule.util.lock.LockFactory;
 
 import java.io.File;
 import java.io.FileFilter;
@@ -39,6 +49,8 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.locks.Lock;
 
 import org.apache.commons.collections.comparators.ReverseComparator;
 
@@ -51,9 +63,11 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
 {
     public static final String COMPARATOR_CLASS_NAME_PROPERTY = "comparator";
     public static final String COMPARATOR_REVERSE_ORDER_PROPERTY = "reverseOrder";
+    public static final String MULE_TRANSPORT_FILE_SINGLEPOLLINSTANCE = "mule.transport.file.singlepollinstance";
 
     private static final List<File> NO_FILES = new ArrayList<File>();
 
+    private FileConnector fileConnector = null;
     private String readDir = null;
     private String moveDir = null;
     private String workDir = null;
@@ -64,6 +78,9 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
     private FilenameFilter filenameFilter = null;
     private FileFilter fileFilter = null;
     private boolean forceSync;
+    private LockFactory lockFactory;
+    private boolean poolOnPrimaryInstanceOnly;
+    private ObjectStore<String> filesBeingProcessingObjectStore;
 
     public FileMessageReceiver(Connector connector,
                                FlowConstruct flowConstruct,
@@ -74,13 +91,15 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
                                long frequency) throws CreateException
     {
         super(connector, flowConstruct, endpoint);
-        this.setFrequency(frequency);
+        this.fileConnector = (FileConnector) connector;
+
+        setFrequency(frequency);
 
         this.readDir = readDir;
         this.moveDir = moveDir;
         this.moveToPattern = moveToPattern;
-        this.workDir = ((FileConnector) connector).getWorkDirectory();
-        this.workFileNamePattern = ((FileConnector) connector).getWorkFileNamePattern();
+        this.workDir = fileConnector.getWorkDirectory();
+        this.workFileNamePattern = fileConnector.getWorkFileNamePattern();
 
         if (endpoint.getFilter() instanceof FilenameFilter)
         {
@@ -94,28 +113,42 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
         {
             throw new CreateException(FileMessages.invalidFileFilter(endpoint.getEndpointURI()), this);
         }
-        
-        checkMustForceSync(endpoint);
+
+        checkMustForceSync();
     }
 
     /**
      * If we will be autodeleting File objects, events must be processed synchronously to avoid a race
      */
-    private void checkMustForceSync(InboundEndpoint endpoint) throws CreateException
+    protected void checkMustForceSync() throws CreateException
     {
         boolean connectorIsAutoDelete = false;
         boolean isStreaming = false;
         if (connector instanceof FileConnector)
         {
-            connectorIsAutoDelete = ((FileConnector) connector).isAutoDelete();
-            isStreaming = ((FileConnector) connector).isStreaming();
+            connectorIsAutoDelete = fileConnector.isAutoDelete();
+            isStreaming = fileConnector.isStreaming();
         }
 
         boolean messageFactoryConsumes = (createMuleMessageFactory() instanceof FileContentsMuleMessageFactory);
-        
+
         forceSync = connectorIsAutoDelete && !messageFactoryConsumes && !isStreaming;
     }
 
+    @Override
+    protected void doInitialise() throws InitialisationException
+    {
+        this.lockFactory = getConnector().getMuleContext().getLockFactory();
+        boolean synchronousProcessing = false;
+        if (getFlowConstruct() instanceof Flow)
+        {
+            synchronousProcessing = ((Flow)getFlowConstruct()).getProcessingStrategy() instanceof SynchronousProcessingStrategy;
+        }
+        this.poolOnPrimaryInstanceOnly = Boolean.valueOf(System.getProperty(MULE_TRANSPORT_FILE_SINGLEPOLLINSTANCE,"false")) || !synchronousProcessing;
+        ObjectStoreManager objectStoreManager = getConnector().getMuleContext().getRegistry().get(MuleProperties.OBJECT_STORE_MANAGER);
+        filesBeingProcessingObjectStore = objectStoreManager.getObjectStore(getEndpoint().getName(),false,1000,60000,20000);
+    }
+
     @Override
     protected void doConnect() throws Exception
     {
@@ -178,7 +211,38 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
                 // don't process directories
                 if (file.isFile())
                 {
-                    processFile(file);
+                    Lock fileLock = lockFactory.createLock(file.getName());
+                    if (fileLock.tryLock())
+                    {
+                        try
+                        {
+                            String fileAbsolutePath = file.getAbsolutePath();
+                            try
+                            {
+                                filesBeingProcessingObjectStore.store(fileAbsolutePath, fileAbsolutePath);
+                                if (logger.isDebugEnabled())
+                                {
+                                    logger.debug(String.format("Flag for $ stored successfully.", fileAbsolutePath));
+                                }
+                            }
+                            catch (ObjectAlreadyExistsException e)
+                            {
+                                if (logger.isDebugEnabled())
+                                {
+                                    logger.debug(String.format("Flag for %s being processed is on. Skipping file.", fileAbsolutePath));
+                                }
+                                continue;
+                            }
+                            if (file.exists())
+                            {
+                                processFile(file);
+                            }
+                        }
+                        finally
+                        {
+                            fileLock.unlock();
+                        }
+                    }
                 }
             }
         }
@@ -188,76 +252,86 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
         }
     }
 
-    public void processFile(File sourceFile) throws MuleException
+    @Override
+    protected boolean pollOnPrimaryInstanceOnly()
+    {
+        return poolOnPrimaryInstanceOnly;
+    }
+
+    public void processFile(File file) throws MuleException
     {
-        FileConnector fileConnector = (FileConnector) connector;
-        
         //TODO RM*: This can be put in a Filter. Also we can add an AndFileFilter/OrFileFilter to allow users to
         //combine file filters (since we can only pass a single filter to File.listFiles, we would need to wrap
         //the current And/Or filters to extend {@link FilenameFilter}
         boolean checkFileAge = fileConnector.getCheckFileAge();
         if (checkFileAge)
         {
-            long fileAge = ((FileConnector) connector).getFileAge();
-            long lastMod = sourceFile.lastModified();
+            long fileAge = fileConnector.getFileAge();
+            long lastMod = file.lastModified();
             long now = System.currentTimeMillis();
             long thisFileAge = now - lastMod;
             if (thisFileAge < fileAge)
             {
                 if (logger.isDebugEnabled())
                 {
-                    logger.debug("The file has not aged enough yet, will return nothing for: " + sourceFile);
+                    logger.debug("The file has not aged enough yet, will return nothing for: " + file);
                 }
                 return;
             }
         }
 
-        String sourceFileOriginalName = sourceFile.getName();
-
         // Perform some quick checks to make sure file can be processed
-        if (!(sourceFile.canRead() && sourceFile.exists() && sourceFile.isFile()))
+        if (!(file.canRead() && file.exists() && file.isFile()))
         {
-            throw new DefaultMuleException(FileMessages.fileDoesNotExist(sourceFileOriginalName));
+            throw new DefaultMuleException(FileMessages.fileDoesNotExist(file.getName()));
         }
 
         // don't process a file that is locked by another process (probably still being written)
-        if (!attemptFileLock(sourceFile))
+        if (!attemptFileLock(file))
         {
             return;
         }
         else if(logger.isInfoEnabled())
         {
-            logger.info("Lock obtained on file: " + sourceFile.getAbsolutePath());
+            logger.info("Lock obtained on file: " + file.getAbsolutePath());
         }
 
         // This isn't nice but is needed as MuleMessage is required to resolve
         // destination file name
         DefaultMuleMessage fileParserMessasge = new DefaultMuleMessage(null, connector.getMuleContext());
-        fileParserMessasge.setOutboundProperty(FileConnector.PROPERTY_ORIGINAL_FILENAME, sourceFileOriginalName);
-        
-        File workFile = null;
+        fileParserMessasge.setOutboundProperty(FileConnector.PROPERTY_ORIGINAL_FILENAME, file.getName());
+
+        // The file may get moved/renamed here so store the original file info.
+        final String originalSourceFile = file.getAbsolutePath();
+        final String originalSourceFileName = file.getName();
+        final File sourceFile;
         if (workDir != null)
         {
-            String workFileName = sourceFileOriginalName;
-            
-            workFileName = fileConnector.getFilenameParser().getFilename(fileParserMessasge,
-                    workFileNamePattern);
+            String workFileName = file.getName();
+
+            workFileName = fileConnector.getFilenameParser().getFilename(fileParserMessasge, workFileNamePattern);
             // don't use new File() directly, see MULE-1112
-            workFile = FileUtils.newFile(workDir, workFileName);
-            
-            move(sourceFile, workFile);
+            File workFile = FileUtils.newFile(workDir, workFileName);
+
+            fileConnector.move(file, workFile);
             // Now the Work File is the Source file
             sourceFile = workFile;
         }
-        
+        else
+        {
+            sourceFile = file;
+        }
+        // Do not use the original file handle beyond this point since it may have moved.
+        file = null;
+
         // set up destination file
         File destinationFile = null;
         if (moveDir != null)
         {
-            String destinationFileName = sourceFileOriginalName;
+            String destinationFileName = originalSourceFileName;
             if (moveToPattern != null)
             {
-                destinationFileName = ((FileConnector) connector).getFilenameParser().getFilename(fileParserMessasge,
+                destinationFileName = fileConnector.getFilenameParser().getFilename(fileParserMessasge,
                     moveToPattern);
             }
             // don't use new File() directly, see MULE-1112
@@ -270,8 +344,25 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
         {
             if (fileConnector.isStreaming())
             {
-                ReceiverFileInputStream payload = new ReceiverFileInputStream(sourceFile,
-                    fileConnector.isAutoDelete(), destinationFile);
+                ReceiverFileInputStream payload = createReceiverFileInputStream(sourceFile, destinationFile, new InputStreamCloseListener()
+                {
+                    @Override
+                    public void fileClose(File file)
+                    {
+                        try
+                        {
+                            if (logger.isDebugEnabled())
+                            {
+                                logger.debug(String.format("Removing processing flag for $ ", file.getAbsolutePath()));
+                            }
+                            filesBeingProcessingObjectStore.remove(file.getAbsolutePath());
+                        }
+                        catch (ObjectStoreException e)
+                        {
+                            logger.warn("Failure trying to remove file " + originalSourceFile + " from list of files under processing");
+                        }
+                    }
+                });
                 message = createMuleMessage(payload, encoding);
             }
             else
@@ -286,99 +377,204 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
             return;
         }
 
-        message.setOutboundProperty(FileConnector.PROPERTY_ORIGINAL_FILENAME, sourceFileOriginalName);
+        message.setOutboundProperty(FileConnector.PROPERTY_ORIGINAL_FILENAME, originalSourceFileName);
         if (forceSync)
         {
             message.setProperty(MuleProperties.MULE_FORCE_SYNC_PROPERTY, Boolean.TRUE, PropertyScope.INBOUND);
         }
-        if (!fileConnector.isStreaming())
+
+        final Object originalPayload = message.getPayload();
+
+        ExecutionTemplate<MuleEvent> executionTemplate = createExecutionTemplate();
+        final MuleMessage finalMessage = message;
+
+        if (fileConnector.isStreaming())
         {
-            moveAndDelete(sourceFile, destinationFile, sourceFileOriginalName, message);
+            processWithStreaming(sourceFile, (ReceiverFileInputStream) originalPayload, executionTemplate, finalMessage);
         }
         else
         {
-            // If we are streaming no need to move/delete now, that will be done when
-            // stream is closed
-            message.setOutboundProperty(FileConnector.PROPERTY_FILENAME, sourceFile.getName());
-            this.routeMessage(message);
+            processWithoutStreaming(originalSourceFile, originalSourceFileName, sourceFile, destinationFile, executionTemplate, finalMessage);
         }
     }
 
-    private void moveAndDelete(final File sourceFile, File destinationFile,
-        String sourceFileOriginalName, MuleMessage message)
+    private void processWithoutStreaming(String originalSourceFile, final String originalSourceFileName, final File sourceFile,final File destinationFile, ExecutionTemplate<MuleEvent> executionTemplate, final MuleMessage finalMessage) throws DefaultMuleException
     {
-        boolean fileWasMoved = false;
-
         try
         {
-            // If we are moving the file to a read directory, move it there now and
-            // hand over a reference to the
-            // File in its moved location
-            if (destinationFile != null)
+            executionTemplate.execute(new ExecutionCallback<MuleEvent>()
+            {
+                @Override
+                public MuleEvent process() throws Exception
+                {
+                    moveAndDelete(sourceFile, destinationFile, originalSourceFileName, finalMessage);
+                    return null;
+                }
+            });
+            deleteFileIfRequired(sourceFile, destinationFile);
+        }
+        catch (MessagingException e)
+        {
+            if (e.causedRollback())
+            {
+                rollbackFileMoveIfRequired(originalSourceFile, sourceFile);
+            }
+            else
+            {
+                deleteFileIfRequired(sourceFile, destinationFile);
+            }
+        }
+        catch (Exception e)
+        {
+            rollbackFileMoveIfRequired(originalSourceFile, sourceFile);
+            connector.getMuleContext().getExceptionListener().handleException(e);
+        }
+        finally
+        {
+            try
+            {
+                filesBeingProcessingObjectStore.remove(originalSourceFile);
+                if (logger.isDebugEnabled())
+                {
+                    logger.debug(String.format("Removing processing flag for $ ", originalSourceFile));
+                }
+            }
+            catch (ObjectStoreException e)
+            {
+                logger.warn("Failure trying to remove file " + originalSourceFile + " from list of files under processing");
+            }
+        }
+    }
+
+    private void processWithStreaming(final File sourceFile, final ReceiverFileInputStream originalPayload, ExecutionTemplate<MuleEvent> executionTemplate, final MuleMessage finalMessage)
+    {
+        try
+        {
+            final AtomicBoolean exceptionWasThrown = new AtomicBoolean(false);
+            executionTemplate.execute(new ExecutionCallback<MuleEvent>()
+            {
+                @Override
+                public MuleEvent process() throws Exception
+                {
+                    try
+                    {
+                        // If we are streaming no need to move/delete now, that will be done when
+                        // stream is closed
+                        finalMessage.setOutboundProperty(FileConnector.PROPERTY_FILENAME, sourceFile.getName());
+                        FileMessageReceiver.this.routeMessage(finalMessage);
+                    }
+                    catch (Exception e)
+                    {
+                        //ES will try to close stream but FileMessageReceiver is the one that must close it.
+                        exceptionWasThrown.set(true);
+                        originalPayload.setStreamProcessingError(true);
+                        throw e;
+                    }
+                    return null;
+                }
+            });
+            //Exception thrown but handled, consume inbound message.
+            if (exceptionWasThrown.get())
+            {
+                originalPayload.setStreamProcessingError(false);
+                originalPayload.close();
+            }
+        }
+        catch (MessagingException e)
+        {
+            //This code is only used by default-exception-estrategy which re-throws exception despite commit.
+            if (!e.causedRollback())
             {
-                // move sourceFile to new destination
                 try
                 {
-                    FileUtils.moveFile(sourceFile, destinationFile);
+                    originalPayload.setStreamProcessingError(false);
+                    originalPayload.close();
                 }
-                catch (IOException e)
+                catch (Exception ex)
                 {
-                    // move didn't work - bail out (will attempt rollback)
-                    throw new DefaultMuleException(FileMessages.failedToMoveFile(
-                        sourceFile.getAbsolutePath(), destinationFile.getAbsolutePath()));
-                }
-
-                // create new Message for destinationFile
-                message = createMuleMessage(destinationFile, endpoint.getEncoding());
-                message.setOutboundProperty(FileConnector.PROPERTY_FILENAME, destinationFile.getName());
-                message.setOutboundProperty(FileConnector.PROPERTY_ORIGINAL_FILENAME, sourceFileOriginalName);
-            }
-
-            // finally deliver the file message
-            this.routeMessage(message);
-
-            // at this point msgAdapter either points to the old sourceFile
-            // or the new destinationFile.
-            if (((FileConnector) connector).isAutoDelete())
-            {
-                // no moveTo directory
-                if (destinationFile == null)
-                {
-                    // delete source
-                    if (!sourceFile.delete())
-                    {
-                        throw new DefaultMuleException(FileMessages.failedToDeleteFile(sourceFile));
-                    }
-                }
-                else
-                {
-                    // nothing to do here since moveFile() should have deleted
-                    // the source file for us
+                    logger.warn(ex);
                 }
             }
         }
         catch (Exception e)
         {
-            boolean fileWasRolledBack = false;
+            connector.getMuleContext().getExceptionListener().handleException(e);
+        }
+    }
 
-            // only attempt rollback if file move was successful
-            if (fileWasMoved)
+    /* Left for baackward compatibility */
+    protected ReceiverFileInputStream createReceiverFileInputStream(File sourceFile, File destinationFile) throws FileNotFoundException
+    {
+        return new ReceiverFileInputStream(sourceFile,
+                                           fileConnector.isAutoDelete(), destinationFile);
+    }
+
+    protected ReceiverFileInputStream createReceiverFileInputStream(File sourceFile, File destinationFile, InputStreamCloseListener closeListener) throws FileNotFoundException
+    {
+        return new ReceiverFileInputStream(sourceFile,
+                                           fileConnector.isAutoDelete(), destinationFile,closeListener);
+    }
+
+    private void rollbackFileMoveIfRequired(String originalSourceFile, File sourceFile)
+    {
+        if (!sourceFile.getAbsolutePath().equals(originalSourceFile))
+        {
+            try
             {
-                try
-                {
-                    rollbackFileMove(destinationFile, sourceFile.getAbsolutePath());
-                    fileWasRolledBack = true;
-                }
-                catch (IOException ioException)
-                {
-                    // eat it
-                }
+                rollbackFileMove(sourceFile, originalSourceFile);
+            }
+            catch (IOException iox)
+            {
+                logger.warn(iox);
+            }
+        }
+    }
+
+    private void moveAndDelete(final File sourceFile, File destinationFile,
+        String sourceFileOriginalName, MuleMessage message) throws MuleException
+    {
+        // If we are moving the file to a read directory, move it there now and
+        // hand over a reference to the
+        // File in its moved location
+        if (destinationFile != null)
+        {
+            // move sourceFile to new destination
+            try
+            {
+                FileUtils.moveFile(sourceFile, destinationFile);
+            }
+            catch (IOException e)
+            {
+                // move didn't work - bail out (will attempt rollback)
+                throw new DefaultMuleException(FileMessages.failedToMoveFile(
+                    sourceFile.getAbsolutePath(), destinationFile.getAbsolutePath()));
             }
 
-            // wrap exception & handle it
-            Message msg = FileMessages.exceptionWhileProcessing(sourceFile.getName(),
-                (fileWasRolledBack ? "successful" : "unsuccessful"));
-            getConnector().getMuleContext().getExceptionListener().handleException(new MessagingException(msg, message, e));
+            // create new Message for destinationFile
+            message = createMuleMessage(destinationFile, endpoint.getEncoding());
+            message.setOutboundProperty(FileConnector.PROPERTY_FILENAME, destinationFile.getName());
+            message.setOutboundProperty(FileConnector.PROPERTY_ORIGINAL_FILENAME, sourceFileOriginalName);
+        }
+
+        // finally deliver the file message
+        this.routeMessage(message);
+    }
+
+    private void deleteFileIfRequired(File sourceFile, File destinationFile) throws DefaultMuleException
+    {
+        // at this point msgAdapter either points to the old sourceFile
+        // or the new destinationFile.
+        if (fileConnector.isAutoDelete())
+        {
+            // no moveTo directory
+            if (destinationFile == null)
+            {
+                // delete source
+                if (!sourceFile.delete())
+                {
+                    throw new DefaultMuleException(FileMessages.failedToDeleteFile(sourceFile));
+                }
+            }
         }
     }
 
@@ -386,7 +582,7 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
      * Try to acquire a lock on a file and release it immediately. Usually used as a
      * quick check to see if another process is still holding onto the file, e.g. a
      * large file (more than 100MB) is still being written to.
-     * 
+     *
      * @param sourceFile file to check
      * @return <code>true</code> if the file can be locked
      */
@@ -453,7 +649,7 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
 
     /**
      * Get a list of files to be processed.
-     * 
+     *
      * @return an array of files to be processed.
      * @throws org.mule.api.MuleException which will wrap any other exceptions or
      *             errors.
@@ -483,7 +679,7 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
         {
             files = currentDirectory.listFiles(filenameFilter);
         }
-        
+
         // the listFiles calls above may actually return null (check the JDK code).
         if (files == null)
         {
@@ -498,7 +694,7 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
             }
             else
             {
-                if (((FileConnector) this.getConnector()).isRecursive())
+                if (fileConnector.isRecursive())
                 {
                     this.basicListFiles(file, discoveredFiles);
                 }
@@ -508,7 +704,7 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
 
     /**
      * Exception tolerant roll back method
-     * 
+     *
      * @throws Throwable
      */
     protected void rollbackFileMove(File sourceFile, String destinationFilePath) throws IOException
@@ -535,30 +731,11 @@ public class FileMessageReceiver extends AbstractPollingMessageReceiver
             {
                 reverse = Boolean.valueOf((String) reverseProperty);
             }
-            
+
             Class<?> clazz = Class.forName(comparatorClassName.toString());
             Comparator<?> comparator = (Comparator<?>)clazz.newInstance();
             return reverse ? new ReverseComparator(comparator) : comparator;
         }
         return null;
     }
-    
-    private void move(final File sourceFile,File destinationFile) throws DefaultMuleException
-    {
-        if (destinationFile != null)
-        {
-            // move sourceFile to new destination. Do not use FileUtils here as it ultimately
-            // falls back to copying the file which will cause problems on large files again -
-            // which is what we're trying to avoid in the first place
-            boolean fileWasMoved = sourceFile.renameTo(destinationFile);
-
-            // move didn't work - bail out
-            if (!fileWasMoved)
-            {
-                throw new DefaultMuleException(FileMessages.failedToMoveFile(sourceFile.getAbsolutePath(),
-                    destinationFile.getAbsolutePath()));
-            }
-        }
-    }
-    
 }
