@@ -1,5 +1,5 @@
 /*
- * $Id: HttpConnector.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,16 +12,29 @@ package org.mule.transport.http;
 
 import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
+import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
 import org.mule.api.construct.FlowConstruct;
+import org.mule.api.endpoint.EndpointURI;
 import org.mule.api.endpoint.ImmutableEndpoint;
 import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.processor.MessageProcessor;
+import org.mule.api.transport.MessageReceiver;
+import org.mule.api.transport.NoReceiverForEndpointException;
 import org.mule.config.i18n.CoreMessages;
+import org.mule.transport.ConnectException;
+import org.mule.transport.http.i18n.HttpMessages;
+import org.mule.transport.http.ntlm.NTLMScheme;
 import org.mule.transport.tcp.TcpConnector;
+import org.mule.util.MapUtils;
 
+import java.io.IOException;
 import java.io.UnsupportedEncodingException;
+import java.net.InetSocketAddress;
+import java.net.ServerSocket;
+import java.net.Socket;
+import java.net.URI;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -29,14 +42,18 @@ import java.util.Map;
 import java.util.Set;
 
 import org.apache.commons.codec.binary.Base64;
+import org.apache.commons.httpclient.Credentials;
 import org.apache.commons.httpclient.HttpClient;
 import org.apache.commons.httpclient.HttpConnectionManager;
 import org.apache.commons.httpclient.HttpMethod;
 import org.apache.commons.httpclient.HttpState;
 import org.apache.commons.httpclient.MultiThreadedHttpConnectionManager;
+import org.apache.commons.httpclient.NTCredentials;
 import org.apache.commons.httpclient.UsernamePasswordCredentials;
+import org.apache.commons.httpclient.auth.AuthPolicy;
 import org.apache.commons.httpclient.auth.AuthScope;
 import org.apache.commons.httpclient.params.HttpConnectionManagerParams;
+import org.apache.commons.httpclient.util.IdleConnectionTimeoutThread;
 
 /**
  * <code>HttpConnector</code> provides a way of receiving and sending http requests
@@ -53,7 +70,6 @@ import org.apache.commons.httpclient.params.HttpConnectionManagerParams;
  * <li>proxyUsername - If the proxy requires authentication supply a username</li>
  * <li>proxyPassword - If the proxy requires authentication supply a password</li>
  * </ul>
- * 
  */
 
 public class HttpConnector extends TcpConnector
@@ -61,37 +77,65 @@ public class HttpConnector extends TcpConnector
 
     public static final String HTTP = "http";
     public static final String HTTP_PREFIX = "http.";
-    
+
     /**
      * MuleEvent property to pass back the status for the response
      */
     public static final String HTTP_STATUS_PROPERTY = HTTP_PREFIX + "status";
     public static final String HTTP_VERSION_PROPERTY = HTTP_PREFIX + "version";
-    
+
     /**
      * @deprecated Instead users can now add properties to the outgoing request using the OUTBOUND property scope on the message.
      */
     @Deprecated
     public static final String HTTP_CUSTOM_HEADERS_MAP_PROPERTY = HTTP_PREFIX + "custom.headers";
 
-    public static final String HTTP_METHOD_PROPERTY = HTTP_PREFIX + "method";
-    
     /**
-     * The path and query portions of the URL being accessed. 
+     * Encapsulates all the HTTP headers
+     */
+    public static final String HTTP_HEADERS = HTTP_PREFIX + "headers";
+
+    /**
+     * Stores the HTTP query parameters received, supports multiple values per key and both query parameter key and
+     * value are unescaped
+     */
+    public static final String HTTP_QUERY_PARAMS = HTTP_PREFIX + "query.params";
+
+    public static final String HTTP_QUERY_STRING = HTTP_PREFIX + "query.string";
+
+    public static final String HTTP_METHOD_PROPERTY = HTTP_PREFIX + "method";
+
+    /**
+     * The path and query portions of the URL being accessed.
      */
     public static final String HTTP_REQUEST_PROPERTY = HTTP_PREFIX + "request";
-    
+
     /**
      * The path portion of the URL being accessed. No query string is included.
      */
     public static final String HTTP_REQUEST_PATH_PROPERTY = HTTP_PREFIX + "request.path";
-    
+
     /**
-     * The context path of the endpoint being accessed. This is the path that the 
+     * The context path of the endpoint being accessed. This is the path that the
      * HTTP endpoint is listening on.
      */
     public static final String HTTP_CONTEXT_PATH_PROPERTY = HTTP_PREFIX + "context.path";
 
+    /**
+     * The context URI of the endpoint being accessed. This is the address that the
+     * HTTP endpoint is listening on. It includes: [scheme]://[host]:[port][http.context.path]
+     */
+    public static final String HTTP_CONTEXT_URI_PROPERTY = HTTP_PREFIX + "context.uri";
+
+
+    /**
+     * The relative path of the URI being accessed in relation to the context path
+     */
+    public static final String HTTP_RELATIVE_PATH_PROPERTY = HTTP_PREFIX + "relative.path";
+
+    public static final String HTTP_SERVLET_REQUEST_PROPERTY = HTTP_PREFIX + "servlet.request";
+    public static final String HTTP_SERVLET_RESPONSE_PROPERTY = HTTP_PREFIX + "servlet.response";
+
     /**
      * Allows the user to set a {@link org.apache.commons.httpclient.params.HttpMethodParams} object in the client
      * request to be set on the HttpMethod request object
@@ -103,10 +147,10 @@ public class HttpConnector extends TcpConnector
 
     public static final String HTTP_DISABLE_STATUS_CODE_EXCEPTION_CHECK = HTTP_PREFIX + "disable.status.code.exception.check";
     public static final String HTTP_ENCODE_PARAMVALUE = HTTP_PREFIX + "encode.paramvalue";
-    
+
     public static final Set<String> HTTP_INBOUND_PROPERTIES;
-    
-    static 
+
+    static
     {
         Set<String> props = new HashSet<String>();
         props.add(HTTP_CONTEXT_PATH_PROPERTY);
@@ -120,14 +164,17 @@ public class HttpConnector extends TcpConnector
         props.add(HTTP_VERSION_PROPERTY);
         props.add(HTTP_ENCODE_PARAMVALUE);
         HTTP_INBOUND_PROPERTIES = props;
+
+        AuthPolicy.registerAuthScheme(AuthPolicy.NTLM, NTLMScheme.class);
     }
-    
+
     public static final String HTTP_COOKIE_SPEC_PROPERTY = "cookieSpec";
     public static final String HTTP_COOKIES_PROPERTY = "cookies";
     public static final String HTTP_ENABLE_COOKIES_PROPERTY = "enableCookies";
 
     public static final String COOKIE_SPEC_NETSCAPE = "netscape";
-    public static final String COOKIE_SPEC_RFC2109 = "rcf2109";
+    public static final String COOKIE_SPEC_RFC2109 = "rfc2109";
+    public static final String ROOT_PATH = "/";
 
     private String proxyHostname = null;
 
@@ -137,17 +184,25 @@ public class HttpConnector extends TcpConnector
 
     private String proxyPassword = null;
 
+    private boolean proxyNtlmAuthentication;
+
     private String cookieSpec;
 
     private boolean enableCookies = false;
 
     protected HttpConnectionManager clientConnectionManager;
 
+    private IdleConnectionTimeoutThread connectionCleaner;
+
+    private boolean disableCleanupThread;
+
+    private org.mule.transport.http.HttpConnectionManager connectionManager;
+
     public HttpConnector(MuleContext context)
     {
         super(context);
     }
-    
+
     @Override
     protected void doInitialise() throws InitialisationException
     {
@@ -155,6 +210,16 @@ public class HttpConnector extends TcpConnector
         if (clientConnectionManager == null)
         {
             clientConnectionManager = new MultiThreadedHttpConnectionManager();
+            String prop = System.getProperty("mule.http.disableCleanupThread");
+            disableCleanupThread = prop != null && prop.equals("true");
+            if (!disableCleanupThread)
+            {
+                connectionCleaner = new IdleConnectionTimeoutThread();
+                connectionCleaner.setName("HttpClient-connection-cleaner-" + getName());
+                connectionCleaner.addConnectionManager(clientConnectionManager);
+                connectionCleaner.start();
+            }
+
             HttpConnectionManagerParams params = new HttpConnectionManagerParams();
             if (getSendBufferSize() != INT_VALUE_NOT_SET)
             {
@@ -178,6 +243,56 @@ public class HttpConnector extends TcpConnector
             params.setDefaultMaxConnectionsPerHost(dispatchers.getMaxTotal());
             clientConnectionManager.setParams(params);
         }
+        //connection manager must be created during initialization due that devkit requires the connection manager before start phase.
+        //That's why it not manager only during stop/start phases and must be created also here.
+        if (connectionManager == null)
+        {
+            try
+            {
+                connectionManager = new org.mule.transport.http.HttpConnectionManager(this, getReceiverWorkManager());
+            }
+            catch (MuleException e)
+            {
+                throw new InitialisationException(CoreMessages.createStaticMessage("failed creating http connection manager"),this);
+            }
+        }
+    }
+
+    @Override
+    protected void doDispose()
+    {
+        if (!disableCleanupThread)
+        {
+            connectionCleaner.shutdown();
+
+            if (!muleContext.getConfiguration().isStandalone())
+            {
+                MultiThreadedHttpConnectionManager.shutdownAll();
+            }
+        }
+        if (this.connectionManager != null)
+        {
+            connectionManager.dispose();
+            connectionManager = null;
+        }
+        super.doDispose();
+    }
+
+    @Override
+    protected void doStop() throws MuleException
+    {
+        this.connectionManager.dispose();
+        this.connectionManager = null;
+    }
+
+    @Override
+    protected void doStart() throws MuleException
+    {
+        super.doStart();
+        if (this.connectionManager == null)
+        {
+            this.connectionManager = new org.mule.transport.http.HttpConnectionManager(this,getReceiverWorkManager());
+        }
     }
 
     @Override
@@ -190,7 +305,7 @@ public class HttpConnector extends TcpConnector
             {
                 // normalize properties for HTTP
                 Map newProperties = new HashMap(endpointProperties.size());
-                for (Iterator entries = endpointProperties.entrySet().iterator(); entries.hasNext();)
+                for (Iterator entries = endpointProperties.entrySet().iterator(); entries.hasNext(); )
                 {
                     Map.Entry entry = (Map.Entry) entries.next();
                     Object key = entry.getKey();
@@ -294,7 +409,7 @@ public class HttpConnector extends TcpConnector
         if (!(COOKIE_SPEC_NETSCAPE.equalsIgnoreCase(cookieSpec) || COOKIE_SPEC_RFC2109.equalsIgnoreCase(cookieSpec)))
         {
             throw new IllegalArgumentException(
-                CoreMessages.propertyHasInvalidValue("cookieSpec", cookieSpec).toString());
+                    CoreMessages.propertyHasInvalidValue("cookieSpec", cookieSpec).toString());
         }
         this.cookieSpec = cookieSpec;
     }
@@ -326,9 +441,19 @@ public class HttpConnector extends TcpConnector
 
         if (getProxyUsername() != null)
         {
-            state.setProxyCredentials(
-                    new AuthScope(null, -1, null, null),
-                    new UsernamePasswordCredentials(getProxyUsername(), getProxyPassword()));
+            Credentials credentials;
+            if (isProxyNtlmAuthentication())
+            {
+                credentials = new NTCredentials(getProxyUsername(), getProxyPassword(), getProxyHostname(), "");
+            }
+            else
+            {
+                credentials = new UsernamePasswordCredentials(getProxyUsername(), getProxyPassword());
+            }
+
+            AuthScope authscope = new AuthScope(getProxyHostname(), getProxyPort());
+
+            state.setProxyCredentials(authscope, credentials);
         }
 
         HttpClient client = new HttpClient();
@@ -348,28 +473,28 @@ public class HttpConnector extends TcpConnector
         if (event != null && event.getCredentials() != null)
         {
             MuleMessage msg = event.getMessage();
-            String authScopeHost = msg.getOutboundProperty(HTTP_PREFIX + "auth.scope.host", event.getEndpoint().getEndpointURI().getHost());
-            int authScopePort = msg.getOutboundProperty(HTTP_PREFIX + "auth.scope.port", event.getEndpoint().getEndpointURI().getPort());
+            String authScopeHost = msg.getOutboundProperty(HTTP_PREFIX + "auth.scope.host", event.getMessageSourceURI().getHost());
+            int authScopePort = msg.getOutboundProperty(HTTP_PREFIX + "auth.scope.port", event.getMessageSourceURI().getPort());
             String authScopeRealm = msg.getOutboundProperty(HTTP_PREFIX + "auth.scope.realm", AuthScope.ANY_REALM);
             String authScopeScheme = msg.getOutboundProperty(HTTP_PREFIX + "auth.scope.scheme", AuthScope.ANY_SCHEME);
             client.getState().setCredentials(
-                new AuthScope(authScopeHost, authScopePort, authScopeRealm, authScopeScheme),
-                new UsernamePasswordCredentials(event.getCredentials().getUsername(), new String(
-                    event.getCredentials().getPassword())));
+                    new AuthScope(authScopeHost, authScopePort, authScopeRealm, authScopeScheme),
+                    new UsernamePasswordCredentials(event.getCredentials().getUsername(), new String(
+                            event.getCredentials().getPassword())));
         }
         else if (endpoint.getEndpointURI().getUserInfo() != null
-            && endpoint.getProperty(HttpConstants.HEADER_AUTHORIZATION) == null)
+                 && endpoint.getProperty(HttpConstants.HEADER_AUTHORIZATION) == null)
         {
             // Add User Creds
             StringBuffer header = new StringBuffer(128);
             header.append("Basic ");
             header.append(new String(Base64.encodeBase64(endpoint.getEndpointURI().getUserInfo().getBytes(
-                endpoint.getEncoding()))));
+                    endpoint.getEncoding()))));
             httpMethod.addRequestHeader(HttpConstants.HEADER_AUTHORIZATION, header.toString());
         }
         //TODO MULE-4501 this sohuld be removed and handled only in the ObjectToHttpRequest transformer
-        else if (event!=null && event.getMessage().getOutboundProperty(HttpConstants.HEADER_AUTHORIZATION) != null &&
-                httpMethod.getRequestHeader(HttpConstants.HEADER_AUTHORIZATION)==null)
+        else if (event != null && event.getMessage().getOutboundProperty(HttpConstants.HEADER_AUTHORIZATION) != null &&
+                 httpMethod.getRequestHeader(HttpConstants.HEADER_AUTHORIZATION) == null)
         {
             String auth = event.getMessage().getOutboundProperty(HttpConstants.HEADER_AUTHORIZATION);
             httpMethod.addRequestHeader(HttpConstants.HEADER_AUTHORIZATION, auth);
@@ -386,14 +511,140 @@ public class HttpConnector extends TcpConnector
      */
     public static String normalizeUrl(String url)
     {
-        if (url == null) 
+        if (url == null)
         {
             url = "/";
-        } 
-        else if (!url.startsWith("/")) 
+        }
+        else if (!url.startsWith("/"))
         {
             url = "/" + url;
         }
         return url;
     }
+
+    public boolean isProxyNtlmAuthentication()
+    {
+        return proxyNtlmAuthentication;
+    }
+
+    public void setProxyNtlmAuthentication(boolean proxyNtlmAuthentication)
+    {
+        this.proxyNtlmAuthentication = proxyNtlmAuthentication;
+    }
+
+    public void connect(EndpointURI endpointURI) throws ConnectException
+    {
+        connectionManager.addConnection(endpointURI);
+    }
+
+    public void disconnect(EndpointURI endpointURI)
+    {
+        connectionManager.removeConnection(endpointURI);
+    }
+
+
+    public HttpMessageReceiver lookupReceiver(Socket socket, RequestLine requestLine) throws NoReceiverForEndpointException
+    {
+        int port = ((InetSocketAddress) socket.getLocalSocketAddress()).getPort();
+        String host = null;
+        for (MessageReceiver messageReceiver : receivers.values())
+        {
+            if (messageReceiver.getEndpointURI().getPort() == port)
+            {
+                host = messageReceiver.getEndpointURI().getHost();
+                break;
+            }
+        }
+        if (host == null)
+        {
+            String url = requestLine.getUrlWithoutParams();
+            throw new NoReceiverForEndpointException(HttpMessages.noReceiverFoundForUrl(url));
+        }
+
+        String requestUriWithoutParams = requestLine.getUrlWithoutParams();
+        StringBuilder requestUri = new StringBuilder(80);
+        if (requestUriWithoutParams.indexOf("://") == -1)
+        {
+            requestUri.append(getProtocol()).append("://").append(host).append(':').append(port);
+            if (!ROOT_PATH.equals(requestUriWithoutParams))
+            {
+                requestUri.append(requestUriWithoutParams);
+            }
+        }
+
+        String uriStr = requestUri.toString();
+        // first check that there is a receiver on the root address
+        if (logger.isTraceEnabled())
+        {
+            logger.trace("Looking up receiver on connector: " + getName() + " with URI key: "
+                         + requestUri.toString());
+        }
+
+        HttpMessageReceiver receiver = (HttpMessageReceiver) lookupReceiver(uriStr);
+
+        // If no receiver on the root and there is a request path, look up the
+        // received based on the root plus request path
+        if (receiver == null && !ROOT_PATH.equals(requestUriWithoutParams))
+        {
+            if (logger.isDebugEnabled())
+            {
+                logger.debug("Secondary lookup of receiver on connector: " + getName()
+                             + " with URI key: " + requestUri.toString());
+            }
+
+            receiver = (HttpMessageReceiver) findReceiverByStem(getReceivers(), uriStr);
+
+            if (receiver == null && logger.isWarnEnabled())
+            {
+                logger.warn("No receiver found with secondary lookup on connector: " + getName()
+                            + " with URI key: " + requestUri.toString());
+                logger.warn("Receivers on connector are: "
+                            + MapUtils.toString(getReceivers(), true));
+            }
+        }
+        if (receiver == null)
+        {
+            throw new NoReceiverForEndpointException(HttpMessages.noReceiverFoundForUrl(requestUriWithoutParams));
+        }
+        return receiver;
+    }
+
+    //Leave for backward compatibility
+    @Deprecated
+    public HttpMessageReceiver lookupReceiver(Socket socket, HttpRequest request)
+    {
+        try
+        {
+            return this.lookupReceiver(socket, request.getRequestLine());
+        }
+        catch (NoReceiverForEndpointException e)
+        {
+            logger.debug("No receiver found: " + e.getMessage());
+            return null;
+        }
+    }
+
+    public static MessageReceiver findReceiverByStem(Map<Object, MessageReceiver> receivers, String uriStr)
+    {
+        int match = 0;
+        MessageReceiver receiver = null;
+        for (Map.Entry<Object, MessageReceiver> e : receivers.entrySet())
+        {
+            String key = (String) e.getKey();
+            MessageReceiver candidate = e.getValue();
+            if (uriStr.startsWith(key) && match < key.length())
+            {
+                match = key.length();
+                receiver = candidate;
+            }
+        }
+        return receiver;
+    }
+
+    @Override
+    protected ServerSocket getServerSocket(URI uri) throws IOException
+    {
+        return super.getServerSocket(uri);
+    }
+
 }
