@@ -1,5 +1,5 @@
 /*
- * $Id: PollingHttpMessageReceiver.java 24265 2012-04-16 06:54:00Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -52,6 +52,11 @@ public class PollingHttpMessageReceiver extends AbstractPollingMessageReceiver
         setupFromConnector(connector);
     }
 
+    @Override
+    protected boolean pollOnPrimaryInstanceOnly() {
+        return true;
+    }
+
     protected void setupFromConnector(Connector connector) throws CreateException
     {
         if (!(connector instanceof HttpPollingConnector))
