@@ -1,5 +1,5 @@
 /*
- * $Id: HttpResponseTimeoutTestCase.java 22735 2011-08-25 16:02:35Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -105,7 +105,7 @@ public class HttpResponseTimeoutTestCase extends AbstractServiceAndFlowTestCase
         // message will be returned as the response. There is no exception payload.
         assertNotNull(message);
         assertNull(message.getExceptionPayload());
-        assertNotNull(getPayload(), message.getPayloadAsString());
+        assertNotNull(message.getPayloadAsString());
         assertTrue((afterCall.getTime() - beforeCall.getTime()) > DEFAULT_RESPONSE_TIMEOUT);
     }
 
