@@ -1,5 +1,5 @@
 /*
- * $Id: JmsConnector.java 22763 2011-08-26 22:30:12Z svacas $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,10 +10,12 @@
 
 package org.mule.transport.jms;
 
+import org.mule.api.DefaultMuleException;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleException;
 import org.mule.api.MuleRuntimeException;
 import org.mule.api.construct.FlowConstruct;
+import org.mule.api.context.notification.ClusterNodeNotificationListener;
 import org.mule.api.context.notification.ConnectionNotificationListener;
 import org.mule.api.endpoint.ImmutableEndpoint;
 import org.mule.api.endpoint.InboundEndpoint;
@@ -26,9 +28,10 @@ import org.mule.api.transport.ReplyToHandler;
 import org.mule.config.ExceptionHelper;
 import org.mule.config.i18n.CoreMessages;
 import org.mule.config.i18n.MessageFactory;
+import org.mule.context.notification.ClusterNodeNotification;
 import org.mule.context.notification.ConnectionNotification;
 import org.mule.context.notification.NotificationException;
-import org.mule.endpoint.AbstractEndpoint;
+import org.mule.routing.MessageFilter;
 import org.mule.transaction.TransactionCoordination;
 import org.mule.transport.AbstractConnector;
 import org.mule.transport.ConnectException;
@@ -191,7 +194,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
     {
         super(context);
     }
-    
+
     public String getProtocol()
     {
         return JMS;
@@ -199,22 +202,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
 
     @Override
     protected void doInitialise() throws InitialisationException
-    {        
-        try
-        {
-            connectionFactory = this.createConnectionFactory();
-        }
-        catch (NamingException ne)
-        {
-            throw new InitialisationException(JmsMessages.errorCreatingConnectionFactory(), ne, this);
-        }
-
-        if ((connectionFactoryProperties != null) && !connectionFactoryProperties.isEmpty())
-        {
-            // apply connection factory properties
-            BeanUtils.populateWithoutFail(connectionFactory, connectionFactoryProperties, true);
-        }
-
+    {
         if (topicResolver == null)
         {
             topicResolver = new DefaultJmsTopicResolver(this);
@@ -231,7 +219,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
                 public void onNotification(ConnectionNotification notification)
                 {
                     if (notification.getAction() == ConnectionNotification.CONNECTION_DISCONNECTED
-                            || notification.getAction() == ConnectionNotification.CONNECTION_FAILED)
+                        || notification.getAction() == ConnectionNotification.CONNECTION_FAILED)
                     {
                         // Remove all dispatchers as any cached session will be invalidated
                         clearDispatchers();
@@ -279,7 +267,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         return result;
     }
 
-    protected ConnectionFactory createConnectionFactory() throws InitialisationException, NamingException
+    protected ConnectionFactory createConnectionFactory() throws NamingException, MuleException
     {
         // if an initial factory class was configured that takes precedence over the 
         // spring-configured connection factory or the one that our subclasses may provide
@@ -298,8 +286,8 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
             }
             else
             {
-                throw new InitialisationException(
-                        JmsMessages.invalidResourceType(ConnectionFactory.class, temp), this);
+                throw new DefaultMuleException(
+                        JmsMessages.invalidResourceType(ConnectionFactory.class, temp));
             }
         }
         else
@@ -323,12 +311,12 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
             }
             catch (Exception e)
             {
-                throw new InitialisationException(e, this);
+                throw new DefaultMuleException(e);
             }
             if (factory == null)
             {
                 // no connection factory ... give up
-                throw new InitialisationException(JmsMessages.noConnectionFactoryConfigured(), this);
+                throw new DefaultMuleException(JmsMessages.noConnectionFactoryConfigured());
             }
             return factory;
         }
@@ -407,8 +395,20 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         }
     }
 
-    protected Connection createConnection() throws NamingException, JMSException, InitialisationException
+    protected Connection createConnection() throws MuleException, JMSException
     {
+        if (connectionFactory == null)
+        {
+            try
+            {
+                connectionFactory = this.createConnectionFactory();
+            }
+            catch (NamingException ne)
+            {
+                throw new DefaultMuleException(JmsMessages.errorCreatingConnectionFactory(), ne);
+            }
+        }
+
         ConnectionFactory cf = this.connectionFactory;
         Connection connection;
 
@@ -447,9 +447,36 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         }
 
 
+
         return connection;
     }
 
+    @Override
+    public void connect() throws Exception {
+        if (muleContext.isPrimaryPollingInstance() || clientId == null)
+        {
+            super.connect();
+        }
+        else
+        {
+            muleContext.registerListener(new ClusterNodeNotificationListener<ClusterNodeNotification>()
+            {
+                @Override
+                public void onNotification(ClusterNodeNotification notification)
+                {
+                    try
+                    {
+                        JmsConnector.this.connect();
+                    }
+                    catch (Exception e)
+                    {
+                        throw new MuleRuntimeException(e);
+                    }
+                }
+            });
+        }
+    }
+
     public void onException(JMSException jmsException)
     {
         final JmsConnector jmsConnector = JmsConnector.this;
@@ -466,13 +493,13 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         }
 
         int expectedReceiverCount = isMultiConsumerReceiver ? 1 :
-                (jmsConnector.getReceivers().size() * jmsConnector.getNumberOfConcurrentTransactedReceivers());
+                                    (jmsConnector.getReceivers().size() * jmsConnector.getNumberOfConcurrentTransactedReceivers());
 
         if (logger.isDebugEnabled())
         {
             logger.debug("About to recycle myself due to remote JMS connection shutdown but need "
-                    + "to wait for all active receivers to report connection loss. Receiver count: "
-                    + (receiverReportedExceptionCount.get() + 1) + '/' + expectedReceiverCount);
+                         + "to wait for all active receivers to report connection loss. Receiver count: "
+                         + (receiverReportedExceptionCount.get() + 1) + '/' + expectedReceiverCount);
         }
 
         if (receiverReportedExceptionCount.incrementAndGet() >= expectedReceiverCount)
@@ -486,6 +513,11 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
     protected void doConnect() throws Exception
     {
         connection = createConnection();
+        if ((connectionFactoryProperties != null) && !connectionFactoryProperties.isEmpty())
+        {
+            // apply connection factory properties
+            BeanUtils.populateWithoutFail(connectionFactory, connectionFactoryProperties, true);
+        }
         if (isStarted())
         {
             connection.start();
@@ -549,6 +581,11 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         final boolean topic = getTopicResolver().isTopic(endpoint);
         return getSession(endpoint.getTransactionConfig().isTransacted(), topic);
     }
+    
+    public Session createSession(ImmutableEndpoint endpoint) throws JMSException
+    {
+        return createSession(endpoint.getTransactionConfig().isTransacted(),getTopicResolver().isTopic(endpoint));
+    }
 
     public Session getSession(boolean transacted, boolean topic) throws JMSException
     {
@@ -560,13 +597,13 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
 
         Transaction tx = TransactionCoordination.getInstance().getTransaction();
 
-        session = jmsSupport.createSession(connection, topic, transacted, acknowledgementMode, noLocal);
+        session = createSession(transacted, topic);
 
         if (logger.isDebugEnabled())
         {
             logger.debug(MessageFormat.format(
                     "Retrieved new jms session from connection: " +
-                            "topic={0}, transacted={1}, ack mode={2}, nolocal={3}: {4}",
+                    "topic={0}, transacted={1}, ack mode={2}, nolocal={3}: {4}",
                     topic, transacted, acknowledgementMode, noLocal, session));
         }
 
@@ -586,6 +623,13 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         return session;
     }
 
+    private Session createSession(boolean transacted, boolean topic) throws JMSException
+    {
+        Session session;
+        session = jmsSupport.createSession(connection, topic, transacted, acknowledgementMode, noLocal);
+        return session;
+    }
+
     @Override
     protected void doStart() throws MuleException
     {
@@ -641,7 +685,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
             {
                 connection.stop();
             }
-            catch (JMSException e)
+            catch (Exception e)
             {
                 // this exception may be thrown when the broker is shut down, but the
                 // stop process should continue all the same
@@ -717,7 +761,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         {
             close(producer);
         }
-        catch (JMSException e)
+        catch (Exception e)
         {
             logger.warn("Failed to close jms message producer: " + e.getMessage());
         }
@@ -757,7 +801,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         {
             close(consumer);
         }
-        catch (JMSException e)
+        catch (Exception e)
         {
             logger.warn("Failed to close jms message consumer: " + e.getMessage());
         }
@@ -795,7 +839,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
             {
                 close(session);
             }
-            catch (JMSException e)
+            catch (Exception e)
             {
                 logger.warn("Failed to close jms session consumer: " + e.getMessage());
             }
@@ -832,7 +876,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         {
             close(tempQueue);
         }
-        catch (JMSException e)
+        catch (Exception e)
         {
             if (logger.isWarnEnabled())
             {
@@ -878,7 +922,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         {
             close(tempTopic);
         }
-        catch (JMSException e)
+        catch (Exception e)
         {
             if (logger.isWarnEnabled())
             {
@@ -1002,8 +1046,8 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         else
         {
             throw new IllegalArgumentException(
-                "JMS specification needs to be one of the defined values in JmsConstants but was: "
-                                + specification);
+                    "JMS specification needs to be one of the defined values in JmsConstants but was: "
+                    + specification);
         }
     }
 
@@ -1167,7 +1211,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
     }
 
     /**
-     * @Deprecated use a {@link JndiNameResolver} instead of access this property
+     * @deprecated use a {@link JndiNameResolver} instead of access this property
      */
     @Deprecated
     public String getJndiInitialFactory()
@@ -1176,7 +1220,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
     }
 
     /**
-     * @Deprecated use a {@link JndiNameResolver} instead of access this property
+     * @deprecated use a {@link JndiNameResolver} instead of access this property
      */
     @Deprecated
     public void setJndiInitialFactory(String jndiInitialFactory)
@@ -1185,7 +1229,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
     }
 
     /**
-     * @Deprecated use a {@link JndiNameResolver} instead of access this property
+     * @deprecated use a {@link JndiNameResolver} instead of access this property
      */
     @Deprecated
     public String getJndiProviderUrl()
@@ -1194,7 +1238,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
     }
 
     /**
-     * @Deprecated use a {@link JndiNameResolver} instead of access this property
+     * @deprecated use a {@link JndiNameResolver} instead of access this property
      */
     @Deprecated
     public void setJndiProviderUrl(String jndiProviderUrl)
@@ -1203,7 +1247,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
     }
 
     /**
-     * @Deprecated use a {@link JndiNameResolver} instead of access this property
+     * @deprecated use a {@link JndiNameResolver} instead of access this property
      */
     @Deprecated
     public Map getJndiProviderProperties()
@@ -1212,7 +1256,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
     }
 
     /**
-     * @Deprecated use a {@link JndiNameResolver} instead of access this property
+     * @deprecated use a {@link JndiNameResolver} instead of access this property
      */
     @Deprecated
     public void setJndiProviderProperties(Map jndiProviderProperties)
@@ -1346,8 +1390,35 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
             {
                 return (JmsSelectorFilter) mp;
             }
+            else if (mp instanceof MessageFilter)
+            {
+                MessageFilter mf = (MessageFilter) mp;
+                if (mf.getFilter() instanceof JmsSelectorFilter)
+                {
+                    return (JmsSelectorFilter) mf.getFilter();
+                }
+            }
         }
 
         return null;
     }
+
+    @Override
+    protected Session createOperationResource(ImmutableEndpoint endpoint) throws MuleException
+    {
+        try
+        {
+            return createSession(endpoint);
+        }
+        catch (JMSException e)
+        {
+            throw new DefaultMuleException(e);
+        }
+    }
+
+    @Override
+    protected Object getOperationResourceFactory()
+    {
+        return getConnection();
+    }
 }
