@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractJmsFunctionalTestCase.java 19506 2010-09-09 18:12:49Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -15,7 +15,7 @@ import org.mule.api.config.ConfigurationBuilder;
 import org.mule.api.transaction.Transaction;
 import org.mule.config.spring.SpringXmlConfigurationBuilder;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
 import org.mule.transaction.TransactionCoordination;
 import org.mule.util.ClassUtils;
 import org.mule.util.CollectionUtils;
@@ -41,7 +41,6 @@ import javax.jms.Session;
 import javax.jms.TextMessage;
 import javax.jms.Topic;
 import javax.jms.TopicConnection;
-import javax.jms.TopicPublisher;
 import javax.transaction.HeuristicMixedException;
 import javax.transaction.HeuristicRollbackException;
 import javax.transaction.RollbackException;
@@ -49,14 +48,18 @@ import javax.transaction.SystemException;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.junit.After;
-import org.junit.Before;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 /**
  * This is the base class for all integration tests that are part of the JMS integration test suite.  This is
  * a suite that can be run on multiple JMS providers since all configuration for the provider is abstracted into
  * a single class which implements {@link org.mule.transport.jms.integration.JmsVendorConfiguration}.  The implementation
- * of this class is loaded by looking for the classname in a properties file called 'jms-vendor-configs.txt'in the root
+ * of this class is loaded by looking for the classname in a properties file called 'jms-vendor-configs.txt' in the root
  * classpath.
  * <p/>
  * This test case provides a number of support methods for testing Jms providers with Mule.  This implementation is based
@@ -73,7 +76,7 @@ import org.junit.Before;
  * The following properties are made available -
  * <ul>
  * <li>${inbound.destination} - the URI of the inbound destination (retrieved from an {@link org.mule.transport.jms.integration.JmsVendorConfiguration} implementation)</li>
- * <li>${outbound.destination} - the URI of the outbound destination (retrieved from an {@link org.mule.transport.jms.integration.JmsVendorConfiguration implementation)</li>
+ * <li>${outbound.destination} - the URI of the outbound destination (retrieved from an {@link org.mule.transport.jms.integration.JmsVendorConfiguration} implementation)</li>
  * <li>${middle.destination} - the URI of the middle destination (retrieved from an {@link org.mule.transport.jms.integration.JmsVendorConfiguration} implementation)</li>
  * <li>${middle2.destination} - the URI of a second middle destination 'middle2'.</li>
  * <li>${middle3.destination} - the URI of a third middle destination 'middle3'.</li>
@@ -86,8 +89,7 @@ import org.junit.Before;
  * transformers for the Jms connector being tested. These configurations are known as 'connector' files, they share the same
  * file name as the generic configuration file prepended with 'connector-'.  The location of these files must be
  * <p/>
- * <code>
- * integration/&lt;provider_name>/connector-&lt;event_flow_config_name></code>
+ * <code>integration/&lt;provider_name>/connector-&lt;event_flow_config_name></code>
  * <p/>
  * The 'provider_name' is obtained from the {@link org.mule.transport.jms.integration.JmsVendorConfiguration} implementation.
  * <p/>
@@ -118,6 +120,8 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
     protected Scenario scenarioRollback;
     protected Scenario scenarioNotReceive;
     protected Scenario scenarioReceive;
+    protected boolean purgeQueuesOnPreSetUp = true;
+    protected boolean purgeQueuesOnTearDown = true;
 
     private MuleClient client = null;
 
@@ -140,7 +144,7 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
      * TODO this method can return more than one provider, but our test class can only handle one at a time
      * IMPORTANT: Only set one class in 'jms-vendor-configs.txt'
      */
-    public static Collection jmsProviderConfigs()
+    public static Collection<?> jmsProviderConfigs()
     {
         JmsVendorConfiguration[][] configs;
         URL url = ClassUtils.getResource("jms-vendor-configs.txt", AbstractJmsFunctionalTestCase.class);
@@ -159,10 +163,10 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
         try
         {
-            List classes = IOUtils.readLines(url.openStream());
+            List<?> classes = IOUtils.readLines(url.openStream());
             configs = new JmsVendorConfiguration[1][classes.size()];
             int i = 0;
-            for (Iterator iterator = classes.iterator(); iterator.hasNext(); i++)
+            for (Iterator<?> iterator = classes.iterator(); iterator.hasNext(); i++)
             {
                 String cls = (String) iterator.next();
                 configs[0][i] = (JmsVendorConfiguration) ClassUtils.instanciateClass(cls, ClassUtils.NO_ARGS);
@@ -177,30 +181,6 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
         }
     }
 
-    /**
-     * Since we are using JUnit 4, but the Mule Test Framework assumes JUnit 3, we
-     * need to explicitly call the setUp and tearDown methods
-     *
-     * @throws Exception if, well, anything goes wrong
-     */
-    @Before
-    public void before() throws Exception
-    {
-        super.setUp();
-    }
-
-    /**
-     * Since we are using JUnit 4, but the Mule Test Framework assumes JUnit 3, we
-     * need to explicitly call the setUp and tearDown methods
-     *
-     * @throws Exception if, well, anything goes wrong
-     */
-    @After
-    public void after() throws Exception
-    {
-        super.tearDown();
-    }
-
     public AbstractJmsFunctionalTestCase()
     {
         // TODO jmsProviderConfigs() can return more than one provider, but our test class can only handle one at a time
@@ -217,30 +197,18 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
         scenarioReceive = new ScenarioReceive();
     }
 
-    @Override
-    protected void suitePreSetUp() throws Exception
-    {
-        super.suitePreSetUp();
-
-        purge(getInboundQueueName());
-        purge(getOutboundQueueName());
-        // TODO DZ: get all of the queue/topic names from the Mule config and just purge those 
-    }
-
     /**
      * Adds the following properties to the registry so that the Xml configuration files can reference them.
      * <p/>
      * <ul>
      * <li>${inbound.destination} - the URI of the inbound destination (retrieved from an {@link org.mule.transport.jms.integration.JmsVendorConfiguration} implementation)</li>
-     * <li>${outbound.destination} - the URI of the outbound destination (retrieved from an {@link org.mule.transport.jms.integration.JmsVendorConfiguration implementation)</li>
+     * <li>${outbound.destination} - the URI of the outbound destination (retrieved from an {@link org.mule.transport.jms.integration.JmsVendorConfiguration} implementation)</li>
      * <li>${middle.destination} - the URI of the middle destination (retrieved from an {@link org.mule.transport.jms.integration.JmsVendorConfiguration} implementation)</li>
      * <li>${middle2.destination} - the URI of a second middle destination 'middle2'.</li>
      * <li>${middle3.destination} - the URI of a third middle destination 'middle3'.</li>
      * <li>${broadcast.destination} - the URI of the broadcast topic (retrieved from an {@link org.mule.transport.jms.integration.JmsVendorConfiguration} implementation)</li>
      * <li>${protocol} - the protocol of the current messaging connector (retrieved from an {@link org.mule.transport.jms.integration.JmsVendorConfiguration} implementation)</li>
      * </ul>
-     *
-     * @return
      */
     @Override
     protected Properties getStartUpProperties()
@@ -256,7 +224,7 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
         props.put(BROADCAST_TOPIC_ENDPOINT_KEY, getJmsConfig().getTopicBroadcastEndpoint());
         props.put("protocol", getJmsConfig().getProtocol());
 
-        Map p = getJmsConfig().getProperties();
+        Map<?, ?> p = getJmsConfig().getProperties();
         if (p != null)
         {
             props.putAll(p);
@@ -398,13 +366,13 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
      * This calls through to {@link org.mule.transport.jms.integration.JmsVendorConfiguration#getDeadLetterDestinationName()}
      *
      * @return The test inbound destination name
-     */    
+     */
     protected final String getDeadLetterQueueName()
     {
         checkConfig();
         return getJmsConfig().getDeadLetterDestinationName();
-    }    
-    
+    }
+
     /**
      * The test outbound queue name.  For consistency this should always be 'out'. Note that you need to make
      * sure that this queue is available in the the JMS provider being tested.
@@ -513,9 +481,18 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
         assertNull(result);
     }
 
+    @Override
     protected void doSetUp() throws Exception
     {
         super.doSetUp();
+
+        if (purgeQueuesOnPreSetUp)
+        {
+            purge(getInboundQueueName());
+            purge(getOutboundQueueName());
+            // TODO DZ: get all of the queue/topic names from the Mule config and just purge those
+        }
+
         client = new MuleClient(muleContext);
         Transaction tx = TransactionCoordination.getInstance().getTransaction();
         if (tx != null)
@@ -525,11 +502,15 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
         }
     }
 
+    @Override
     protected void doTearDown() throws Exception
     {
-        purge(getInboundQueueName());
-        purge(getOutboundQueueName());
-        purgeTopics();
+        if (purgeQueuesOnTearDown)
+        {
+            purge(getInboundQueueName());
+            purge(getOutboundQueueName());
+            purgeTopics();
+        }
 
         super.doTearDown();
         if (client != null)
@@ -598,11 +579,6 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
     /**
      * By default this will create a Queue, override to create a topic
-     *
-     * @param session
-     * @param scenario
-     * @return
-     * @throws JMSException
      */
     protected Destination createInputDestination(Session session, Scenario scenario) throws JMSException
     {
@@ -611,18 +587,12 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
     /**
      * By default this will create a Queue, override to create a topic
-     *
-     * @param session
-     * @param scenario
-     * @return
-     * @throws JMSException
      */
     protected Destination createOutputDestination(Session session, Scenario scenario) throws JMSException
     {
         return session.createQueue(scenario.getOutputDestinationName());
     }
 
-     /**/
     public Message receive(Scenario scenario) throws Exception
     {
         assertNotNull("scenario is null!", scenario);
@@ -662,7 +632,14 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
         {
             if (connection != null)
             {
-                connection.close();
+                try
+                {
+                    connection.close();
+                }
+                catch (JMSException e)
+                {
+                    logger.warn("Failed to close jms connection: " + e.getMessage());
+                }
             }
         }
     }
@@ -672,10 +649,7 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
      * other tests may still exist from other tests' runs.
      * <p/>
      * Well-behaving tests should drain both inbound and outbound destinations, as well as any intermediary ones.
-     * Typically this method is called from {@link #suitePreSetUp()} and {@link #suitePostTearDown()}, with proper super calls.
      * @param destination destination name without any protocol specifics
-     * @see #suitePreSetUp()
-     * @see #suitePostTearDown()
      */
     protected void purge(final String destination) throws JMSException
     {
@@ -697,7 +671,7 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
                 logger.debug("Destination " + destination + " isn't empty, draining it");
             }
         }
-        catch (Exception e)        
+        catch (Exception e)
         {
             logger.error("unable to purge : " + destination);
         }
@@ -710,7 +684,14 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
                 {
                     s.close();
                 }
-                c.close();
+                try
+                {
+                    c.close();
+                }
+                catch (JMSException e)
+                {
+                    logger.warn("Failed to close jms connection: " + e.getMessage());
+                }
             }
         }
     }
@@ -731,10 +712,6 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
     /**
      * Clear the specified topic
-     *
-     * @param destination
-     * @param topic
-     * @throws Exception
      */
     protected void purgeTopic(String destination, String topic) throws Exception
     {
@@ -744,7 +721,7 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
         try
         {
             logger.debug("purging topic : " + topic);
-            c = (TopicConnection) getConnection(true, false);
+            c = getConnection(true, false);
             if (c == null)
             {
                 logger.debug("could not create a connection to topic : " + destination);
@@ -757,8 +734,6 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
             Topic dest = s.createTopic(destination);
             logger.debug("created topic destination");
 
-            TopicPublisher t;
-
             if (client != null)
             {
                 client.dispose();
@@ -768,7 +743,7 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
             try
             {
-                consumer = s.createDurableSubscriber((Topic) dest, topic);
+                consumer = s.createDurableSubscriber(dest, topic);
                 logger.debug("created consumer");
                 while (consumer.receiveNoWait() != null)
                 {
@@ -793,7 +768,14 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
                 {
                     s.close();
                 }
-                c.close();
+                try
+                {
+                    c.close();
+                }
+                catch (JMSException e)
+                {
+                    logger.warn("Failed to close jms connection: " + e.getMessage());
+                }
             }
         }
         logger.debug("completed draining topic :" + topic);
@@ -815,7 +797,6 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
     protected interface Scenario
     {
-
         boolean isPersistent();
 
         void setPersistent(boolean persistent);
@@ -843,52 +824,60 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
     protected abstract class AbstractScenario implements Scenario
     {
-
         private String inputQueue = getInboundQueueName();
         private String outputQueue = getOutboundQueueName();
         private boolean persistent = false;
 
+        @Override
         public boolean isPersistent()
         {
             return persistent;
         }
 
+        @Override
         public void setPersistent(boolean persistent)
         {
             this.persistent = persistent;
         }
 
+        @Override
         public String getInputDestinationName()
         {
             return inputQueue;
         }
 
+        @Override
         public String getOutputDestinationName()
         {
             return outputQueue;
         }
 
+        @Override
         public void setInputDestinationName(String inputQueue)
         {
             this.inputQueue = inputQueue;
         }
 
+        @Override
         public void setOutputDestinationName(String outputQueue)
         {
             this.outputQueue = outputQueue;
         }
 
+        @Override
         public int getAcknowledge()
         {
             return Session.AUTO_ACKNOWLEDGE;
         }
 
+        @Override
         public void send(Session session, MessageProducer producer) throws JMSException
         {
             producer.send(session.createTextMessage(DEFAULT_INPUT_MESSAGE));
             applyTransaction(session);
         }
 
+        @Override
         public Message receive(Session session, MessageConsumer consumer) throws JMSException
         {
             Message message = consumer.receive(getTimeout());
@@ -904,12 +893,13 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
     protected class NonTransactedScenario extends AbstractScenario
     {
-
+        @Override
         public boolean isTransacted()
         {
             return false;
         }
 
+        @Override
         protected void applyTransaction(Session session) throws JMSException
         {
             // do nothing
@@ -918,12 +908,13 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
     protected class ScenarioCommit extends AbstractScenario
     {
-
+        @Override
         public boolean isTransacted()
         {
             return true;
         }
 
+        @Override
         protected void applyTransaction(Session session) throws JMSException
         {
             session.commit();
@@ -932,12 +923,13 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
     protected class ScenarioRollback extends AbstractScenario
     {
-
+        @Override
         public boolean isTransacted()
         {
             return true;
         }
 
+        @Override
         protected void applyTransaction(Session session) throws JMSException
         {
             session.rollback();
@@ -946,7 +938,6 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
     protected class ScenarioNotReceive extends NonTransactedScenario
     {
-
         @Override
         public Message receive(Session session, MessageConsumer consumer) throws JMSException
         {
@@ -958,7 +949,6 @@ public abstract class AbstractJmsFunctionalTestCase extends FunctionalTestCase
 
     protected class ScenarioReceive extends NonTransactedScenario
     {
-
         @Override
         public Message receive(Session session, MessageConsumer consumer) throws JMSException
         {
