@@ -1,5 +1,5 @@
 /*
- * $Id: JmsQueueWithTransactionTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -16,8 +16,13 @@ import org.mule.module.client.MuleClient;
 
 import org.junit.Test;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
 public class JmsQueueWithTransactionTestCase extends AbstractJmsFunctionalTestCase
 {
+
+    @Override
     protected String getConfigResources()
     {
         return "integration/jms-queue-with-transaction.xml";
