@@ -1,5 +1,5 @@
 /*
- * $Id: JmsRemoteSyncMule2868TestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -16,9 +16,12 @@ import org.mule.module.client.MuleClient;
 
 import org.junit.Test;
 
+import static org.junit.Assert.assertEquals;
+
 public class JmsRemoteSyncMule2868TestCase extends AbstractJmsFunctionalTestCase
 {
 
+    @Override
     protected String getConfigResources()
     {
         return "integration/jms-remote-sync-mule2868.xml";
