@@ -1,5 +1,5 @@
 /*
- * $Id: JmsSingleTransactionNoneTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -17,15 +17,17 @@ import org.junit.Test;
  */
 public class JmsSingleTransactionNoneTestCase extends AbstractJmsFunctionalTestCase
 {
+
+    @Override
     protected String getConfigResources()
     {
         return "integration/jms-single-tx-NONE.xml";
     }
 
     @Override
-    protected void suitePreSetUp() throws Exception
+    protected void doSetUp() throws Exception
     {
-        super.suitePreSetUp();
+        super.doSetUp();
 
         purge(getInboundQueueName());
         purge(getJmsConfig().getMiddleDestinationName());
