@@ -1,5 +1,5 @@
 /*
- * $Id: MulticastMessageReceiver.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -76,4 +76,9 @@ public class MulticastMessageReceiver extends UdpMessageReceiver
         super.doDispose();
     }
 
+    @Override
+    public boolean shouldConsumeInEveryNode()
+    {
+        return false;
+    }
 }
