@@ -1,5 +1,5 @@
 /*
- * $Id: QuartzEventGeneratorAnnotationTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,22 +12,30 @@ package org.mule.transport.quartz;
 
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
 import org.mule.transport.NullPayload;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+
 public class QuartzEventGeneratorAnnotationTestCase extends FunctionalTestCase
 {
+
     @Override
     protected String getConfigResources()
     {
         return "quartz-event-generator-with-annotation.xml";
     }
 
+    @Test
     public void testReceiveEvent() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
 
-        MuleMessage result = client.request("vm://intervalQueue", RECEIVE_TIMEOUT);
+        MuleMessage result = client.request("vm://intervalQueue", RECEIVE_TIMEOUT * 2);
         assertNotNull(result);
         assertFalse(result.getPayload() instanceof NullPayload);
         assertEquals("pinged! (interval)", result.getPayload());
@@ -37,7 +45,4 @@ public class QuartzEventGeneratorAnnotationTestCase extends FunctionalTestCase
         assertFalse(result.getPayload() instanceof NullPayload);
         assertEquals("pinged! (cron)", result.getPayload());
     }
-    
 }
-
-
