@@ -1,5 +1,5 @@
 /*
- * $Id: QuartzMessageDispatcher.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -64,9 +64,10 @@ public class QuartzMessageDispatcher extends AbstractMessageDispatcher
 
         JobDetail jobDetail = new JobDetail();
         // make the job name unique per endpoint (MULE-753)
-        jobDetail.setName(event.getEndpoint().getEndpointURI().getAddress() + "-" + event.getId());
+        jobDetail.setName(endpoint.getEndpointURI().getAddress() + "-" + event.getId());
 
         JobDataMap jobDataMap = new JobDataMap();
+        jobDataMap.put(QuartzConnector.PROPERTY_JOB_DYNAMIC, Boolean.TRUE);
         MuleMessage msg = event.getMessage();
         // populate from invocation and outbound scopes only
         for (String key : msg.getInvocationPropertyNames())
@@ -81,8 +82,9 @@ public class QuartzMessageDispatcher extends AbstractMessageDispatcher
         if (jobConfig instanceof ScheduledDispatchJobConfig) 
         {
             ScheduledDispatchJobConfig scheduledDispatchJobConfig = (ScheduledDispatchJobConfig) jobConfig;
-            String endpointRef = event.getMuleContext().getExpressionManager().parse(
-                scheduledDispatchJobConfig.getEndpointRef(), event.getMessage());
+            String endpointRef = event.getMuleContext()
+                .getExpressionManager()
+                .parse(scheduledDispatchJobConfig.getEndpointRef(), event);
 
             jobDataMap.put("endpointRef", endpointRef);
         }
@@ -160,7 +162,7 @@ public class QuartzMessageDispatcher extends AbstractMessageDispatcher
             throw new IllegalArgumentException(
                 QuartzMessages.cronExpressionOrIntervalMustBeSet().getMessage());
         }
-        trigger.setName(event.getEndpoint().getEndpointURI().toString() + "-" + event.getId());
+        trigger.setName(endpoint.getEndpointURI().toString() + "-" + event.getId());
         trigger.setGroup(groupName);
         trigger.setJobName(jobDetail.getName());
         trigger.setJobGroup(jobGroupName);
