@@ -1,5 +1,5 @@
 /*
- * $Id: ScheduleConfigBuilder.java 21320 2011-02-20 08:01:36Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,7 +12,7 @@ package org.mule.transport.quartz.config;
 import org.mule.MessageExchangePattern;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleException;
-import org.mule.api.NamedObject;
+import org.mule.api.NameableObject;
 import org.mule.api.endpoint.EndpointBuilder;
 import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.transport.quartz.QuartzConnector;
@@ -22,7 +22,7 @@ import org.quartz.Scheduler;
 /**
  * TODO
  */
-public class ScheduleConfigBuilder implements NamedObject
+public class ScheduleConfigBuilder implements NameableObject
 {
     private EndpointBuilder endpointBuilder;
     private QuartzConnector connector;
