@@ -1,5 +1,5 @@
 /*
- * $Id: MuleRESTReceiverServlet.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -194,7 +194,7 @@ public class MuleRESTReceiverServlet extends MuleReceiverServlet
             }
         }
 
-        InboundEndpoint endpoint = muleContext.getRegistry().lookupEndpointFactory().getInboundEndpoint(endpointName);
+        InboundEndpoint endpoint = muleContext.getEndpointFactory().getInboundEndpoint(endpointName);
         if (endpoint == null)
         {
             // if we dont find an endpoint for the given name, lets check the
