@@ -1,5 +1,5 @@
 /*
- * $Id: ServletNamespaceHandlerTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,26 +10,35 @@
 
 package org.mule.transport.servlet;
 
-import org.mule.tck.FunctionalTestCase;
 import org.mule.api.endpoint.EndpointBuilder;
+import org.mule.tck.junit4.FunctionalTestCase;
+
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 
 public class ServletNamespaceHandlerTestCase extends FunctionalTestCase
 {
+
+    @Override
     protected String getConfigResources()
     {
         return "servlet-namespace-config.xml";
     }
 
+    @Test
     public void testElements() throws Exception
     {
         ServletConnector connector =
                 (ServletConnector) muleContext.getRegistry().lookupConnector("servletConnector");
 
         assertEquals("foo", connector.getServletUrl());
-
         EndpointBuilder b = muleContext.getRegistry().lookupEndpointBuilder("ep");
         assertNotNull(b);
         assertEquals("foo/bar", b.buildInboundEndpoint().getEndpointURI().getAddress());
+        assertTrue(connector.isUseCachedHttpServletRequest());
     }
 
 }
