@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractSftpTestCase.java 21886 2011-05-11 22:45:18Z pablo.kraan $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,32 +10,33 @@
 
 package org.mule.transport.sftp;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 import static org.mule.context.notification.EndpointMessageNotification.MESSAGE_DISPATCHED;
 import static org.mule.context.notification.EndpointMessageNotification.MESSAGE_SENT;
 
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleEventContext;
 import org.mule.api.MuleException;
-import org.mule.api.component.Component;
 import org.mule.api.context.notification.EndpointMessageNotificationListener;
 import org.mule.api.context.notification.ServerNotification;
 import org.mule.api.endpoint.EndpointBuilder;
 import org.mule.api.endpoint.EndpointURI;
 import org.mule.api.endpoint.ImmutableEndpoint;
-import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.api.exception.MessagingExceptionHandler;
+import org.mule.api.exception.RollbackSourceCallback;
 import org.mule.api.exception.SystemExceptionHandler;
 import org.mule.api.model.Model;
 import org.mule.api.service.Service;
 import org.mule.api.transport.Connector;
 import org.mule.context.notification.EndpointMessageNotification;
 import org.mule.module.client.MuleClient;
-import org.mule.routing.filters.WildcardFilter;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 import org.mule.tck.functional.EventCallback;
+import org.mule.tck.junit4.rule.DynamicPort;
+import org.mule.transport.sftp.util.SftpServer;
 import org.mule.transport.sftp.util.ValueHolder;
-import org.mule.util.FileUtils;
-import org.mule.util.IOUtils;
 import org.mule.util.StringMessageUtils;
 
 import com.jcraft.jsch.ChannelSftp;
@@ -51,25 +52,43 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-
-import edu.emory.mathcs.backport.java.util.concurrent.CountDownLatch;
-import edu.emory.mathcs.backport.java.util.concurrent.TimeUnit;
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicInteger;
+import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicInteger;
 
 import org.apache.commons.lang.SystemUtils;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import org.junit.Before;
+import org.junit.Rule;
 
 /**
  * @author Lennart Häggkvist, Magnus Larsson Date: Jun 8, 2009
  */
-public abstract class AbstractSftpTestCase extends FunctionalTestCase
+public abstract class AbstractSftpTestCase extends AbstractServiceAndFlowTestCase
 {
+    private static final String HOST = "localhost";
+    private static final String USER = "muletest1";
+    private static final String PASSWORD = "muletest1";
+    private static final String FILENAME_HEADER = "filename";
+    protected static final Map<String, String> MESSAGE_PROPERTIES = new HashMap<String, String>();
+    protected static String INBOUND_ENDPOINT_DIR = "inbound";
+    protected static String OUTBOUND_ENDPOINT_DIR = "outbound";
+    {
+        MESSAGE_PROPERTIES.put(FILENAME_HEADER, FILENAME);
+    }
 
-    protected static final String FILE_NAME = "file.txt";
+    protected static final String FILENAME = "file.txt";
 
-    protected final Logger logger = LoggerFactory.getLogger(AbstractSftpTestCase.class);
+    @Rule
+    public DynamicPort port = new DynamicPort("SFTP_PORT");
 
+    protected SftpServer sftpServer;
+    protected SftpClient sftpClient;
+    
+    public AbstractSftpTestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
+    }
+    
     /**
      * Deletes all files in the directory, useful when testing to ensure that no
      * files are in the way...
@@ -93,7 +112,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
      * Deletes a directory with all its files and sub-directories. The reason it do a
      * "chmod 700" before the delete is that some tests changes the permission, and
      * thus we have to restore the right to delete it...
-     * 
+     *
      * @param muleClient
      * @param endpointName
      * @param relativePath
@@ -216,17 +235,13 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
     /**
      * Returns a SftpClient that is logged in to the sftp server that the endpoint is
      * configured against.
-     * 
-     * @param muleClient
-     * @param endpointName
-     * @return
-     * @throws IOException
      */
     protected SftpClient getSftpClient(MuleClient muleClient, String endpointName) throws IOException
     {
         ImmutableEndpoint endpoint = getImmutableEndpoint(muleClient, endpointName);
         EndpointURI endpointURI = endpoint.getEndpointURI();
         SftpClient sftpClient = new SftpClient(endpointURI.getHost());
+        sftpClient.setPort(endpointURI.getPort());
 
         SftpConnector sftpConnector = (SftpConnector) endpoint.getConnector();
 
@@ -256,6 +271,27 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
         return sftpClient;
     }
 
+    /**
+     * Returns a SftpClient that is logged in to the sftp server that the endpoint is
+     * configured against.
+     */
+    protected SftpClient getSftpClient(String host, int port, String user, String password)
+        throws IOException
+    {
+        SftpClient sftpClient = new SftpClient(host);
+        sftpClient.setPort(port);
+        try
+        {
+            sftpClient.login(user, password);
+        }
+        catch (Exception e)
+        {
+            fail("Login failed: " + e);
+        }
+        return sftpClient;
+    }
+
+    
     /** Checks if the file exists on the server */
     protected boolean verifyFileExists(SftpClient sftpClient, EndpointURI endpointURI, String file)
         throws IOException
@@ -327,6 +363,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
 
         EventCallback callback = new EventCallback()
         {
+            @Override
             public void eventReceived(MuleEventContext context, Object component) throws Exception
             {
 
@@ -369,21 +406,18 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
             // and count down the latch after saving the thrown exception
             muleContext.setExceptionListener(new SystemExceptionHandler()
             {
-                public void handleException(Exception e)
+                @Override
+                public void handleException(Exception e, RollbackSourceCallback rollbackMethod)
                 {
                     if (logger.isInfoEnabled()) logger.info("expected exception occurred: " + e, e);
                     exceptionHolder.value = e;
                     latch.countDown();
                 }
 
-                public WildcardFilter getCommitTxFilter()
+                @Override
+                public void handleException(Exception exception)
                 {
-                    return null;
-                }
-
-                public WildcardFilter getRollbackTxFilter()
-                {
-                    return null;
+                    handleException(exception, null);
                 }
             });
 
@@ -392,6 +426,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
                 muleContext.getRegistry().lookupService(serviceName).setExceptionListener(
                     new MessagingExceptionHandler()
                     {
+                        @Override
                         public MuleEvent handleException(Exception e, MuleEvent event)
                         {
                             if (logger.isInfoEnabled()) logger.info("expected exception occurred: " + e, e);
@@ -399,16 +434,6 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
                             latch.countDown();
                             return event;
                         }
-
-                        public WildcardFilter getCommitTxFilter()
-                        {
-                            return null;
-                        }
-
-                        public WildcardFilter getRollbackTxFilter()
-                        {
-                            return null;
-                        }
                     });
             }
         }
@@ -418,6 +443,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
         {
             int totSize = 0;
 
+            @Override
             public int read() throws IOException
             {
                 totSize++;
@@ -465,6 +491,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
      */
     protected void executeBaseAssertionsBeforeCall()
     {
+        // empty
     }
 
     /**
@@ -528,7 +555,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
     /**
      * Initiates a list of sftp-endpoint-directories. Ensures that affected services
      * are stopped during the initiation.
-     * 
+     *
      * @param serviceNames
      * @param endpointNames
      * @throws Exception
@@ -570,7 +597,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
     /**
      * Ensures that the directory exists and is writable by deleting the directory
      * and then recreate it.
-     * 
+     *
      * @param endpointName
      * @throws org.mule.api.MuleException
      * @throws java.io.IOException
@@ -610,10 +637,11 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
      * outbound endpoint, i.e. that the file has been consumed by the inbound
      * endpoint and that the content of the file has been sent to the outgoing
      * endpoint.
-     * 
+     *
      * @param p where inboundEndpoint and outboundEndpoint are mandatory, @see
      *            DispatchParameters for details.
      */
+    @SuppressWarnings("rawtypes")
     protected void dispatchAndWaitForDelivery(final DispatchParameters p)
     {
         // Declare countdown latch and listener
@@ -631,6 +659,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
             // outbound endpoint
             listener = new EndpointMessageNotificationListener()
             {
+                @Override
                 public void onNotification(ServerNotification notification)
                 {
 
@@ -719,10 +748,9 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
     /**
      * Helper method for initiating a test and wait for an exception to be caught by
      * the sftp-connector.
-     * 
+     *
      * @param p where sftpConnector and inboundEndpoint are mandatory, @see
      *            DispatchParameters for details.
-     * @return
      */
     protected Exception dispatchAndWaitForException(final DispatchParameters p,
                                                     String expectedFailingConnector,
@@ -747,8 +775,8 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
             // sftp-connector
             listener = new SystemExceptionHandler()
             {
-
-                public void handleException(Exception e)
+                @Override
+                public void handleException(Exception e, RollbackSourceCallback rollbackMethod)
                 {
                     exceptionHolder.value = e;
                     if (logger.isDebugEnabled())
@@ -757,19 +785,16 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
                     latch.countDown();
                 }
 
-                public WildcardFilter getCommitTxFilter()
+                @Override
+                public void handleException(Exception exception)
                 {
-                    return null;
-                }
-
-                public WildcardFilter getRollbackTxFilter()
-                {
-                    return null;
+                    handleException(exception, null);
                 }
             };
 
             messagingListener = new MessagingExceptionHandler()
             {
+                @Override
                 public MuleEvent handleException(Exception e, MuleEvent event)
                 {
                     exceptionHolder.value = e;
@@ -779,16 +804,6 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
                     latch.countDown();
                     return event;
                 }
-
-                public WildcardFilter getCommitTxFilter()
-                {
-                    return null;
-                }
-
-                public WildcardFilter getRollbackTxFilter()
-                {
-                    return null;
-                }
             };
 
             currentMessagingListener = muleContext.getRegistry()
@@ -852,7 +867,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
                 currentMessagingListener);
         }
 
-        return (Exception) exceptionHolder.value;
+        return exceptionHolder.value;
     }
 
     protected void recursiveDeleteInLocalFilesystem(File parent) throws IOException
@@ -892,8 +907,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
         if (parent.exists())
         {
             // FIXME DZ: since setWritable doesnt exist on jdk5, need to detect os to make dir writable
-            String os = System.getProperty("os.name").toLowerCase();
-            if(SystemUtils.IS_OS_WINDOWS)
+            if (SystemUtils.IS_OS_WINDOWS)
             {
                 Runtime.getRuntime().exec("attrib -r /D" + parent.getAbsolutePath());
             }
@@ -911,7 +925,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
 
     /**
      * Asserts that there are no files found on the path <i>path</i>.
-     * 
+     *
      * @param path The path in the local filesystem to check
      * @throws IOException Exception
      */
@@ -922,7 +936,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
 
     /**
      * Asserts that no files are found on the path that the <i>endpointName</i> use.
-     * 
+     *
      * @param muleClient MuleClient
      * @param endpointName The endpoint name
      * @throws IOException Exception
@@ -935,7 +949,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
     /**
      * Asserts that no files are found on the sub directory <i>subDirectory</i> under
      * the path that <i>endpointName</i> use.
-     * 
+     *
      * @param muleClient MuleClient
      * @param endpointName The endpoint name
      * @param subDirectory The sub directory
@@ -950,7 +964,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
     /**
      * Asserts that only the <i>expectedFile</i> is found on the path <i>path</i>,
      * where filenames can be expressed as a regular expression.
-     * 
+     *
      * @param path The path in the local filesystem to check
      * @param expectedFile Expected file
      * @throws IOException Exception
@@ -963,7 +977,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
     /**
      * Asserts that only the <i>expectedFiles</i> are found on the path <i>path</i>,
      * where filenames can be expressed as a regular expression.
-     * 
+     *
      * @param path The path in the local filesystem to check
      * @param expectedFiles Expected files
      * @throws IOException Exception
@@ -981,7 +995,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
      * Asserts that only the <i>expectedFile</i> is found on the path that the
      * <i>endpointName</i> use, where filenames can be expressed as a regular
      * expression.
-     * 
+     *
      * @param muleClient MuleClient
      * @param endpointName The endpoint name
      * @param expectedFile Expected file
@@ -997,7 +1011,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
      * Asserts that only the <i>expectedFiles</i> are found on the path that the
      * <i>endpointName</i> use, where filenames can be expressed as a regular
      * expression.
-     * 
+     *
      * @param muleClient MuleClient
      * @param endpointName The endpoint name
      * @param expectedFiles Expected files
@@ -1013,7 +1027,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
      * Asserts that only the <i>expectedFile</i> is found on the sub directory
      * <i>subDirectory</i> under the path that <i>endpointName</i> use, where
      * filenames can be expressed as a regular expression.
-     * 
+     *
      * @param muleClient MuleClient
      * @param endpointName The endpoint name
      * @param subDirectory The sub directory
@@ -1032,7 +1046,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
      * Asserts that only the <i>expectedFiles</i> are found on the sub directory
      * <i>subDirectory</i> under the path that <i>endpointName</i> use, where
      * filenames can be expressed as a regular expression.
-     * 
+     *
      * @param muleClient MuleClient
      * @param endpointName The endpoint name
      * @param subDirectory The sub directory
@@ -1064,7 +1078,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
     /**
      * Asserts that only the <i>expectedFiles</i> are found on the path <i>path</i>,
      * where filenames can be expressed as a regular expression.
-     * 
+     *
      * @param sftpClient SftpClient
      * @param path The path to check
      * @param expectedFiles Expected files
@@ -1083,7 +1097,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
     /**
      * Asserts that only the <i>expectedFiles</i> are found in the file-array
      * <i>path</i>, where filenames can be expressed as a regular expression.
-     * 
+     *
      * @param path
      * @param expectedFiles
      * @param foundFiles
@@ -1121,7 +1135,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
 
     /**
      * Return the first string in a string-list that matches the regexp
-     * 
+     *
      * @param list
      * @param regexp
      * @return the first string that match the regexp or null if no match
@@ -1147,7 +1161,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
      * Helper class for dynamic assignment of parameters to the method
      * dispatchAndWaitForDelivery() Only inboundEndpoint and outboundEndpoint are
      * mandatory, the rest of the parameters are optional.
-     * 
+     *
      * @author Magnus Larsson
      */
     public class DispatchParameters
@@ -1185,7 +1199,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
         /**
          * Optional name of the file, defaults to FILE_NAME
          */
-        private String filename = FILE_NAME;
+        private String filename = FILENAME;
 
         /**
          * Mandatory name of the outbound endpoint, i.e. where we will wait for a
@@ -1197,7 +1211,7 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
          * Optional timeout for how long we will wait for a message to be delivered
          * to the outbound endpoint
          */
-        private long timeout = 10000;
+        private long timeout = 100000;
 
         public DispatchParameters(String inboundEndpoint, String outboundEndpoint)
         {
@@ -1295,54 +1309,37 @@ public abstract class AbstractSftpTestCase extends FunctionalTestCase
     {
         assertTrue("context is not started", muleContext.getLifecycleManager().getState().isStarted());
         Map<String, Connector> connectorMap = muleContext.getRegistry().lookupByType(Connector.class);
-        Map<String, InboundEndpoint> inboundMap = muleContext.getRegistry().lookupByType(
-            InboundEndpoint.class);
         Map<String, Service> serviceMap = muleContext.getRegistry().lookupByType(Service.class);
         Map<String, Model> modelMap = muleContext.getRegistry().lookupByType(Model.class);
-        Map<String, Component> componentMap = muleContext.getRegistry().lookupByType(Component.class);
-        // Map<String, OutboundEndpoint> outboundMap =
-        // muleContext.getRegistry().lookupByType(OutboundEndpoint.class);
 
-        Iterator it = connectorMap.entrySet().iterator();
-        while (it.hasNext())
+        Iterator<Map.Entry<String, Connector>> connectorItr = connectorMap.entrySet().iterator();
+        while (connectorItr.hasNext())
         {
-            Map.Entry<String, Connector> pairs = (Map.Entry<String, Connector>) it.next();
+            Map.Entry<String, Connector> pairs = connectorItr.next();
             logger.debug("checking connector : " + pairs.getKey());
             assertTrue(pairs.getKey() + " is not started", pairs.getValue().isStarted());
         }
 
-        it = serviceMap.entrySet().iterator();
-        while (it.hasNext())
+        Iterator<Map.Entry<String, Service>> serviceItr = serviceMap.entrySet().iterator();
+        while (serviceItr.hasNext())
         {
-            Map.Entry<String, Service> pairs = (Map.Entry<String, Service>) it.next();
+            Map.Entry<String, Service> pairs = serviceItr.next();
             assertTrue(pairs.getKey() + " is not started", pairs.getValue().isStarted());
         }
 
-        it = modelMap.entrySet().iterator();
-        while (it.hasNext())
+        Iterator<Map.Entry<String, Model>> modelItr = modelMap.entrySet().iterator();
+        while (modelItr.hasNext())
         {
-            Map.Entry<String, Model> pairs = (Map.Entry<String, Model>) it.next();
+            Map.Entry<String, Model> pairs = modelItr.next();
             assertTrue(pairs.getKey() + " is not started", pairs.getValue().getLifecycleState().isStarted());
         }
     }
     
-    /**
-     * Look for the sftp test properties file in our environment.
-     * If it's not found, don't run these tests 
-     */
-    @Override
-    protected boolean isDisabledInThisEnvironment()
-    {
-
-        try
-        {
-            IOUtils.getResourceAsString("sftp-settings.properties", this.getClass());
-        }
-        catch (IOException e)
-        {
-            return true;
-        }
-        
-        return false;
+    @Before
+    public void before() throws Exception {
+        sftpServer = new SftpServer(this.port.getNumber());
+        sftpServer.start();
+        sftpClient = getSftpClient(HOST, port.getNumber(), USER, PASSWORD);
     }
+    
 }
