@@ -1,5 +1,5 @@
 /*
- * $Id: SftpSizeCheckFunctionalTestCase.java 21084 2011-01-24 23:33:30Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,19 +10,35 @@
 
 package org.mule.transport.sftp;
 
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
 /**
- * Test the sizeCheck feature.
+ * Test the sizeCheck feature
  */
 public class SftpSizeCheckFunctionalTestCase extends AbstractSftpTestCase
 {
+
     private static final long TIMEOUT = 15000;
 
     // Size of the generated stream - 2 Mb
     final static int SEND_SIZE = 1024 * 1024 * 2;
 
-    protected String getConfigResources()
+    public SftpSizeCheckFunctionalTestCase(ConfigVariant variant, String configResources)
     {
-        return "mule-sftp-sizeCheck-test-config.xml";
+        super(variant, configResources);
+    }
+    
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "mule-sftp-sizeCheck-test-config-service.xml"},
+            {ConfigVariant.FLOW, "mule-sftp-sizeCheck-test-config-flow.xml"}
+        });
     }
 
     @Override
@@ -36,12 +52,13 @@ public class SftpSizeCheckFunctionalTestCase extends AbstractSftpTestCase
     /**
      * Test the sizeCheck feature
      */
+    @Test
     public void testSizeCheck() throws Exception
     {
         // TODO. Add some tests specific to sizeCheck, i.e. create a very large file
         // and ensure that the sizeChec prevents the inbound enpoint to read the file
         // during creation of it
 
-        executeBaseTest("inboundEndpoint", "vm://test.upload", FILE_NAME, SEND_SIZE, "receiving", TIMEOUT);
+        executeBaseTest("inboundEndpoint", "vm://test.upload", FILENAME, SEND_SIZE, "receiving", TIMEOUT);
     }
 }
