@@ -1,5 +1,5 @@
 /*
- * $Id: SftpTempDirFunctionalTestCase.java 22475 2011-07-20 14:30:04Z justin.calleja $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -40,10 +40,8 @@ public class SftpTempDirFunctionalTestCase extends AbstractSftpTestCase
     @Parameters
     public static Collection<Object[]> parameters()
     {
-        return Arrays.asList(new Object[][]{
-            {ConfigVariant.SERVICE, "mule-sftp-temp-dir-config-service.xml"},
-            {ConfigVariant.FLOW, "mule-sftp-temp-dir-config-flow.xml"}
-        });
+        return Arrays.asList(new Object[][]{{ConfigVariant.SERVICE, "mule-sftp-temp-dir-config-service.xml"},
+            {ConfigVariant.FLOW, "mule-sftp-temp-dir-config-flow.xml"}});
     }
 
     @Override
@@ -76,9 +74,9 @@ public class SftpTempDirFunctionalTestCase extends AbstractSftpTestCase
             assertFalse(
                 "No file should exist in the temp directory",
                 super.verifyFileExists(sftpClientInbound, endpointInbound.getEndpointURI().getPath()
-                                                          + "/uploading", FILE_NAME));
+                                                          + "/uploading", FILENAME));
             assertFalse("The file should not exist in the source directory",
-                super.verifyFileExists(sftpClientInbound, endpointInbound.getEndpointURI(), FILE_NAME));
+                super.verifyFileExists(sftpClientInbound, endpointInbound.getEndpointURI(), FILENAME));
         }
         finally
         {
@@ -92,8 +90,8 @@ public class SftpTempDirFunctionalTestCase extends AbstractSftpTestCase
         {
             assertFalse("The temp directory should not have been created",
                 tempDirectoryExists(sftpClientOutbound, muleClient, OUTBOUND_ENDPOINT_NAME2));
-            assertTrue("The file should exist in the final destination : " + FILE_NAME,
-                super.verifyFileExists(sftpClientOutbound, endpointOutbound.getEndpointURI(), FILE_NAME));
+            assertTrue("The file should exist in the final destination : " + FILENAME,
+                super.verifyFileExists(sftpClientOutbound, endpointOutbound.getEndpointURI(), FILENAME));
         }
         finally
         {
@@ -119,7 +117,7 @@ public class SftpTempDirFunctionalTestCase extends AbstractSftpTestCase
             assertFalse("The temp directory should not have been created",
                 tempDirectoryExists(sftpClientInbound, muleClient, INBOUND_ENDPOINT_NAME));
             assertFalse("The file should not exist in the source directory",
-                super.verifyFileExists(sftpClientInbound, endpointInbound.getEndpointURI(), FILE_NAME));
+                super.verifyFileExists(sftpClientInbound, endpointInbound.getEndpointURI(), FILENAME));
         }
         finally
         {
@@ -134,7 +132,7 @@ public class SftpTempDirFunctionalTestCase extends AbstractSftpTestCase
             assertTrue("The temp directory should have been created",
                 tempDirectoryExists(sftpClientOutbound, muleClient, OUTBOUND_ENDPOINT_NAME));
             assertTrue("The file should exist in the final destination",
-                super.verifyFileExists(sftpClientOutbound, endpointOutbound.getEndpointURI(), FILE_NAME));
+                super.verifyFileExists(sftpClientOutbound, endpointOutbound.getEndpointURI(), FILENAME));
         }
         finally
         {
