@@ -1,5 +1,5 @@
 /*
- * $Id: ExceptionListener.java 21084 2011-01-24 23:33:30Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,6 +10,7 @@
 
 package org.mule.transport.sftp.notification;
 
+import org.mule.api.exception.RollbackSourceCallback;
 import org.mule.api.exception.SystemExceptionHandler;
 
 import org.slf4j.Logger;
@@ -24,4 +25,8 @@ public class ExceptionListener implements SystemExceptionHandler
         logger.debug(e.getLocalizedMessage());
     }
 
+    public void handleException(Exception exception, RollbackSourceCallback rollbackMethod)
+    {
+        handleException(exception);
+    }
 }
