@@ -1,5 +1,5 @@
 /*
- * $Id: AxisConnector.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,6 +12,7 @@ package org.mule.transport.soap.axis;
 
 import org.mule.api.MuleContext;
 import org.mule.api.MuleException;
+import org.mule.api.MuleRuntimeException;
 import org.mule.api.construct.FlowConstruct;
 import org.mule.api.context.notification.MuleContextNotificationListener;
 import org.mule.api.endpoint.EndpointBuilder;
@@ -20,7 +21,7 @@ import org.mule.api.endpoint.ImmutableEndpoint;
 import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.processor.MessageProcessor;
-import org.mule.api.security.EndpointSecurityFilter;
+import org.mule.api.security.SecurityFilter;
 import org.mule.api.service.Service;
 import org.mule.api.source.CompositeMessageSource;
 import org.mule.api.transport.MessageReceiver;
@@ -47,6 +48,7 @@ import org.mule.util.ClassUtils;
 import org.mule.util.CollectionUtils;
 import org.mule.util.MuleUrlStreamHandlerFactory;
 
+import java.lang.reflect.Field;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -55,6 +57,7 @@ import java.util.Map;
 
 import javax.xml.namespace.QName;
 
+import org.apache.axis.AxisProperties;
 import org.apache.axis.client.Call;
 import org.apache.axis.configuration.SimpleProvider;
 import org.apache.axis.deployment.wsdd.WSDDConstants;
@@ -401,7 +404,7 @@ public class AxisConnector extends AbstractConnector implements MuleContextNotif
         serviceEndpointbuilder.addMessageProcessor(new MessageFilter(receiver.getEndpoint().getFilter()));
         // set the Security filter on the axis endpoint on the real receiver
         // endpoint
-        EndpointSecurityFilter securityFilter = receiver.getEndpoint().getSecurityFilter();
+        SecurityFilter securityFilter = receiver.getEndpoint().getSecurityFilter();
         if (securityFilter != null)
         {
             serviceEndpointbuilder.addMessageProcessor(new SecurityFilterMessageProcessor(securityFilter));
@@ -417,17 +420,14 @@ public class AxisConnector extends AbstractConnector implements MuleContextNotif
         CollectionUtils.removeType(procs, SecurityFilterMessageProcessor.class);
         receiverEndpointBuilder.setMessageProcessors(procs);
 
-        InboundEndpoint serviceEndpoint = muleContext.getRegistry()
-            .lookupEndpointFactory()
+        InboundEndpoint serviceEndpoint = muleContext.getEndpointFactory()
             .getInboundEndpoint(serviceEndpointbuilder);
 
-        InboundEndpoint receiverEndpoint = muleContext.getRegistry()
-            .lookupEndpointFactory()
+        InboundEndpoint receiverEndpoint = muleContext.getEndpointFactory()
             .getInboundEndpoint(receiverEndpointBuilder);
 
         receiver.setEndpoint(receiverEndpoint);
 
-        
         ((CompositeMessageSource) axisComponent.getMessageSource()).addSource(serviceEndpoint);
     }
 
@@ -448,7 +448,7 @@ public class AxisConnector extends AbstractConnector implements MuleContextNotif
 
     // This initialization could be performed in the initialize() method.  Putting it here essentially makes
     // it a lazy-create/lazy-init
-    // Another option would be to put it in the default-axis-config.xml (MULE-2102) with lazy-init="true" 
+    // Another option would be to put it in the default-axis-config.xml (MULE-2102) with lazy-init="true"
     // but that makes us depend on Spring.
     // Another consideration is how/when this implicit component gets disposed.
     protected Service getOrCreateAxisComponent() throws MuleException
@@ -511,7 +511,24 @@ public class AxisConnector extends AbstractConnector implements MuleContextNotif
     @Override
     protected void doDispose()
     {
-        // template method
+        // clear static references to classloaders to prevent loading classes from
+        // closed jars and avoid memory leaks on application redeploy.
+        try
+        {
+            Field field = AxisProperties.class.getDeclaredField("loaders");
+            field.setAccessible(true);
+            field.set(null, null);
+
+            field = AxisProperties.class.getDeclaredField("nameDiscoverer");
+            field.setAccessible(true);
+            field.set(null, null);
+        }
+        catch (Exception e)
+        {
+            logger.error(
+                "Error disposing AxisConnector, this may cause a memory leak. Error is: " + e.getMessage(), e);
+        }
+
     }
 
     public String getServerConfig()
@@ -657,7 +674,7 @@ public class AxisConnector extends AbstractConnector implements MuleContextNotif
                         axisComponent = getOrCreateAxisComponent();
                     }
                     muleContext.getRegistry().registerService(axisComponent);
-    
+
                     // We have to perform a small hack here to rewrite servlet://
                     // endpoints with the
                     // real http:// address
@@ -682,7 +699,7 @@ public class AxisConnector extends AbstractConnector implements MuleContextNotif
         }
         catch (MuleException e)
         {
-            handleException(e);
+            throw new MuleRuntimeException(e);
         }
     }
 }
