@@ -1,5 +1,5 @@
 /*
- * $Id: SaveCertificateCallback.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,13 +13,12 @@ package org.mule.transport.ssl;
 import org.mule.api.MuleEventContext;
 import org.mule.tck.functional.EventCallback;
 
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicBoolean;
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicReference;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicReference;
 
 public class SaveCertificateCallback implements EventCallback
 {
-
-    private AtomicReference certificates;
+    private AtomicReference<Object> certificates;
     private AtomicBoolean called;
 
     public SaveCertificateCallback()
@@ -27,6 +26,7 @@ public class SaveCertificateCallback implements EventCallback
         clear();
     }
 
+    @Override
     public void eventReceived(MuleEventContext context, Object component) throws Exception
     {
         certificates.set(context.getMessage().getOutboundProperty(SslConnector.LOCAL_CERTIFICATES));
@@ -35,7 +35,7 @@ public class SaveCertificateCallback implements EventCallback
 
     public void clear()
     {
-        certificates = new AtomicReference();
+        certificates = new AtomicReference<Object>();
         called = new AtomicBoolean(false);
     }
 
@@ -48,5 +48,4 @@ public class SaveCertificateCallback implements EventCallback
     {
         return certificates.get();
     }
-
 }
