@@ -1,5 +1,5 @@
 /*
- * $Id: SslFunctionalTestCase.java 20756 2010-12-15 19:20:32Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,24 +10,54 @@
 
 package org.mule.transport.ssl;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 import org.mule.api.MuleMessage;
 import org.mule.api.service.Service;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
 import org.mule.tck.functional.CounterCallback;
 import org.mule.tck.functional.EventCallback;
 import org.mule.tck.functional.FunctionalTestComponent;
+import org.mule.tck.junit4.FunctionalTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
 import org.mule.tck.testmodels.mule.TestSedaService;
+import org.mule.util.JdkVersionUtils;
+import org.mule.util.JdkVersionUtils.JdkVersion;
 
-public class SslFunctionalTestCase extends DynamicPortTestCase 
+import org.junit.Rule;
+import org.junit.Test;
+
+public class SslFunctionalTestCase extends FunctionalTestCase 
 {
     private static int NUM_MESSAGES = 100;
 
+    @Rule
+    public DynamicPort dynamicPort1 = new DynamicPort("port1");
+
+    @Rule
+    public DynamicPort dynamicPort2 = new DynamicPort("port2");
+
+    @Rule
+    public DynamicPort dynamicPort3 = new DynamicPort("port3");
+
+    @Override
     protected String getConfigResources()
     {
         return "ssl-functional-test.xml";
     }
 
+    @Override
+    protected boolean isExcluded()
+    {
+        // exclude these tests if we're running in Java 7 because ssl is broken in
+        // the jdk
+        return super.isExcluded() || System.getProperty("java.version").matches("1\\.7\\..*")
+        		|| JdkVersionUtils.getJdkVersion().compareTo(new JdkVersion("1.6.0_26")) > 0;
+    }
+
+    @Test
     public void testSend() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -35,6 +65,7 @@ public class SslFunctionalTestCase extends DynamicPortTestCase
         assertEquals(TEST_MESSAGE + " Received", result.getPayloadAsString());
     }
 
+    @Test
     public void testSendMany() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -56,6 +87,7 @@ public class SslFunctionalTestCase extends DynamicPortTestCase
         assertEquals(NUM_MESSAGES, ((CounterCallback) cc).getCallbackCount());
     }
 
+    @Test
     public void testAsynchronous() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -67,9 +99,4 @@ public class SslFunctionalTestCase extends DynamicPortTestCase
         assertEquals(TEST_MESSAGE + " Received Async", response.getPayloadAsString());
     }
 
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 3;
-    }
 }
