@@ -1,5 +1,5 @@
 /*
- * $Id: SslHandshakeTimingTestCase.java 22387 2011-07-12 03:53:36Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,16 +10,19 @@
 
 package org.mule.transport.ssl;
 
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
+
 import org.mule.DefaultMuleMessage;
 import org.mule.api.MuleMessage;
 import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.api.service.Service;
 import org.mule.config.DefaultMuleConfiguration;
-import org.mule.service.ServiceCompositeMessageSource;
 import org.mule.tck.junit4.AbstractMuleContextTestCase;
 
-import com.mockobjects.dynamic.Mock;
-
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.util.Collections;
@@ -27,10 +30,6 @@ import java.util.Map;
 
 import org.junit.Test;
 
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-
 /**
  * Whitebox test for the SSL latch in SslMessageReceiver. The use of reflection here is hacky
  * but the alternative would be stubbing large parts of the JSSE classes in order to influence
@@ -43,7 +42,7 @@ public class SslHandshakeTimingTestCase extends AbstractMuleContextTestCase
     public void testSslHandshakeTimeout() throws Exception
     {
         SslMessageReceiver receiver = setupMockSslMessageReciever();
-        
+
         // note how we call preRoute without a prior handshakeCompleted ... this must
         // run into a timeout
         try
@@ -58,16 +57,16 @@ public class SslHandshakeTimingTestCase extends AbstractMuleContextTestCase
             assertTrue(cause instanceof IllegalStateException);
         }
     }
-    
+
     @Test
     public void testSslHandshakeSuccessful() throws Exception
     {
         SslMessageReceiver receiver = setupMockSslMessageReciever();
-                
+
         MuleMessage message = new DefaultMuleMessage(TEST_MESSAGE, muleContext);
         receiver.handshakeCompleted(new MockHandshakeCompletedEvent());
         callPreRoute(receiver, message);
-        
+
         assertNotNull(message.getOutboundProperty(SslConnector.PEER_CERTIFICATES));
         assertNotNull(message.getOutboundProperty(SslConnector.LOCAL_CERTIFICATES));
     }
@@ -76,21 +75,15 @@ public class SslHandshakeTimingTestCase extends AbstractMuleContextTestCase
     {
         SslConnector connector = new SslConnector(muleContext);
         connector.setSslHandshakeTimeout(1000);
-        
-        Mock mockService = new Mock(Service.class);
-        mockService.expect("getResponseRouter");
-        mockService.expectAndReturn("getInboundRouter", new ServiceCompositeMessageSource());
-        Service service = (Service) mockService.proxy();
-        
+
         Map<String, Object> properties = Collections.emptyMap();
 
-        Mock mockEndpoint = new Mock(InboundEndpoint.class);
-        mockEndpoint.expectAndReturn("getConnector", connector);
-        mockEndpoint.expectAndReturn("getEncoding", new DefaultMuleConfiguration().getDefaultEncoding());
-        mockEndpoint.expectAndReturn("getProperties", properties);
-        mockEndpoint.expectAndReturn("getProperties", properties);
-        InboundEndpoint endpoint = (InboundEndpoint) mockEndpoint.proxy();
+        InboundEndpoint endpoint = mock(InboundEndpoint.class);
+        when(endpoint.getProperties()).thenReturn(properties);
+        when(endpoint.getConnector()).thenReturn(connector);
+        when(endpoint.getEncoding()).thenReturn(new DefaultMuleConfiguration().getDefaultEncoding());
 
+        Service service = mock(Service.class);
         return new SslMessageReceiver(connector, service, endpoint);
     }
 
@@ -99,7 +92,7 @@ public class SslHandshakeTimingTestCase extends AbstractMuleContextTestCase
         Method preRouteMessage = receiver.getClass().getDeclaredMethod("preRoute", MuleMessage.class);
         assertNotNull(preRouteMessage);
         preRouteMessage.setAccessible(true);
-                
+
         preRouteMessage.invoke(receiver, new Object[] { message });
     }
 }
