@@ -1,5 +1,5 @@
 /*
- * $Id: TcpLengthFunctionalTestCase.java 19817 2010-10-04 18:10:39Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,24 +12,49 @@ package org.mule.transport.tcp;
 
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
 
-public class TcpLengthFunctionalTestCase extends DynamicPortTestCase
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.ClassRule;
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
+
+public class TcpLengthFunctionalTestCase extends AbstractServiceAndFlowTestCase
 {
     protected static String TEST_MESSAGE = "Test TCP Request";
     private int timeout = 60 * 1000 / 20;
 
-    public TcpLengthFunctionalTestCase()
+    @ClassRule
+    public static DynamicPort dynamicPort1 = new DynamicPort("port1");
+
+    @ClassRule
+    public static DynamicPort dynamicPort2 = new DynamicPort("port2");
+
+    @ClassRule
+    public static DynamicPort dynamicPort3 = new DynamicPort("port3");
+        
+    public TcpLengthFunctionalTestCase(ConfigVariant variant, String configResources)
     {
-        setDisposeManagerPerSuite(true);
+        super(variant, configResources);        
+        setDisposeContextPerClass(true);
     }
-
-    protected String getConfigResources()
+    
+    @Parameters
+    public static Collection<Object[]> parameters()
     {
-        return "tcp-length-functional-test.xml";
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "tcp-length-functional-test-service.xml"},
+            {ConfigVariant.FLOW, "tcp-length-functional-test-flow.xml"}
+        });
     }
 
+    @Test
     public void testSend() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -37,6 +62,7 @@ public class TcpLengthFunctionalTestCase extends DynamicPortTestCase
         assertEquals(TEST_MESSAGE + " Received", result.getPayloadAsString());
     }
 
+    @Test
     public void testDispatchAndReplyViaStream() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -48,6 +74,7 @@ public class TcpLengthFunctionalTestCase extends DynamicPortTestCase
         assertNull(result);
     }
 
+    @Test
     public void testDispatchAndReply() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -59,9 +86,4 @@ public class TcpLengthFunctionalTestCase extends DynamicPortTestCase
         assertNull(result);
     }
 
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 3;
-    }
 }
