@@ -1,5 +1,5 @@
 /*
- * $Id: LengthProtocolLengthTestCase.java 19817 2010-10-04 18:10:39Z dzapata $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,26 +10,53 @@
 
 package org.mule.transport.tcp.issues;
 
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
 
-import edu.emory.mathcs.backport.java.util.Arrays;
+import java.util.Arrays;
+import java.util.Collection;
 
-public class LengthProtocolLengthTestCase extends DynamicPortTestCase
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
+public class LengthProtocolLengthTestCase extends AbstractServiceAndFlowTestCase
 {
 
-    protected String getConfigResources()
+    @Rule
+    public DynamicPort dynamicPort1 = new DynamicPort("port1");
+
+    @Rule
+    public DynamicPort dynamicPort2 = new DynamicPort("port2");
+
+    public LengthProtocolLengthTestCase(ConfigVariant variant, String configResources)
     {
-        return "length-protocol-length-test.xml";
+        super(variant, configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "length-protocol-length-test-service.xml"},
+            {ConfigVariant.FLOW, "length-protocol-length-test-flow.xml"}
+        });
+    }      
+
+    @Test
     public void testLength() throws Exception
     {
         doTest("length", 5, true);
         doTest("length", 15, false);
     }
 
+    @Test
     public void testSafe() throws Exception
     {
         doTest("safe", 5, true);
@@ -72,10 +99,4 @@ public class LengthProtocolLengthTestCase extends DynamicPortTestCase
         }
     }
 
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 2;
-    }
-
 }
