@@ -1,5 +1,5 @@
 /*
- * $Id: MultiStreamMule1692TestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,40 +10,61 @@
 
 package org.mule.transport.tcp.issues;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicReference;
+
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
 import org.mule.api.MuleEventContext;
 import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 import org.mule.tck.functional.EventCallback;
 import org.mule.tck.functional.FunctionalStreamingTestComponent;
+import org.mule.tck.junit4.rule.DynamicPort;
 
-import java.util.HashMap;
-
-import edu.emory.mathcs.backport.java.util.concurrent.CountDownLatch;
-import edu.emory.mathcs.backport.java.util.concurrent.TimeUnit;
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicReference;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
-public class MultiStreamMule1692TestCase extends DynamicPortTestCase
+public class MultiStreamMule1692TestCase extends AbstractServiceAndFlowTestCase
 {
-
-    private static final Log logger = LogFactory.getLog(MultiStreamMule1692TestCase.class);
+    
     public static final int TIMEOUT = 3000;
     public static final String TEST_MESSAGE = "Test TCP Request";
     public static final String TEST_MESSAGE_2 = "Second test TCP Request";
     public static final String RESULT = "Received stream; length: 16; 'Test...uest'";
-    public static final String RESULT_2 = "Received stream; length: 23; 'Seco...uest'"; 
-    
-    protected String getConfigResources()
-    {
-        return "tcp-streaming-test.xml";
-    }
+    public static final String RESULT_2 = "Received stream; length: 23; 'Seco...uest'";
 
-    private EventCallback newCallback(final CountDownLatch latch, final AtomicReference message)
+    @Rule
+    public DynamicPort dynamicPort1 = new DynamicPort("port1");
+
+    @Rule
+    public DynamicPort dynamicPort2 = new DynamicPort("port2");
+
+    public MultiStreamMule1692TestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
+    }
+    
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "tcp-streaming-test-service.xml"},
+            {ConfigVariant.FLOW, "tcp-streaming-test-flow.xml"}
+        });
+    }
+    
+    private EventCallback newCallback(final CountDownLatch latch, final AtomicReference<String> message)
     {
         return new EventCallback()
         {
+            @Override
             public synchronized void eventReceived(MuleEventContext context, Object component)
             {
                 try
@@ -63,38 +84,30 @@ public class MultiStreamMule1692TestCase extends DynamicPortTestCase
             }
         };
     }
-    
+
+    @Test
     public void testSend() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
 
         Object ftc = getComponent("testComponent");
         assertTrue("FunctionalStreamingTestComponent expected", ftc instanceof FunctionalStreamingTestComponent);
-//        assertNotNull(ftc);
-//        assertEquals(1, ftc.getNumber());
 
 
         final CountDownLatch latch = new CountDownLatch(1);
-        final AtomicReference message = new AtomicReference();
+        final AtomicReference<String> message = new AtomicReference<String>();
         ((FunctionalStreamingTestComponent) ftc).setEventCallback(newCallback(latch, message), TEST_MESSAGE.length());
         client.dispatch(((InboundEndpoint) client.getMuleContext().getRegistry().lookupObject("testInbound")).getAddress(),
-            TEST_MESSAGE, new HashMap());
+            TEST_MESSAGE, new HashMap<Object, Object>());
         latch.await(10, TimeUnit.SECONDS);
         assertEquals(RESULT, message.get());
 
         final CountDownLatch latch2 = new CountDownLatch(1);
-        final AtomicReference message2 = new AtomicReference();
+        final AtomicReference<String> message2 = new AtomicReference<String>();
         ((FunctionalStreamingTestComponent) ftc).setEventCallback(newCallback(latch2, message2), TEST_MESSAGE_2.length());
         client.dispatch(((InboundEndpoint) client.getMuleContext().getRegistry().lookupObject("testInbound")).getAddress(),
-            TEST_MESSAGE_2, new HashMap());
+            TEST_MESSAGE_2, new HashMap<Object, Object>());
         latch2.await(10, TimeUnit.SECONDS);
         assertEquals(RESULT_2, message2.get());
     }
-
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 2;
-    }
 }
-
