@@ -1,5 +1,5 @@
 /*
- * $Id: VMEndpointTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,10 +12,16 @@ package org.mule.transport.vm;
 
 import org.mule.api.endpoint.EndpointURI;
 import org.mule.endpoint.MuleEndpointURI;
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleContextTestCase;
 
-public class VMEndpointTestCase extends AbstractMuleTestCase
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+
+public class VMEndpointTestCase extends AbstractMuleContextTestCase
 {
+
+    @Test
     public void testUrlWithProvider() throws Exception
     {
         EndpointURI url = new MuleEndpointURI("vm://some.queue?endpointName=vmProvider", muleContext);
