@@ -1,5 +1,5 @@
 /*
- * $Id: PersistentUnaddressedVmQueueTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,26 +10,43 @@
 
 package org.mule.transport.vm.functional;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 
-public class PersistentUnaddressedVmQueueTestCase extends FunctionalTestCase
+public class PersistentUnaddressedVmQueueTestCase extends AbstractServiceAndFlowTestCase
 {
+
     private static final int RECEIVE_TIMEOUT = 5000;
 
-    protected String getConfigResources()
+    public PersistentUnaddressedVmQueueTestCase(ConfigVariant variant, String configResources)
     {
-        return "vm/persistent-unaddressed-vm-queue-test.xml";
+        super(variant, configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "vm/persistent-unaddressed-vm-queue-test-service.xml"},
+            {ConfigVariant.FLOW, "vm/persistent-unaddressed-vm-queue-test-flow.xml"}});
+    }
+
+    @Test
     public void testAsynchronousDispatching() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
         client.dispatch("vm://receiver1?connector=Connector1", "Test", null);
         MuleMessage result = client.request("vm://out?connector=Connector2", RECEIVE_TIMEOUT);
         assertNotNull(result);
-        assertEquals(result.getPayloadAsString(),"Test");
+        assertEquals(result.getPayloadAsString(), "Test");
     }
-
 }
