@@ -1,5 +1,5 @@
 /*
- * $Id: CaseInsensitiveHashMapTestCase.java 22387 2011-07-12 03:53:36Z dirk.olmes $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,6 +10,7 @@
 package org.mule.util;
 
 import org.mule.tck.junit4.AbstractMuleTestCase;
+import org.mule.tck.size.SmallTest;
 
 import org.apache.commons.lang.SerializationUtils;
 import org.junit.Test;
@@ -18,6 +19,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
+@SmallTest
 public class CaseInsensitiveHashMapTestCase extends AbstractMuleTestCase
 {
     protected CaseInsensitiveHashMap createTestMap()
