@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractSynchronizedVariable.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,7 +10,7 @@
 
 package org.mule.util.concurrent;
 
-import edu.emory.mathcs.backport.java.util.concurrent.Executor;
+import java.util.concurrent.Executor;
 
 // @ThreadSafe
 public abstract class AbstractSynchronizedVariable implements Executor
