@@ -1,5 +1,5 @@
 /*
- * $Id: CommonsPoolObjectPool.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -74,6 +74,8 @@ public class CommonsPoolObjectPool implements ObjectPool
             config.maxActive = poolingProfile.getMaxActive();
             config.maxWait = poolingProfile.getMaxWait();
             config.whenExhaustedAction = (byte) poolingProfile.getExhaustedAction();
+            config.minEvictableIdleTimeMillis = poolingProfile.getMinEvictionMillis();
+            config.timeBetweenEvictionRunsMillis = poolingProfile.getEvictionCheckIntervalMillis();
         }
 
         pool = new GenericObjectPool(getPooledObjectFactory(), config);
