@@ -1,5 +1,5 @@
 /*
- * $Id: QueueConfiguration.java 24442 2012-05-28 22:15:50Z pablo.kraan $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -17,6 +17,7 @@ import java.io.Serializable;
 
 public class QueueConfiguration
 {
+    public final static int INFINITY_CAPACTY = 0;
     protected final int capacity;
     protected final QueueStore<Serializable> objectStore;
 
@@ -73,4 +74,9 @@ public class QueueConfiguration
     {
         return objectStore.isPersistent();
     }
+
+    public int getCapacity()
+    {
+        return capacity;
+    }
 }
