@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractTransactionContext.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -92,4 +92,7 @@ public abstract class AbstractTransactionContext
         notifyAll();
     }
 
+    public abstract void doCommit() throws ResourceManagerException;
+
+    public abstract void doRollback() throws ResourceManagerException;
 }
