@@ -1,5 +1,5 @@
 /*
- * $Id: SyncWorkExecutor.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id$
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -29,9 +29,9 @@ package org.mule.work;
 
 import org.mule.api.work.WorkExecutor;
 
-import javax.resource.spi.work.WorkException;
+import java.util.concurrent.Executor;
 
-import edu.emory.mathcs.backport.java.util.concurrent.Executor;
+import javax.resource.spi.work.WorkException;
 
 public class SyncWorkExecutor implements WorkExecutor
 {
